@@ -6,7 +6,7 @@ WIKIPATH="../../../flare-engine.wiki"
 
 if [ -d "$WIKIPATH" ]; then
 	sed -e "s/PAGETITLE/$PAGETITLE/g" header.txt > "$HTMLFILE"
-	markdown "$WIKIPATH/Code-Conventions.md" >> "$HTMLFILE"
+	markdown -f -smarty "$WIKIPATH/Code-Conventions.md" >> "$HTMLFILE"
 	cat footer.txt >> "$HTMLFILE"
 fi
 
