@@ -1,5 +1,6 @@
 /*
 Copyright © 2012 Stefan Beller
+Copyright © 2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -15,13 +16,13 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
-#pragma once
-#ifndef __ANIMATION_MANAGER__
-#define __ANIMATION_MANAGER__
+#ifndef ANIMATION_MANAGER_H
+#define ANIMATION_MANAGER_H
 
-#include "AnimationSet.h"
 #include "CommonIncludes.h"
 
+class AnimationSet;
+
 class AnimationManager {
 private:
 	std::vector<AnimationSet*> sets;
