@@ -28,6 +28,7 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 
 #include "CombatText.h"
 #include "CommonIncludes.h"
+#include "EngineSettings.h"
 #include "FileParser.h"
 #include "FontEngine.h"
 #include "Settings.h"
@@ -35,6 +36,8 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "UtilsParsing.h"
 #include "WidgetLabel.h"
 
+#include <stdio.h>
+
 Combat_Text_Item::Combat_Text_Item()
 	: label(NULL)
 	, lifespan(0)
@@ -42,8 +45,8 @@ Combat_Text_Item::Combat_Text_Item()
 	, floating_offset(0)
 	, text("")
 	, displaytype(0)
-	, is_int(false)
-	, int_value(0)
+	, is_number(false)
+	, number_value(0)
 {}
 
 Combat_Text_Item::~Combat_Text_Item() {
@@ -72,8 +75,8 @@ CombatText::CombatText() {
 				duration = Parse::toDuration(infile.val);
 			}
 			else if(infile.key == "speed") {
-				// @ATTR speed|int|Motion speed of the combat text.
-				speed = (static_cast<float>(Parse::toInt(infile.val)) * Settings::LOGIC_FPS) / settings->max_frames_per_sec;
+				// @ATTR speed|float|Motion speed of the combat text.
+				speed = (Parse::toFloat(infile.val) * Settings::LOGIC_FPS) / settings->max_frames_per_sec;
 			}
 			else if (infile.key == "offset") {
 				// @ATTR offset|int|The vertical offset for the combat text's starting position.
@@ -123,28 +126,24 @@ void CombatText::addString(const std::string& message, const FPoint& location, i
 	combat_text.push_back(c);
 }
 
-void CombatText::addInt(int num, const FPoint& location, int displaytype) {
+void CombatText::addFloat(float num, const FPoint& location, int displaytype) {
 	if (!settings->combat_text)
 		return;
 
-	std::stringstream ss;
-
 	// when adding multiple combat text of the same type and position on the same frame, add the num to the existing text
 	for (std::vector<Combat_Text_Item>::iterator it = combat_text.begin(); it != combat_text.end(); ++it) {
-		if (it->is_int && it->displaytype == displaytype && it->lifespan == duration && it->pos.x == location.x && it->pos.y == location.y) {
-			it->int_value += num;
-			ss << it->int_value;
-			it->text = ss.str();
-			it->label->setText(ss.str());
+		if (it->is_number && it->displaytype == displaytype && it->lifespan == duration && it->pos.x == location.x && it->pos.y == location.y) {
+			it->number_value += num;
+			it->text = Utils::floatToString(it->number_value, eset->number_format.combat_text);
+			it->label->setText(it->text);
 			return;
 		}
 	}
 
-	ss << num;
-	addString(ss.str(), location, displaytype);
+	addString(Utils::floatToString(num, eset->number_format.combat_text), location, displaytype);
 
-	combat_text.back().is_int = true;
-	combat_text.back().int_value = num;
+	combat_text.back().is_number = true;
+	combat_text.back().number_value = num;
 }
 
 void CombatText::logic(const FPoint& _cam) {
