@@ -22,14 +22,18 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "Animation.h"
 #include "AnimationManager.h"
 #include "AnimationSet.h"
+#include "CombatText.h"
 #include "EffectManager.h"
 #include "EngineSettings.h"
 #include "Hazard.h"
+#include "MessageEngine.h"
 #include "PowerManager.h"
 #include "Settings.h"
 #include "SharedGameResources.h"
 #include "SharedResources.h"
+#include "StatBlock.h"
 #include "Stats.h"
+#include "UtilsMath.h"
 
 EffectDef::EffectDef()
 	: id("")
@@ -43,7 +47,17 @@ EffectDef::EffectDef()
 	, render_above(false)
 	, color_mod(255, 255, 255)
 	, alpha_mod(255)
-	, attack_speed_anim("") {
+	, attack_speed_anim("")
+	, is_immunity_type(false) {
+}
+
+EffectParams::EffectParams()
+	: is_from_item(false)
+	, is_multiplier(false)
+	, duration(0)
+	, source_type(Power::SOURCE_TYPE_NEUTRAL)
+	, magnitude(0)
+	, power_id(EffectManager::NO_POWER) {
 }
 
 Effect::Effect()
@@ -56,7 +70,7 @@ Effect::Effect()
 	, magnitude_max(0)
 	, animation_name("")
 	, animation(NULL)
-	, item(false)
+	, is_from_item(false)
 	, trigger(-1)
 	, render_above(false)
 	, passive_id(0)
@@ -64,7 +78,8 @@ Effect::Effect()
 	, group_stack(false)
 	, color_mod(Color(255,255,255).encodeRGBA())
 	, alpha_mod(255)
-	, attack_speed_anim("") {
+	, attack_speed_anim("")
+	, is_multiplier(false) {
 }
 
 Effect::Effect(const Effect& other) {
@@ -89,7 +104,7 @@ Effect& Effect::operator=(const Effect& other) {
 	type = other.type;
 	magnitude = other.magnitude;
 	magnitude_max = other.magnitude_max;
-	item = other.item;
+	is_from_item = other.is_from_item;
 	trigger = other.trigger;
 	render_above = other.render_above;
 	passive_id = other.passive_id;
@@ -98,6 +113,7 @@ Effect& Effect::operator=(const Effect& other) {
 	color_mod = other.color_mod;
 	alpha_mod = other.alpha_mod;
 	attack_speed_anim = other.attack_speed_anim;
+	is_multiplier = other.is_multiplier;
 
 	return *this;
 }
@@ -135,15 +151,7 @@ int Effect::getTypeFromString(const std::string& type_str) {
 	else if (type_str == "mpot_percent") return Effect::MPOT_PERCENT;
 	else if (type_str == "speed") return Effect::SPEED;
 	else if (type_str == "attack_speed") return Effect::ATTACK_SPEED;
-	else if (type_str == "immunity") return Effect::IMMUNITY;
-	else if (type_str == "immunity_damage") return Effect::IMMUNITY_DAMAGE;
-	else if (type_str == "immunity_slow") return Effect::IMMUNITY_SLOW;
-	else if (type_str == "immunity_stun") return Effect::IMMUNITY_STUN;
-	else if (type_str == "immunity_hp_steal") return Effect::IMMUNITY_HP_STEAL;
-	else if (type_str == "immunity_mp_steal") return Effect::IMMUNITY_MP_STEAL;
-	else if (type_str == "immunity_knockback") return Effect::IMMUNITY_KNOCKBACK;
-	else if (type_str == "immunity_damage_reflect") return Effect::IMMUNITY_DAMAGE_REFLECT;
-	else if (type_str == "immunity_stat_debuff") return Effect::IMMUNITY_STAT_DEBUFF;
+	else if (type_str == "resist_all") return Effect::RESIST_ALL;
 	else if (type_str == "stun") return Effect::STUN;
 	else if (type_str == "revive") return Effect::REVIVE;
 	else if (type_str == "convert") return Effect::CONVERT;
@@ -152,33 +160,69 @@ int Effect::getTypeFromString(const std::string& type_str) {
 	else if (type_str == "shield") return Effect::SHIELD;
 	else if (type_str == "heal") return Effect::HEAL;
 	else if (type_str == "knockback") return Effect::KNOCKBACK;
+
+	// TODO deprecated effect types
+	else if (type_str == "immunity") return Effect::RESIST_ALL;
+	else if (type_str == "immunity_damage") return Effect::TYPE_COUNT + Stats::RESIST_DAMAGE_OVER_TIME;
+	else if (type_str == "immunity_slow") return Effect::TYPE_COUNT + Stats::RESIST_SLOW;
+	else if (type_str == "immunity_stun") return Effect::TYPE_COUNT + Stats::RESIST_STUN;
+	else if (type_str == "immunity_knockback") return Effect::TYPE_COUNT + Stats::RESIST_KNOCKBACK;
+	else if (type_str == "immunity_damage_reflect") return Effect::TYPE_COUNT + Stats::RESIST_DAMAGE_REFLECT;
+	else if (type_str == "immunity_stat_debuff") return Effect::TYPE_COUNT + Stats::RESIST_STAT_DEBUFF;
+	else if (type_str == "immunity_hp_steal") return Effect::TYPE_COUNT + Stats::RESIST_HP_STEAL;
+	else if (type_str == "immunity_mp_steal") return Effect::TYPE_COUNT + Stats::RESIST_MP_STEAL;
+
 	else {
+		int offset_index = Effect::TYPE_COUNT;
+
 		for (int i=0; i<Stats::COUNT; ++i) {
 			if (type_str == Stats::KEY[i]) {
-				return Effect::TYPE_COUNT + i;
+				return offset_index + i;
 			}
 		}
+		offset_index += Stats::COUNT;
 
 		for (size_t i=0; i<eset->damage_types.list.size(); ++i) {
 			if (type_str == eset->damage_types.list[i].min) {
-				return Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(i*2);
+				return offset_index + static_cast<int>(i*2);
 			}
 			else if (type_str == eset->damage_types.list[i].max) {
-				return Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(i*2) + 1;
+				return offset_index + static_cast<int>(i*2) + 1;
 			}
 		}
+		offset_index += static_cast<int>(eset->damage_types.count);
 
 		for (size_t i=0; i<eset->elements.list.size(); ++i) {
 			if (type_str == eset->elements.list[i].resist_id) {
-				return Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count + i);
+				return offset_index + static_cast<int>(i);
 			}
 		}
+		offset_index += static_cast<int>(eset->elements.list.size());
+
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+				if (type_str == eset->resource_stats.list[i].ids[j]) {
+					return offset_index + static_cast<int>((i * EngineSettings::ResourceStats::STAT_COUNT) + j);
+				}
+			}
+		}
+		offset_index += static_cast<int>(eset->resource_stats.stat_count);
+
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t j = 0; j < EngineSettings::ResourceStats::EFFECT_COUNT; ++j) {
+				if (type_str == eset->resource_stats.list[i].ids[EngineSettings::ResourceStats::STAT_COUNT + j]) {
+					return offset_index + static_cast<int>((i * EngineSettings::ResourceStats::EFFECT_COUNT) + j);
+				}
+			}
+		}
+		offset_index += static_cast<int>(eset->resource_stats.effect_count);
 
 		for (size_t i=0; i<eset->primary_stats.list.size(); ++i) {
 			if (type_str == eset->primary_stats.list[i].id) {
-				return Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size() + i);
+				return offset_index + static_cast<int>(i);
 			}
 		}
+
 	}
 
 	Utils::logError("EffectManager: '%s' is not a valid effect type.", type_str.c_str());
@@ -186,23 +230,42 @@ int Effect::getTypeFromString(const std::string& type_str) {
 }
 
 bool Effect::typeIsStat(int t) {
-	return t >= Effect::TYPE_COUNT && t < Effect::TYPE_COUNT + Stats::COUNT;
+	int offset_index = Effect::TYPE_COUNT;
+	return t >= offset_index && t < offset_index + Stats::COUNT;
 }
 
 bool Effect::typeIsDmgMin(int t) {
-	return t >= Effect::TYPE_COUNT + Stats::COUNT && t < Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) && (t - Stats::COUNT - Effect::TYPE_COUNT) % 2 == 0;
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT;
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->damage_types.count) && (t - offset_index) % 2 == 0;
 }
 
 bool Effect::typeIsDmgMax(int t) {
-	return t >= Effect::TYPE_COUNT + Stats::COUNT && t < Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) && (t - Stats::COUNT - Effect::TYPE_COUNT) % 2 == 1;
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT;
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->damage_types.count) && (t - offset_index) % 2 == 1;
 }
 
 bool Effect::typeIsResist(int t) {
-	return t >= Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) && t < Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size());
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count);
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->elements.list.size());
+}
+
+bool Effect::typeIsResourceStat(int t) {
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count + eset->elements.list.size());
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->resource_stats.stat_count);
+}
+
+bool Effect::typeIsResourceEffect(int t) {
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count + eset->elements.list.size() + eset->resource_stats.stat_count);
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->resource_stats.effect_count);
 }
 
 bool Effect::typeIsPrimary(int t) {
-	return t >= Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size()) && t < Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size()) + static_cast<int>(eset->primary_stats.list.size());
+	int offset_index = Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count + eset->elements.list.size() + eset->resource_stats.stat_effect_count);
+	return t >= offset_index && t < offset_index + static_cast<int>(eset->primary_stats.list.size());
+}
+
+bool Effect::typeIsEffectResist(int t) {
+	return t >= Effect::TYPE_COUNT + Stats::RESIST_DAMAGE_OVER_TIME && t <= Effect::TYPE_COUNT + Stats::RESIST_MP_STEAL;
 }
 
 int Effect::getStatFromType(int t) {
@@ -210,20 +273,62 @@ int Effect::getStatFromType(int t) {
 }
 
 size_t Effect::getDmgFromType(int t) {
-	return static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT);
+	return static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) / 2;
 }
 
 size_t Effect::getResistFromType(int t) {
 	return static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) - eset->damage_types.count;
 }
 
+size_t Effect::getResourceStatFromType(int t) {
+	size_t offset_index = static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) - eset->damage_types.count - eset->elements.list.size();
+
+	if (offset_index > eset->resource_stats.stat_count) {
+		// effect-only stat (e.g. heal)
+		size_t effect_offset_index = offset_index - eset->resource_stats.stat_count;
+		return effect_offset_index / EngineSettings::ResourceStats::EFFECT_COUNT;
+	}
+	else {
+		return offset_index / EngineSettings::ResourceStats::STAT_COUNT;
+	}
+}
+
+size_t Effect::getResourceStatSubIndexFromType(int t) {
+	size_t offset_index = static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) - eset->damage_types.count - eset->elements.list.size();
+
+	if (offset_index > eset->resource_stats.stat_count) {
+		// effect-only stat (e.g. heal)
+		size_t effect_offset_index = offset_index - eset->resource_stats.stat_count;
+		return EngineSettings::ResourceStats::STAT_COUNT + (effect_offset_index % EngineSettings::ResourceStats::EFFECT_COUNT);
+	}
+	else {
+		return offset_index % EngineSettings::ResourceStats::STAT_COUNT;
+	}
+}
+
 size_t Effect::getPrimaryFromType(int t) {
-	return static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) - eset->damage_types.count - eset->elements.list.size();
+	return static_cast<size_t>(t - Effect::TYPE_COUNT - Stats::COUNT) - eset->damage_types.count - eset->elements.list.size() - eset->resource_stats.stat_effect_count;
+}
+
+bool Effect::isImmunityTypeString(const std::string& type_str) {
+	if (type_str == "immunity") return true;
+	else if (type_str == "immunity_damage") return true;
+	else if (type_str == "immunity_slow") return true;
+	else if (type_str == "immunity_stun") return true;
+	else if (type_str == "immunity_knockback") return true;
+	else if (type_str == "immunity_damage_reflect") return true;
+	else if (type_str == "immunity_stat_debuff") return true;
+	else if (type_str == "immunity_hp_steal") return true;
+	else if (type_str == "immunity_mp_steal") return true;
+	else return false;
 }
 
 EffectManager::EffectManager()
-	: bonus(std::vector<int>(Stats::COUNT + eset->damage_types.count + eset->elements.list.size(), 0))
-	, bonus_primary(std::vector<int>(eset->primary_stats.list.size(), 0))
+	: resource_ot(eset->resource_stats.list.size(), 0)
+	, resource_ot_percent(eset->resource_stats.list.size(), 0)
+	, bonus(Stats::COUNT + eset->damage_types.count + eset->elements.list.size() + eset->resource_stats.stat_effect_count, 0)
+	, bonus_multiplier(bonus.size(), 1)
+	, bonus_primary(eset->primary_stats.list.size(), 0)
 	, triggered_others(false)
 	, triggered_block(false)
 	, triggered_hit(false)
@@ -245,14 +350,6 @@ void EffectManager::clearStatus() {
 	mpot = 0;
 	mpot_percent = 0;
 	speed = 100;
-	immunity_damage = false;
-	immunity_slow = false;
-	immunity_stun = false;
-	immunity_hp_steal = false;
-	immunity_mp_steal = false;
-	immunity_knockback = false;
-	immunity_damage_reflect = false;
-	immunity_stat_debuff = false;
 	stun = false;
 	revive = false;
 	convert = false;
@@ -260,18 +357,27 @@ void EffectManager::clearStatus() {
 	fear = false;
 	knockback_speed = 0;
 
-	for (unsigned i=0; i<Stats::COUNT + eset->damage_types.count + eset->elements.list.size(); i++) {
+	for (size_t i = 0; i < bonus.size(); ++i) {
 		bonus[i] = 0;
+		bonus_multiplier[i] = 1;
 	}
 
-	for (unsigned i=0; i<bonus_primary.size(); i++) {
+	for (size_t i = 0; i < bonus_primary.size(); ++i) {
 		bonus_primary[i] = 0;
 	}
+
+	for (size_t i = 0; i < resource_ot.size(); ++i) {
+		resource_ot[i] = 0;
+		resource_ot_percent[i] = 0;
+	}
 }
 
 void EffectManager::logic() {
 	clearStatus();
 
+	int offset_resource_effects = Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size()) + static_cast<int>(eset->resource_stats.stat_count);
+	int offset_primary_stats = offset_resource_effects + static_cast<int>(eset->resource_stats.stat_count);
+
 	for (size_t i=0; i<effect_list.size(); ++i) {
 		Effect& ei = effect_list[i];
 
@@ -307,33 +413,23 @@ void EffectManager::logic() {
 		// @TYPE attack_speed|Changes attack speed. A magnitude of 100 is 100% speed (aka normal speed).
 		// attack speed is calculated when getAttackSpeed() is called
 
-		// @TYPE immunity|Applies all immunity effects. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY) {
-			immunity_damage = true;
-			immunity_slow = true;
-			immunity_stun = true;
-			immunity_hp_steal = true;
-			immunity_mp_steal = true;
-			immunity_knockback = true;
-			immunity_damage_reflect = true;
-			immunity_stat_debuff = true;
+		// @TYPE resist_all|Applies a bonus to all of the non-elemental resistance stats.
+		else if (ei.type == Effect::RESIST_ALL) {
+			bonus[Stats::RESIST_DAMAGE_OVER_TIME] += ei.magnitude;
+			bonus[Stats::RESIST_SLOW] += ei.magnitude;
+			bonus[Stats::RESIST_STUN] += ei.magnitude;
+			bonus[Stats::RESIST_KNOCKBACK] += ei.magnitude;
+			bonus[Stats::RESIST_DAMAGE_REFLECT] += ei.magnitude;
+			bonus[Stats::RESIST_STAT_DEBUFF] += ei.magnitude;
+			bonus[Stats::RESIST_HP_STEAL] += ei.magnitude;
+			bonus[Stats::RESIST_MP_STEAL] += ei.magnitude;
+
+			for (size_t j = 0; j < eset->resource_stats.list.size(); ++j) {
+				size_t resist_steal_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+				resist_steal_index += (j+1) * EngineSettings::ResourceStats::STAT_RESIST_STEAL;
+				bonus[resist_steal_index] += ei.magnitude;
+			}
 		}
-		// @TYPE immunity_damage|Removes and prevents damage over time. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_DAMAGE) immunity_damage = true;
-		// @TYPE immunity_slow|Removes and prevents slow effects. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_SLOW) immunity_slow = true;
-		// @TYPE immunity_stun|Removes and prevents stun effects. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_STUN) immunity_stun = true;
-		// @TYPE immunity_hp_steal|Prevents HP stealing. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_HP_STEAL) immunity_hp_steal = true;
-		// @TYPE immunity_mp_steal|Prevents MP stealing. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_MP_STEAL) immunity_mp_steal = true;
-		// @TYPE immunity_knockback|Removes and prevents knockback effects. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_KNOCKBACK) immunity_knockback = true;
-		// @TYPE immunity_damage_reflect|Prevents damage reflection. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_DAMAGE_REFLECT) immunity_damage_reflect = true;
-		// @TYPE immunity_stat_debuff|Prevents stat value altering effects that have a magnitude less than 0. Magnitude is ignored.
-		else if (ei.type == Effect::IMMUNITY_STAT_DEBUFF) immunity_stat_debuff = true;
 
 		// @TYPE stun|Can't move or attack. Being attacked breaks stun.
 		else if (ei.type == Effect::STUN) stun = true;
@@ -347,12 +443,26 @@ void EffectManager::logic() {
 		else if (ei.type == Effect::KNOCKBACK) knockback_speed = static_cast<float>(ei.magnitude)/static_cast<float>(settings->max_frames_per_sec);
 
 		// @TYPE ${STAT}|Increases ${STAT}, where ${STAT} is any valid stat_id.
-		else if (ei.type >= Effect::TYPE_COUNT && ei.type < Effect::TYPE_COUNT + Stats::COUNT + static_cast<int>(eset->damage_types.count) + static_cast<int>(eset->elements.list.size())) {
-			bonus[ei.type - Effect::TYPE_COUNT] += ei.magnitude;
+		else if (ei.type >= Effect::TYPE_COUNT && ei.type < offset_resource_effects) {
+			if (ei.is_multiplier)
+				bonus_multiplier[ei.type - Effect::TYPE_COUNT] *= ei.magnitude;
+			else
+				bonus[ei.type - Effect::TYPE_COUNT] += ei.magnitude;
+		}
+		else if (ei.type >= offset_resource_effects && ei.type < offset_primary_stats && do_timed_effect) {
+			size_t resource_index = Effect::getResourceStatFromType(ei.type);
+			size_t resource_sub_index = Effect::getResourceStatSubIndexFromType(ei.type);
+
+			if (resource_sub_index == EngineSettings::ResourceStats::STAT_HEAL) {
+				resource_ot[resource_index] += ei.magnitude;
+			}
+			else if (resource_sub_index == EngineSettings::ResourceStats::STAT_HEAL_PERCENT) {
+				resource_ot_percent[resource_index] += ei.magnitude;
+			}
 		}
 		// @TYPE ${PRIMARYSTAT}|Increases ${PRIMARYSTAT}, where ${PRIMARYSTAT} is any of the primary stats defined in engine/primary_stats.txt. Example: physical
-		else if (ei.type >= Effect::TYPE_COUNT) {
-			bonus_primary[ei.type - Effect::TYPE_COUNT - Stats::COUNT - eset->damage_types.count - eset->elements.list.size()] += ei.magnitude;
+		else if (ei.type >= offset_primary_stats) {
+			bonus_primary[ei.type - offset_primary_stats] += static_cast<int>(ei.magnitude);
 		}
 
 		ei.timer.tick();
@@ -384,39 +494,45 @@ void EffectManager::logic() {
 	}
 }
 
-void EffectManager::addEffect(EffectDef &effect, int duration, int magnitude, int source_type, PowerID power_id) {
-	addEffectInternal(effect, duration, magnitude, source_type, false, power_id);
-}
-
-void EffectManager::addItemEffect(EffectDef &effect, int duration, int magnitude) {
-	// only the hero can wear items, so use Power::SOURCE_TYPE_HERO
-	addEffectInternal(effect, duration, magnitude, Power::SOURCE_TYPE_HERO, true, NO_POWER);
-}
-
-void EffectManager::addEffectInternal(EffectDef &effect, int duration, int magnitude, int source_type, bool item, PowerID power_id) {
+void EffectManager::addEffect(StatBlock* stats, EffectDef &effect, EffectParams &params) {
 	refresh_stats = true;
 
 	// if we're already immune, don't add negative effects
-	if (immunity_damage && (effect.type == Effect::DAMAGE || effect.type == Effect::DAMAGE_PERCENT))
-		return;
-	else if (immunity_slow && effect.type == Effect::SPEED && magnitude < 100)
-		return;
-	else if (immunity_stun && effect.type == Effect::STUN)
-		return;
-	else if (immunity_knockback && effect.type == Effect::KNOCKBACK)
-		return;
-	else if (immunity_stat_debuff && effect.type > Effect::TYPE_COUNT && magnitude < 0)
-		return;
+	if (stats) {
+		if ((effect.type == Effect::DAMAGE || effect.type == Effect::DAMAGE_PERCENT) && Math::percentChanceF(stats->get(Stats::RESIST_DAMAGE_OVER_TIME))) {
+			comb->addString(msg->get("Resist"), stats->pos, CombatText::MSG_MISS);
+			return;
+		}
+		else if (effect.type == Effect::SPEED && params.magnitude < 100 && Math::percentChanceF(stats->get(Stats::RESIST_SLOW))) {
+			comb->addString(msg->get("Resist"), stats->pos, CombatText::MSG_MISS);
+			return;
+		}
+		else if (effect.type == Effect::STUN && Math::percentChanceF(stats->get(Stats::RESIST_STUN))) {
+			comb->addString(msg->get("Resist"), stats->pos, CombatText::MSG_MISS);
+			return;
+		}
+		else if (effect.type == Effect::KNOCKBACK && Math::percentChanceF(stats->get(Stats::RESIST_KNOCKBACK))) {
+			comb->addString(msg->get("Resist"), stats->pos, CombatText::MSG_MISS);
+			return;
+		}
+		else if (effect.type > Effect::TYPE_COUNT && params.magnitude < 0 && Math::percentChanceF(stats->get(Stats::RESIST_STAT_DEBUFF))) {
+			comb->addString(msg->get("Resist"), stats->pos, CombatText::MSG_MISS);
+			return;
+		}
+	}
+	else {
+		Utils::logError("EffectManager: No statblock detected when adding effect");
+	}
 
 	// only allow one knockback effect at a time
 	if (effect.type == Effect::KNOCKBACK && knockback_speed != 0)
 		return;
 
 	bool insert_effect = false;
-	size_t insert_pos;
+	size_t insert_pos = 0;
 	int stacks_applied = 0;
-	int trigger = power_id > 0 ? powers->powers[power_id].passive_trigger : -1;
-	size_t passive_id = (power_id > 0 && powers->powers[power_id].passive) ? power_id : 0;
+	int trigger = params.power_id > 0 ? powers->powers[params.power_id].passive_trigger : -1;
+	size_t passive_id = (params.power_id > 0 && powers->powers[params.power_id].passive) ? params.power_id : 0;
 
 	for (size_t i=effect_list.size(); i>0; i--) {
 		Effect& ei = effect_list[i-1];
@@ -432,11 +548,11 @@ void EffectManager::addEffectInternal(EffectDef &effect, int duration, int magni
 			}
 			else{
 				if (effect.type == Effect::SHIELD && effect.group_stack){
-					ei.magnitude += magnitude;
+					ei.magnitude += params.magnitude;
 
 					if (effect.max_stacks == -1
-						|| (magnitude != 0 && ei.magnitude_max/magnitude < effect.max_stacks)){
-						ei.magnitude_max += magnitude;
+						|| (params.magnitude != 0 && static_cast<int>(ei.magnitude_max/params.magnitude) < effect.max_stacks)){
+						ei.magnitude_max += params.magnitude;
 					}
 
 					if (ei.magnitude > ei.magnitude_max){
@@ -456,17 +572,15 @@ void EffectManager::addEffectInternal(EffectDef &effect, int duration, int magni
 				stacks_applied++;
 			}
 		}
-		// if we're adding an immunity effect, remove all negative effects
-		if (effect.type == Effect::IMMUNITY)
-			clearNegativeEffects();
-		else if (effect.type == Effect::IMMUNITY_DAMAGE)
-			clearNegativeEffects(Effect::IMMUNITY_DAMAGE);
-		else if (effect.type == Effect::IMMUNITY_SLOW)
-			clearNegativeEffects(Effect::IMMUNITY_SLOW);
-		else if (effect.type == Effect::IMMUNITY_STUN)
-			clearNegativeEffects(Effect::IMMUNITY_STUN);
-		else if (effect.type == Effect::IMMUNITY_KNOCKBACK)
-			clearNegativeEffects(Effect::IMMUNITY_KNOCKBACK);
+	}
+
+	// if we're adding a debuff resistance effect, remove applicable negative effects
+	for (int i = Stats::RESIST_DAMAGE_OVER_TIME; i <= Stats::RESIST_STAT_DEBUFF; ++i) {
+		float resist_chance = (stats ? stats->get(static_cast<Stats::STAT>(i)) + params.magnitude : params.magnitude);
+
+		if ((effect.type == Effect::RESIST_ALL || effect.type == Effect::TYPE_COUNT + i) && Math::percentChanceF(resist_chance)) {
+			clearNegativeEffects(Effect::TYPE_COUNT + i);
+		}
 	}
 
 	Effect e;
@@ -485,12 +599,13 @@ void EffectManager::addEffectInternal(EffectDef &effect, int duration, int magni
 		e.loadAnimation(effect.animation);
 	}
 
-	e.timer.setDuration(duration);
-	e.magnitude = e.magnitude_max = magnitude;
-	e.item = item;
+	e.timer.setDuration(params.duration);
+	e.magnitude = e.magnitude_max = params.magnitude;
+	e.is_from_item = params.is_from_item;
+	e.is_multiplier = params.is_multiplier;
 	e.trigger = trigger;
 	e.passive_id = passive_id;
-	e.source_type = source_type;
+	e.source_type = params.source_type;
 
 	if (insert_effect) {
 		if (effect.max_stacks != -1 && stacks_applied >= effect.max_stacks){
@@ -554,25 +669,32 @@ void EffectManager::clearEffects() {
 }
 
 void EffectManager::clearNegativeEffects(int type) {
-	for (size_t i=effect_list.size(); i > 0; i--) {
-		if ((type == -1 || type == Effect::IMMUNITY_DAMAGE) && effect_list[i-1].type == Effect::DAMAGE)
-			removeEffect(i-1);
-		else if ((type == -1 || type == Effect::IMMUNITY_DAMAGE) && effect_list[i-1].type == Effect::DAMAGE_PERCENT)
-			removeEffect(i-1);
-		else if ((type == -1 || type == Effect::IMMUNITY_SLOW) && effect_list[i-1].type == Effect::SPEED && effect_list[i-1].magnitude_max < 100)
-			removeEffect(i-1);
-		else if ((type == -1 || type == Effect::IMMUNITY_STUN) && effect_list[i-1].type == Effect::STUN)
-			removeEffect(i-1);
-		else if ((type == -1 || type == Effect::IMMUNITY_KNOCKBACK) && effect_list[i-1].type == Effect::KNOCKBACK)
-			removeEffect(i-1);
-		else if ((type == -1 || type == Effect::IMMUNITY_STAT_DEBUFF) && effect_list[i-1].type > Effect::TYPE_COUNT && effect_list[i-1].magnitude_max < 0)
-			removeEffect(i-1);
+	bool remove_damage = (type == Effect::RESIST_ALL || type == Effect::TYPE_COUNT + Stats::RESIST_DAMAGE_OVER_TIME);
+	bool remove_slow = (type == Effect::RESIST_ALL || type == Effect::TYPE_COUNT + Stats::RESIST_SLOW);
+	bool remove_stun = (type == Effect::RESIST_ALL || type == Effect::TYPE_COUNT + Stats::RESIST_STUN);
+	bool remove_knockback = (type == Effect::RESIST_ALL || type == Effect::TYPE_COUNT + Stats::RESIST_KNOCKBACK);
+	bool remove_stat_debuff = (type == Effect::RESIST_ALL || type == Effect::TYPE_COUNT + Stats::RESIST_STAT_DEBUFF);
+
+	for (size_t i = effect_list.size(); i > 0; i--) {
+		size_t ei = i-1;
+		if (remove_damage && effect_list[ei].type == Effect::DAMAGE)
+			removeEffect(ei);
+		else if (remove_damage && effect_list[ei].type == Effect::DAMAGE_PERCENT)
+			removeEffect(ei);
+		else if (remove_slow && effect_list[ei].type == Effect::SPEED && effect_list[ei].magnitude_max < 100)
+			removeEffect(ei);
+		else if (remove_stun && effect_list[ei].type == Effect::STUN)
+			removeEffect(ei);
+		else if (remove_knockback && effect_list[ei].type == Effect::KNOCKBACK)
+			removeEffect(ei);
+		else if (remove_stat_debuff && effect_list[ei].type > Effect::TYPE_COUNT && effect_list[ei].magnitude_max < 0)
+			removeEffect(ei);
 	}
 }
 
 void EffectManager::clearItemEffects() {
 	for (size_t i=effect_list.size(); i > 0; i--) {
-		if (effect_list[i-1].item) removeEffect(i-1);
+		if (effect_list[i-1].is_from_item) removeEffect(i-1);
 	}
 }
 
@@ -582,14 +704,14 @@ void EffectManager::clearTriggerEffects(int trigger) {
 	}
 }
 
-int EffectManager::damageShields(int dmg) {
-	int over_dmg = dmg;
+float EffectManager::damageShields(float dmg) {
+	float over_dmg = dmg;
 
 	for (unsigned i=0; i<effect_list.size(); i++) {
 		if (effect_list[i].magnitude_max > 0 && effect_list[i].type == Effect::SHIELD) {
 			effect_list[i].magnitude -= over_dmg;
 			if (effect_list[i].magnitude < 0) {
-				over_dmg = abs(effect_list[i].magnitude);
+				over_dmg = fabsf(effect_list[i].magnitude);
 				effect_list[i].magnitude = 0;
 			}
 			else {
