@@ -29,37 +29,30 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 
 class Animation;
 class Hazard;
+class StatBlock;
 
 class Effect {
 public:
-	static const int TYPE_COUNT = 26;
 	enum {
 		NONE = 0,
-		DAMAGE = 1,
-		DAMAGE_PERCENT = 2,
-		HPOT = 3,
-		HPOT_PERCENT = 4,
-		MPOT = 5,
-		MPOT_PERCENT = 6,
-		SPEED = 7,
-		ATTACK_SPEED = 8,
-		IMMUNITY = 9,
-		IMMUNITY_DAMAGE = 10,
-		IMMUNITY_SLOW = 11,
-		IMMUNITY_STUN = 12,
-		IMMUNITY_HP_STEAL = 13,
-		IMMUNITY_MP_STEAL = 14,
-		IMMUNITY_KNOCKBACK = 15,
-		IMMUNITY_DAMAGE_REFLECT = 16,
-		IMMUNITY_STAT_DEBUFF = 17,
-		STUN = 18,
-		REVIVE = 19,
-		CONVERT = 20,
-		FEAR = 21,
-		DEATH_SENTENCE = 22,
-		SHIELD = 23,
-		HEAL = 24,
-		KNOCKBACK = 25
+		DAMAGE,
+		DAMAGE_PERCENT,
+		HPOT,
+		HPOT_PERCENT,
+		MPOT,
+		MPOT_PERCENT,
+		SPEED,
+		ATTACK_SPEED,
+		RESIST_ALL,
+		STUN,
+		REVIVE,
+		CONVERT,
+		FEAR,
+		DEATH_SENTENCE,
+		SHIELD,
+		HEAL,
+		KNOCKBACK,
+		TYPE_COUNT
 	};
 
 	Effect();
@@ -75,22 +68,29 @@ public:
 	static bool typeIsDmgMin(int t);
 	static bool typeIsDmgMax(int t);
 	static bool typeIsResist(int t);
+	static bool typeIsResourceStat(int t);
+	static bool typeIsResourceEffect(int t);
 	static bool typeIsPrimary(int t);
+	static bool typeIsEffectResist(int t);
 	static int getStatFromType(int t);
 	static size_t getDmgFromType(int t);
 	static size_t getResistFromType(int t);
+	static size_t getResourceStatFromType(int t);
+	static size_t getResourceStatSubIndexFromType(int t);
 	static size_t getPrimaryFromType(int t);
 
+	static bool isImmunityTypeString(const std::string& type_str); // handling of deprecated types
+
 	std::string id;
 	std::string name;
 	int icon;
 	Timer timer;
 	int type;
-	int magnitude;
-	int magnitude_max;
+	float magnitude;
+	float magnitude_max;
 	std::string animation_name;
 	Animation* animation;
-	bool item;
+	bool is_from_item;
 	int trigger;
 	bool render_above;
 	size_t passive_id;
@@ -99,6 +99,7 @@ public:
 	uint32_t color_mod;
 	uint8_t alpha_mod;
 	std::string attack_speed_anim;
+	bool is_multiplier;
 };
 
 class EffectDef {
@@ -117,28 +118,40 @@ public:
 	Color color_mod;
 	uint8_t alpha_mod;
 	std::string attack_speed_anim;
+
+	bool is_immunity_type; // handling of deprecated types
+};
+
+class EffectParams {
+public:
+	EffectParams();
+
+	bool is_from_item;
+	bool is_multiplier;
+	int duration;
+	int source_type;
+	float magnitude;
+	PowerID power_id;
 };
 
 class EffectManager {
 private:
 	void removeEffect(size_t id);
 	void clearStatus();
-	void addEffectInternal(EffectDef &effect, int duration, int magnitude, int source_type, bool item, PowerID power_id);
 
 public:
 	EffectManager();
 	~EffectManager();
 	void logic();
-	void addEffect(EffectDef &effect, int duration, int magnitude, int source_type, PowerID power_id);
-	void addItemEffect(EffectDef &effect, int duration, int magnitude);
+	void addEffect(StatBlock* stats, EffectDef &effect, EffectParams &params);
 	void removeEffectType(const int type);
 	void removeEffectPassive(size_t id);
 	void removeEffectID(const std::vector< std::pair<std::string, int> >& remove_effects);
 	void clearEffects();
-	void clearNegativeEffects(int type = -1);
+	void clearNegativeEffects(int type);
 	void clearItemEffects();
 	void clearTriggerEffects(int trigger);
-	int damageShields(int dmg);
+	float damageShields(float dmg);
 	bool isDebuffed();
 	void getCurrentColor(Color& color_mod);
 	void getCurrentAlpha(uint8_t& alpha_mod);
@@ -148,21 +161,17 @@ public:
 
 	std::vector<Effect> effect_list;
 
-	int damage;
-	int damage_percent;
-	int hpot;
-	int hpot_percent;
-	int mpot;
-	int mpot_percent;
+	// TODO rename these to *_per_second; maybe make into array?
+	float damage;
+	float damage_percent;
+	float hpot;
+	float hpot_percent;
+	float mpot;
+	float mpot_percent;
+	std::vector<float> resource_ot;
+	std::vector<float> resource_ot_percent;
+
 	float speed;
-	bool immunity_damage;
-	bool immunity_slow;
-	bool immunity_stun;
-	bool immunity_hp_steal;
-	bool immunity_mp_steal;
-	bool immunity_knockback;
-	bool immunity_damage_reflect;
-	bool immunity_stat_debuff;
 	bool stun;
 	bool revive;
 	bool convert;
@@ -170,10 +179,11 @@ public:
 	bool fear;
 	float knockback_speed;
 
-	std::vector<int> bonus;
-	std::vector<int> bonus_resist;
+	std::vector<float> bonus;
+	std::vector<float> bonus_multiplier;
 	std::vector<int> bonus_primary;
 
+	// TODO convert to array
 	bool triggered_others;
 	bool triggered_block;
 	bool triggered_hit;
