@@ -28,6 +28,7 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "Settings.h"
 #include "SharedResources.h"
 #include "Utils.h"
+#include "UtilsMath.h"
 #include "UtilsParsing.h"
 
 void EngineSettings::load() {
@@ -46,6 +47,8 @@ void EngineSettings::load() {
 	tileset.load();
 	widgets.load();
 	xp.load();
+	number_format.load();
+	resource_stats.load();
 }
 
 void EngineSettings::Misc::load() {
@@ -77,6 +80,8 @@ void EngineSettings::Misc::load() {
 	combat_aborts_npc_interact = true;
 	fogofwar = 0;
 	save_fogofwar = false;
+	mouse_move_deadzone_moving = 0.25f;
+	mouse_move_deadzone_not_moving = 0.75f;
 
 	FileParser infile;
 	// @CLASS EngineSettings: Misc|Description of engine/misc.txt
@@ -103,9 +108,9 @@ void EngineSettings::Misc::load() {
 			// @ATTR sound_falloff|int|The maximum radius in tiles that any single sound is audible.
 			else if (infile.key == "sound_falloff")
 				sound_falloff = Parse::toInt(infile.val);
-			// @ATTR party_exp_percentage|int|The percentage of XP given to allies.
+			// @ATTR party_exp_percentage|float|The percentage of XP given to allies.
 			else if (infile.key == "party_exp_percentage")
-				party_exp_percentage = Parse::toInt(infile.val);
+				party_exp_percentage = Parse::toFloat(infile.val);
 			// @ATTR enable_ally_collision|bool|Allows allies to block the player's path.
 			else if (infile.key == "enable_ally_collision")
 				enable_ally_collision = Parse::toBool(infile.val);
@@ -179,6 +184,12 @@ void EngineSettings::Misc::load() {
 			else if (infile.key == "save_fogofwar")
 				save_fogofwar = Parse::toBool(infile.val);
 
+			// @ATTR mouse_move_deadzone|float, float : Deadzone while moving, Deadzone while not moving|Adds a deadzone circle around the player to prevent erratic behavior when using mouse movement. Ideally, the deadzone when moving should be less than the deadzone when not moving. Defaults are 0.25 and 0.75 respectively.
+			else if (infile.key == "mouse_move_deadzone") {
+				mouse_move_deadzone_moving = Parse::popFirstFloat(infile.val);
+				mouse_move_deadzone_not_moving = Parse::popFirstFloat(infile.val);
+			}
+
 			else infile.error("EngineSettings: '%s' is not a valid key.", infile.key.c_str());
 		}
 		infile.close();
@@ -313,53 +324,67 @@ void EngineSettings::Combat::load() {
 	max_crit_damage = 200;
 	min_overhit_damage = 100;
 	max_overhit_damage = 100;
+	resource_round_method = EngineSettings::Combat::RESOURCE_ROUND_METHOD_ROUND;
 
 	FileParser infile;
 	// @CLASS EngineSettings: Combat|Description of engine/combat.txt
 	if (infile.open("engine/combat.txt", FileParser::MOD_FILE, FileParser::ERROR_NORMAL)) {
 		while (infile.next()) {
 			if (infile.key == "absorb_percent") {
-				// @ATTR absorb_percent|int, int : Minimum, Maximum|Limits the percentage of damage that can be absorbed. A max value less than 100 will ensure that the target always takes at least 1 damage from non-elemental attacks.
-				min_absorb = Parse::popFirstInt(infile.val);
-				max_absorb = Parse::popFirstInt(infile.val);
+				// @ATTR absorb_percent|float, float : Minimum, Maximum|Limits the percentage of damage that can be absorbed. A max value less than 100 will ensure that the target always takes at least 1 damage from non-elemental attacks.
+				min_absorb = Parse::popFirstFloat(infile.val);
+				max_absorb = Parse::popFirstFloat(infile.val);
 				max_absorb = std::max(max_absorb, min_absorb);
 			}
 			else if (infile.key == "resist_percent") {
-				// @ATTR resist_percent|int, int : Minimum, Maximum|Limits the percentage of damage that can be resisted. A max value less than 100 will ensure that the target always takes at least 1 damage from elemental attacks.
-				min_resist = Parse::popFirstInt(infile.val);
-				max_resist = Parse::popFirstInt(infile.val);
+				// @ATTR resist_percent|float, float : Minimum, Maximum|Limits the percentage of damage that can be resisted. A max value less than 100 will ensure that the target always takes at least 1 damage from elemental attacks.
+				min_resist = Parse::popFirstFloat(infile.val);
+				max_resist = Parse::popFirstFloat(infile.val);
 				max_resist = std::max(max_resist, min_resist);
 			}
 			else if (infile.key == "block_percent") {
-				// @ATTR block_percent|int, int : Minimum, Maximum|Limits the percentage of damage that can be absorbed when the target is in the 'block' animation state. A max value less than 100 will ensure that the target always takes at least 1 damage from non-elemental attacks.
-				min_block = Parse::popFirstInt(infile.val);
-				max_block = Parse::popFirstInt(infile.val);
+				// @ATTR block_percent|float, float : Minimum, Maximum|Limits the percentage of damage that can be absorbed when the target is in the 'block' animation state. A max value less than 100 will ensure that the target always takes at least 1 damage from non-elemental attacks.
+				min_block = Parse::popFirstFloat(infile.val);
+				max_block = Parse::popFirstFloat(infile.val);
 				max_block = std::max(max_block, min_block);
 			}
 			else if (infile.key == "avoidance_percent") {
-				// @ATTR avoidance_percent|int, int : Minimum, Maximum|Limits the percentage chance that damage will be avoided.
-				min_avoidance = Parse::popFirstInt(infile.val);
-				max_avoidance = Parse::popFirstInt(infile.val);
+				// @ATTR avoidance_percent|float, float : Minimum, Maximum|Limits the percentage chance that damage will be avoided.
+				min_avoidance = Parse::popFirstFloat(infile.val);
+				max_avoidance = Parse::popFirstFloat(infile.val);
 				max_avoidance = std::max(max_avoidance, min_avoidance);
 			}
-			// @ATTR miss_damage_percent|int, int : Minimum, Maximum|The percentage of damage dealt when a miss occurs.
+			// @ATTR miss_damage_percent|float, float : Minimum, Maximum|The percentage of damage dealt when a miss occurs.
 			else if (infile.key == "miss_damage_percent") {
-				min_miss_damage = Parse::popFirstInt(infile.val);
-				max_miss_damage = Parse::popFirstInt(infile.val);
+				min_miss_damage = Parse::popFirstFloat(infile.val);
+				max_miss_damage = Parse::popFirstFloat(infile.val);
 				max_miss_damage = std::max(max_miss_damage, min_miss_damage);
 			}
-			// @ATTR crit_damage_percent|int, int : Minimum, Maximum|The percentage of damage dealt when a critical hit occurs.
+			// @ATTR crit_damage_percent|float, float : Minimum, Maximum|The percentage of damage dealt when a critical hit occurs.
 			else if (infile.key == "crit_damage_percent") {
-				min_crit_damage = Parse::popFirstInt(infile.val);
-				max_crit_damage = Parse::popFirstInt(infile.val);
+				min_crit_damage = Parse::popFirstFloat(infile.val);
+				max_crit_damage = Parse::popFirstFloat(infile.val);
 				max_crit_damage = std::max(max_crit_damage, min_crit_damage);
 			}
-			// @ATTR overhit_damage_percent|int, int : Minimum, Maximum|The percentage of damage dealt when an overhit occurs.
+			// @ATTR overhit_damage_percent|float, float : Minimum, Maximum|The percentage of damage dealt when an overhit occurs.
 			else if (infile.key == "overhit_damage_percent") {
-				min_overhit_damage = Parse::popFirstInt(infile.val);
-				max_overhit_damage = Parse::popFirstInt(infile.val);
+				min_overhit_damage = Parse::popFirstFloat(infile.val);
+				max_overhit_damage = Parse::popFirstFloat(infile.val);
 				max_overhit_damage = std::max(max_overhit_damage, min_overhit_damage);
 			}
+			// @ATTR resource_round_method|['none', 'round', 'floor', 'ceil']|Rounds the numbers for most combat events that affect HP/MP. For example: damage taken, HP healed, MP consumed. Defaults to 'round'.
+			else if (infile.key == "resource_round_method") {
+				if (infile.val == "none")
+					resource_round_method = EngineSettings::Combat::RESOURCE_ROUND_METHOD_NONE;
+				else if (infile.val == "round")
+					resource_round_method = EngineSettings::Combat::RESOURCE_ROUND_METHOD_ROUND;
+				else if (infile.val == "floor")
+					resource_round_method = EngineSettings::Combat::RESOURCE_ROUND_METHOD_FLOOR;
+				else if (infile.val == "ceil")
+					resource_round_method = EngineSettings::Combat::RESOURCE_ROUND_METHOD_CEIL;
+				else
+					infile.error("EngineSettings: '%s' is not a valid resource rounding method.", infile.val.c_str());
+			}
 
 			else infile.error("EngineSettings: '%s' is not a valid key.", infile.key.c_str());
 		}
@@ -367,6 +392,22 @@ void EngineSettings::Combat::load() {
 	}
 }
 
+float EngineSettings::Combat::resourceRound(const float resource_val) {
+	if (resource_round_method == EngineSettings::Combat::RESOURCE_ROUND_METHOD_ROUND) {
+		return roundf(resource_val);
+	}
+	else if (resource_round_method == EngineSettings::Combat::RESOURCE_ROUND_METHOD_FLOOR) {
+		return floorf(resource_val);
+	}
+	else if (resource_round_method == EngineSettings::Combat::RESOURCE_ROUND_METHOD_CEIL) {
+		return ceilf(resource_val);
+	}
+	else {
+		// EngineSettings::Combat::RESOURCE_ROUND_METHOD_NONE
+		return resource_val;
+	}
+}
+
 void EngineSettings::Elements::load() {
 	// reset to defaults
 	list.clear();
@@ -686,12 +727,12 @@ void EngineSettings::DeathPenalty::load() {
 			if (infile.key == "enable") enabled = Parse::toBool(infile.val);
 			// @ATTR permadeath|bool|Force permadeath for all new saves.
 			else if (infile.key == "permadeath") permadeath = Parse::toBool(infile.val);
-			// @ATTR currency|int|Remove this percentage of currency.
-			else if (infile.key == "currency") currency = Parse::toInt(infile.val);
-			// @ATTR xp_total|int|Remove this percentage of total XP.
-			else if (infile.key == "xp_total") xp = Parse::toInt(infile.val);
-			// @ATTR xp_current_level|int|Remove this percentage of the XP gained since the last level.
-			else if (infile.key == "xp_current_level") xp_current = Parse::toInt(infile.val);
+			// @ATTR currency|float|Remove this percentage of currency.
+			else if (infile.key == "currency") currency = Parse::toFloat(infile.val);
+			// @ATTR xp_total|float|Remove this percentage of total XP.
+			else if (infile.key == "xp_total") xp = Parse::toFloat(infile.val);
+			// @ATTR xp_current_level|float|Remove this percentage of the XP gained since the last level.
+			else if (infile.key == "xp_current_level") xp_current = Parse::toFloat(infile.val);
 			// @ATTR random_item|bool|Removes a random item from the player's inventory.
 			else if (infile.key == "random_item") item = Parse::toBool(infile.val);
 
@@ -1039,3 +1080,133 @@ int EngineSettings::XPTable::getLevelFromXP(unsigned long level_xp) {
 
 	return level;
 }
+
+void EngineSettings::NumberFormat::load() {
+	// reset to defaults
+	player_statbar = 0;
+	enemy_statbar = 0;
+	combat_text = 0;
+	character_menu = 2;
+	item_tooltips = 2;
+	power_tooltips = 2;
+	durations = 1;
+	death_penalty = 2;
+
+	FileParser infile;
+	// @CLASS EngineSettings: Number Format|Description of engine/number_format.txt
+	if (infile.open("engine/number_format.txt", FileParser::MOD_FILE, FileParser::ERROR_NORMAL)) {
+		while (infile.next()) {
+			// @ATTR player_statbar|int|Number of digits after the decimal place to display for values in the player's statbars (HP/MP).
+			if (infile.key == "player_statbar")
+				player_statbar = std::max(0, Parse::toInt(infile.val));
+			// @ATTR enemy_statbar|int|Number of digits after the decimal place to display for values in the enemy HP statbar.
+			else if (infile.key == "enemy_statbar")
+				enemy_statbar = std::max(0, Parse::toInt(infile.val));
+			// @ATTR combat_text|int|Number of digits after the decimal place to display for values in combat text.
+			else if (infile.key == "combat_text")
+				combat_text = std::max(0, Parse::toInt(infile.val));
+			// @ATTR character_menu|int|Number of digits after the decimal place to display for values in the 'Character' menu.
+			else if (infile.key == "character_menu")
+				character_menu = std::max(0, Parse::toInt(infile.val));
+			// @ATTR item_tooltips|int|Number of digits after the decimal place to display for values in item tooltips.
+			else if (infile.key == "item_tooltips")
+				item_tooltips = std::max(0, Parse::toInt(infile.val));
+			// @ATTR power_tooltips|int|Number of digits after the decimal place to display for values in power tooltips (except durations).
+			else if (infile.key == "power_tooltips")
+				power_tooltips = std::max(0, Parse::toInt(infile.val));
+			// @ATTR durations|int|Number of digits after the decimal place to display for durations.
+			else if (infile.key == "durations")
+				durations = std::max(0, Parse::toInt(infile.val));
+			// @ATTR death_penalty|int|Number of digits after the decimal place to display for death penalty messages.
+			else if (infile.key == "death_penalty")
+				death_penalty = std::max(0, Parse::toInt(infile.val));
+
+			else
+				infile.error("EngineSettings: '%s' is not a valid key.", infile.key.c_str());
+		}
+		infile.close();
+	}
+
+}
+
+void EngineSettings::ResourceStats::load() {
+	// reset to defaults
+	list.clear();
+	stat_count = 0;
+	effect_count = 0;
+	stat_effect_count = 0;
+
+	FileParser infile;
+	// @CLASS EngineSettings: Resource Stats|Description of engine/resource_stats.txt
+	if (infile.open("engine/resource_stats.txt", FileParser::MOD_FILE, FileParser::ERROR_NORMAL)) {
+		while (infile.next()) {
+			if (infile.new_section) {
+				if (infile.section == "resource_stat") {
+					list.resize(list.size()+1);
+
+					list.back().ids.resize(EngineSettings::ResourceStats::STAT_EFFECT_COUNT);
+					list.back().text.resize(EngineSettings::ResourceStats::STAT_COUNT);
+					list.back().text_desc.resize(EngineSettings::ResourceStats::STAT_COUNT);
+				}
+			}
+
+			if (list.empty() || infile.section != "resource_stat")
+				continue;
+
+			// @ATTR resource_stat.stat_base|string|The identifier used for the base ("Max") stat.
+			if (infile.key == "stat_base") list.back().ids[EngineSettings::ResourceStats::STAT_BASE] = infile.val;
+			// @ATTR resource_stat.stat_regen|string|The identifier used for the regeneration stat.
+			else if (infile.key == "stat_regen") list.back().ids[EngineSettings::ResourceStats::STAT_REGEN] = infile.val;
+			// @ATTR resource_stat.stat_steal|string|The identifier used for steal stat.
+			else if (infile.key == "stat_steal") list.back().ids[EngineSettings::ResourceStats::STAT_STEAL] = infile.val;
+			// @ATTR resource_stat.stat_resist_steal|string|The identifier used for the resistance to steal stat.
+			else if (infile.key == "stat_resist_steal") list.back().ids[EngineSettings::ResourceStats::STAT_RESIST_STEAL] = infile.val;
+			// @ATTR resource_stat.stat_heal|string|The identifier used for heal-over-time effects.
+			else if (infile.key == "stat_heal") list.back().ids[EngineSettings::ResourceStats::STAT_HEAL] = infile.val;
+			// @ATTR resource_stat.stat_heal_percent|string|The identifier used for percentage-based heal-over-time effects.
+			else if (infile.key == "stat_heal_percent") list.back().ids[EngineSettings::ResourceStats::STAT_HEAL_PERCENT] = infile.val;
+
+			// @ATTR resource_stat.menu_filename|filename|The MenuStatBar definition file to use for displaying this stat.
+			else if (infile.key == "menu_filename") list.back().menu_filename = infile.val;
+
+			// @ATTR resource_stat.text_base|string|The printed name of the base ("Max") stat as seen in-game.
+			else if (infile.key == "text_base") list.back().text[EngineSettings::ResourceStats::STAT_BASE] = msg->get(infile.val);
+			// @ATTR resource_stat.text_base_desc|string|The printed description of the base ("Max") stat as seen in-game.
+			else if (infile.key == "text_base_desc") list.back().text_desc[EngineSettings::ResourceStats::STAT_BASE] = msg->get(infile.val);
+
+			// @ATTR resource_stat.text_regen|string|The name of the regeneration stat as seen in-game.
+			else if (infile.key == "text_regen") list.back().text[EngineSettings::ResourceStats::STAT_REGEN] = msg->get(infile.val);
+			// @ATTR resource_stat.text_regen_desc|string|The description of the regeneration stat as seen in-game.
+			else if (infile.key == "text_regen_desc") list.back().text_desc[EngineSettings::ResourceStats::STAT_REGEN] = msg->get(infile.val);
+
+			// @ATTR resource_stat.text_steal|string|The name of the steal stat as seen in-game.
+			else if (infile.key == "text_steal") list.back().text[EngineSettings::ResourceStats::STAT_STEAL] = msg->get(infile.val);
+			// @ATTR resource_stat.text_steal_desc|string|The description of the steal stat as seen in-game.
+			else if (infile.key == "text_steal_desc") list.back().text_desc[EngineSettings::ResourceStats::STAT_STEAL] = msg->get(infile.val);
+
+			// @ATTR resource_stat.text_resist_steal|string|The name of the resistance to steal stat as seen in-game.
+			else if (infile.key == "text_resist_steal") list.back().text[EngineSettings::ResourceStats::STAT_RESIST_STEAL] = msg->get(infile.val);
+			// @ATTR resource_stat.text_resist_steal_desc|string|The description of the resistance to steal stat as seen in-game.
+			else if (infile.key == "text_resist_steal_desc") list.back().text_desc[EngineSettings::ResourceStats::STAT_RESIST_STEAL] = msg->get(infile.val);
+
+			// @ATTR resource_stat.text_combat_heal|string|The name of the stat in combat text as seen during heal-over-time.
+			else if (infile.key == "text_combat_heal") list.back().text_combat_heal = msg->get(infile.val);
+			// @ATTR resource_stat.text_log_restore|string|The text in the player's log when this stat is restored via EventManager's 'restore' property.
+			else if (infile.key == "text_log_restore") list.back().text_log_restore = msg->get(infile.val);
+			// @ATTR resource_stat.text_log_low|string|The text in the player's log when trying to use a Power that requires more than the available amount of this resource.
+			else if (infile.key == "text_log_low") list.back().text_log_low = msg->get(infile.val);
+			// @ATTR resource_stat.text_tooltip_heal|string|The text in Power tooltips used for heal-over-time Effects.
+			else if (infile.key == "text_tooltip_heal") list.back().text_tooltip_heal = msg->get(infile.val);
+			// @ATTR resource_stat.text_tooltip_cost|string|The text in Power tooltips that describes the casting cost of this resource.
+			else if (infile.key == "text_tooltip_cost") list.back().text_tooltip_cost = msg->get(infile.val);
+
+			else infile.error("EngineSettings: '%s' is not a valid key.", infile.key.c_str());
+		}
+		infile.close();
+	}
+
+	stat_count = list.size() * EngineSettings::ResourceStats::STAT_COUNT; // base, regen, steal, resist_steal
+	effect_count = list.size() * (EngineSettings::ResourceStats::STAT_EFFECT_COUNT - EngineSettings::ResourceStats::STAT_COUNT); // heal, heal_percent
+	stat_effect_count = stat_count + effect_count;
+}
+
