@@ -49,7 +49,7 @@ public:
 		std::string window_title;
 		std::string save_prefix;
 		int sound_falloff;
-		int party_exp_percentage;
+		float party_exp_percentage;
 		bool enable_ally_collision;
 		bool enable_ally_collision_ai;
 		ItemID currency_id;
@@ -68,6 +68,8 @@ public:
 		bool combat_aborts_npc_interact;
 		unsigned short fogofwar;
 		bool save_fogofwar;
+		float mouse_move_deadzone_moving;
+		float mouse_move_deadzone_not_moving;
 	};
 
 	class Resolutions {
@@ -94,21 +96,30 @@ public:
 	class Combat {
 	public:
 		void load();
+		float resourceRound(const float resource_val);
 
-		int min_absorb;
-		int max_absorb;
-		int min_resist;
-		int max_resist;
-		int min_block;
-		int max_block;
-		int min_avoidance;
-		int max_avoidance;
-		int min_miss_damage;
-		int max_miss_damage;
-		int min_crit_damage;
-		int max_crit_damage;
-		int min_overhit_damage;
-		int max_overhit_damage;
+		enum {
+			RESOURCE_ROUND_METHOD_NONE = 0,
+			RESOURCE_ROUND_METHOD_ROUND,
+			RESOURCE_ROUND_METHOD_FLOOR,
+			RESOURCE_ROUND_METHOD_CEIL
+		};
+
+		float min_absorb;
+		float max_absorb;
+		float min_resist;
+		float max_resist;
+		float min_block;
+		float max_block;
+		float min_avoidance;
+		float max_avoidance;
+		float min_miss_damage;
+		float max_miss_damage;
+		float min_crit_damage;
+		float max_crit_damage;
+		float min_overhit_damage;
+		float max_overhit_damage;
+		unsigned short resource_round_method;
 	};
 
 	class Elements {
@@ -203,9 +214,9 @@ public:
 
 		bool enabled;
 		bool permadeath;
-		int currency;
-		int xp;
-		int xp_current;
+		float currency;
+		float xp;
+		float xp_current;
 		bool item;
 	};
 
@@ -287,6 +298,61 @@ public:
 		std::vector<unsigned long> xp_table;
 	};
 
+	class NumberFormat {
+	public:
+		void load();
+
+		int player_statbar;
+		int enemy_statbar;
+		int combat_text;
+		int character_menu;
+		int item_tooltips;
+		int power_tooltips;
+		int durations;
+		int death_penalty;
+	};
+
+	class ResourceStats {
+	public:
+		enum {
+			// statblock & effect
+			STAT_BASE = 0,
+			STAT_REGEN,
+			STAT_STEAL,
+			STAT_RESIST_STEAL,
+
+			// effect only
+			STAT_HEAL,
+			STAT_HEAL_PERCENT,
+
+			STAT_EFFECT_COUNT
+		};
+		static const size_t STAT_COUNT = STAT_HEAL;
+		static const size_t EFFECT_COUNT = STAT_EFFECT_COUNT - STAT_COUNT;
+
+		class ResourceStat {
+		public:
+			std::vector<std::string> ids;
+			std::vector<std::string> text;
+			std::vector<std::string> text_desc;
+
+			std::string menu_filename;
+
+			std::string text_combat_heal;
+			std::string text_log_restore;
+			std::string text_log_low;
+			std::string text_tooltip_heal;
+			std::string text_tooltip_cost;
+		};
+
+		void load();
+
+		std::vector<ResourceStat> list;
+		size_t stat_count;
+		size_t effect_count;
+		size_t stat_effect_count;
+	};
+
 	Misc misc;
 	Resolutions resolutions;
 	Gameplay gameplay;
@@ -302,6 +368,8 @@ public:
 	Tileset tileset;
 	Widgets widgets;
 	XPTable xp;
+	NumberFormat number_format;
+	ResourceStats resource_stats;
 };
 
 #endif // ENGINESETTINGS_H
