@@ -360,10 +360,7 @@ bool Entity::takeHit(Hazard &h) {
 	// exit if it was a beacon (to prevent stats.targeted from being set)
 	if (powers->powers[h.power_index].beacon) return false;
 
-	// prepare the combat text
-	CombatText *combat_text = comb;
-
-	if (h.power->type == Power::TYPE_MISSILE && Math::percentChance(stats.get(Stats::REFLECT))) {
+	if (h.power->type == Power::TYPE_MISSILE && Math::percentChanceF(stats.get(Stats::REFLECT))) {
 		// reflect the missile 180 degrees
 		h.setAngle(h.angle+static_cast<float>(M_PI));
 
@@ -385,7 +382,7 @@ bool Entity::takeHit(Hazard &h) {
 	}
 
 	// if it's a miss, do nothing
-	int accuracy = h.accuracy;
+	float accuracy = h.accuracy;
 	if(powers->powers[h.power_index].mod_accuracy_mode == Power::STAT_MODIFIER_MODE_MULTIPLY)
 		accuracy = (accuracy * powers->powers[h.power_index].mod_accuracy_value) / 100;
 	else if(powers->powers[h.power_index].mod_accuracy_mode == Power::STAT_MODIFIER_MODE_ADD)
@@ -393,35 +390,35 @@ bool Entity::takeHit(Hazard &h) {
 	else if(powers->powers[h.power_index].mod_accuracy_mode == Power::STAT_MODIFIER_MODE_ABSOLUTE)
 		accuracy = powers->powers[h.power_index].mod_accuracy_value;
 
-	int avoidance = 0;
+	float avoidance = 0;
 	if(!powers->powers[h.power_index].trait_avoidance_ignore) {
 		avoidance = stats.get(Stats::AVOIDANCE);
 	}
 
-	int true_avoidance = 100 - (accuracy - avoidance);
-	bool is_overhit = (true_avoidance < 0 && !h.src_stats->perfect_accuracy) ? Math::percentChance(abs(true_avoidance)) : false;
+	float true_avoidance = 100 - (accuracy - avoidance);
+	bool is_overhit = (true_avoidance < 0 && !h.src_stats->perfect_accuracy) ? Math::percentChanceF(fabsf(true_avoidance)) : false;
 	true_avoidance = std::min(std::max(true_avoidance, eset->combat.min_avoidance), eset->combat.max_avoidance);
 
 	bool missed = false;
-	if (!h.src_stats->perfect_accuracy && Math::percentChance(true_avoidance)) {
+	if (!h.src_stats->perfect_accuracy && Math::percentChanceF(true_avoidance)) {
 		missed = true;
 	}
 
 	// calculate base damage
-	int dmg = Math::randBetween(h.dmg_min, h.dmg_max);
+	float dmg = Math::randBetweenF(h.dmg_min, h.dmg_max);
 
 	if(powers->powers[h.power_index].mod_damage_mode == Power::STAT_MODIFIER_MODE_MULTIPLY)
 		dmg = dmg * powers->powers[h.power_index].mod_damage_value_min / 100;
 	else if(powers->powers[h.power_index].mod_damage_mode == Power::STAT_MODIFIER_MODE_ADD)
 		dmg += powers->powers[h.power_index].mod_damage_value_min;
 	else if(powers->powers[h.power_index].mod_damage_mode == Power::STAT_MODIFIER_MODE_ABSOLUTE)
-		dmg = Math::randBetween(powers->powers[h.power_index].mod_damage_value_min, powers->powers[h.power_index].mod_damage_value_max);
+		dmg = Math::randBetweenF(powers->powers[h.power_index].mod_damage_value_min, powers->powers[h.power_index].mod_damage_value_max);
 
 	// apply elemental resistance
 	if (h.power->trait_elemental >= 0 && static_cast<size_t>(h.power->trait_elemental) < eset->elements.list.size()) {
 		size_t i = h.power->trait_elemental;
 
-		int resist = stats.getResist(i);
+		float resist = stats.getResist(i);
 		// resist values < 0 are weakness, and are unaffected by min/max resist setting
 		if (resist >= 0) {
 			if (resist < eset->combat.min_resist)
@@ -435,20 +432,20 @@ bool Entity::takeHit(Hazard &h) {
 
 	if (!h.power->trait_armor_penetration) { // armor penetration ignores all absorption
 		// subtract absorption from armor
-		int absorption = Math::randBetween(stats.get(Stats::ABS_MIN), stats.get(Stats::ABS_MAX));
+		float absorption = Math::randBetweenF(stats.get(Stats::ABS_MIN), stats.get(Stats::ABS_MAX));
 
 		if (absorption > 0 && dmg > 0) {
-			int abs = absorption;
+			float base_absorb = absorption;
 			if (stats.effects.triggered_block) {
-				if ((abs*100)/dmg < eset->combat.min_block)
+				if ((base_absorb*100)/dmg < eset->combat.min_block)
 					absorption = (dmg * eset->combat.min_block) /100;
-				if ((abs*100)/dmg > eset->combat.max_block)
+				if ((base_absorb*100)/dmg > eset->combat.max_block)
 					absorption = (dmg * eset->combat.max_block) /100;
 				}
 			else {
-				if ((abs*100)/dmg < eset->combat.min_absorb)
+				if ((base_absorb*100)/dmg < eset->combat.min_absorb)
 					absorption = (dmg * eset->combat.min_absorb) /100;
-				if ((abs*100)/dmg > eset->combat.max_absorb)
+				if ((base_absorb*100)/dmg > eset->combat.max_absorb)
 					absorption = (dmg * eset->combat.max_absorb) /100;
 			}
 
@@ -478,7 +475,7 @@ bool Entity::takeHit(Hazard &h) {
 	}
 
 	// check for crits
-	int true_crit_chance = h.crit_chance;
+	float true_crit_chance = h.crit_chance;
 
 	if(powers->powers[h.power_index].mod_crit_mode == Power::STAT_MODIFIER_MODE_MULTIPLY)
 		true_crit_chance = true_crit_chance * powers->powers[h.power_index].mod_crit_value / 100;
@@ -490,42 +487,44 @@ bool Entity::takeHit(Hazard &h) {
 	if (stats.effects.stun || stats.effects.speed < 100)
 		true_crit_chance += h.power->trait_crits_impaired;
 
-	bool crit = Math::percentChance(true_crit_chance);
+	bool crit = Math::percentChanceF(true_crit_chance);
 	if (crit) {
 		// default is dmg * 2
-		dmg = (dmg * Math::randBetween(eset->combat.min_crit_damage, eset->combat.max_crit_damage)) / 100;
+		dmg = (dmg * Math::randBetweenF(eset->combat.min_crit_damage, eset->combat.max_crit_damage)) / 100;
 		if(!stats.hero)
 			mapr->cam.shake_timer.setDuration(settings->max_frames_per_sec/2);
 	}
 	else if (is_overhit) {
-		dmg = (dmg * Math::randBetween(eset->combat.min_overhit_damage, eset->combat.max_overhit_damage)) / 100;
+		dmg = (dmg * Math::randBetweenF(eset->combat.min_overhit_damage, eset->combat.max_overhit_damage)) / 100;
 		// Should we use shakycam for overhits?
 	}
 
 	// misses cause reduced damage
 	if (missed) {
-		dmg = (dmg * Math::randBetween(eset->combat.min_miss_damage, eset->combat.max_miss_damage)) / 100;
+		dmg = (dmg * Math::randBetweenF(eset->combat.min_miss_damage, eset->combat.max_miss_damage)) / 100;
 	}
 
+	dmg = eset->combat.resourceRound(dmg);
+
 	if (!powers->powers[h.power_index].ignore_zero_damage) {
 		if (dmg == 0) {
-			combat_text->addString(msg->get("miss"), stats.pos, CombatText::MSG_MISS);
+			comb->addString(msg->get("miss"), stats.pos, CombatText::MSG_MISS);
 			return false;
 		}
 		else if(stats.hero)
-			combat_text->addInt(dmg, stats.pos, CombatText::MSG_TAKEDMG);
+			comb->addFloat(dmg, stats.pos, CombatText::MSG_TAKEDMG);
 		else {
 			if(crit || is_overhit)
-				combat_text->addInt(dmg, stats.pos, CombatText::MSG_CRIT);
+				comb->addFloat(dmg, stats.pos, CombatText::MSG_CRIT);
 			else if (missed)
-				combat_text->addInt(dmg, stats.pos, CombatText::MSG_MISS);
+				comb->addFloat(dmg, stats.pos, CombatText::MSG_MISS);
 			else
-				combat_text->addInt(dmg, stats.pos, CombatText::MSG_GIVEDMG);
+				comb->addFloat(dmg, stats.pos, CombatText::MSG_GIVEDMG);
 		}
 	}
 
 	// temporarily save the current HP for calculating HP/MP steal on final blow
-	int prev_hp = stats.hp;
+	float prev_hp = stats.hp;
 
 	// save debuff status to check for on_debuff powers later
 	bool was_debuffed = stats.effects.isDebuffed();
@@ -543,38 +542,65 @@ bool Entity::takeHit(Hazard &h) {
 
 		// HP/MP steal is cumulative between stat bonus and power bonus
 		if (h.src_stats->hp > 0) {
-			int hp_steal = h.power->hp_steal + h.src_stats->get(Stats::HP_STEAL);
-			if (!stats.effects.immunity_hp_steal && hp_steal != 0) {
-				int steal_amt = (std::min(dmg, prev_hp) * hp_steal) / 100;
-				if (steal_amt == 0) steal_amt = 1;
-				combat_text->addString(msg->get("+%d HP",steal_amt), h.src_stats->pos, CombatText::MSG_BUFF);
-				h.src_stats->hp = std::min(h.src_stats->hp + steal_amt, h.src_stats->get(Stats::HP_MAX));
+			float hp_steal = h.power->hp_steal + h.src_stats->get(Stats::HP_STEAL);
+			if (hp_steal != 0) {
+				if (Math::percentChanceF(stats.get(Stats::RESIST_HP_STEAL))) {
+					comb->addString(msg->get("Resist"), stats.pos, CombatText::MSG_MISS);
+				}
+				else {
+					float steal_amt = (std::min(dmg, prev_hp) * hp_steal) / 100;
+					steal_amt = eset->combat.resourceRound(steal_amt);
+					comb->addString(msg->getv("+%s HP", Utils::floatToString(steal_amt, eset->number_format.combat_text).c_str()), h.src_stats->pos, CombatText::MSG_BUFF);
+					h.src_stats->hp = std::min(h.src_stats->hp + steal_amt, h.src_stats->get(Stats::HP_MAX));
+				}
 			}
-			int mp_steal = h.power->mp_steal + h.src_stats->get(Stats::MP_STEAL);
-			if (!stats.effects.immunity_mp_steal && mp_steal != 0) {
-				int steal_amt = (std::min(dmg, prev_hp) * mp_steal) / 100;
-				if (steal_amt == 0) steal_amt = 1;
-				combat_text->addString(msg->get("+%d MP",steal_amt), h.src_stats->pos, CombatText::MSG_BUFF);
-				h.src_stats->mp = std::min(h.src_stats->mp + steal_amt, h.src_stats->get(Stats::MP_MAX));
+			float mp_steal = h.power->mp_steal + h.src_stats->get(Stats::MP_STEAL);
+			if (mp_steal != 0) {
+				if (Math::percentChanceF(stats.get(Stats::RESIST_MP_STEAL))) {
+					comb->addString(msg->get("Resist"), stats.pos, CombatText::MSG_MISS);
+				}
+				else {
+					float steal_amt = (std::min(dmg, prev_hp) * mp_steal) / 100;
+					steal_amt = eset->combat.resourceRound(steal_amt);
+					comb->addString(msg->getv("+%s MP", Utils::floatToString(steal_amt, eset->number_format.combat_text).c_str()), h.src_stats->pos, CombatText::MSG_BUFF);
+					h.src_stats->mp = std::min(h.src_stats->mp + steal_amt, h.src_stats->get(Stats::MP_MAX));
+				}
+			}
+			for (size_t i = 0; i < h.src_stats->resource_stats.size(); ++i) {
+				float resource_steal = h.power->resource_steal[i] + h.src_stats->getResourceStat(i, EngineSettings::ResourceStats::STAT_STEAL);
+				if (resource_steal != 0) {
+					if (Math::percentChanceF(stats.getResourceStat(i, EngineSettings::ResourceStats::STAT_RESIST_STEAL))) {
+						comb->addString(msg->get("Resist"), stats.pos, CombatText::MSG_MISS);
+					}
+					else {
+						float steal_amt = (std::min(dmg, prev_hp) * resource_steal) / 100;
+						steal_amt = eset->combat.resourceRound(steal_amt);
+						comb->addString("+" + Utils::floatToString(steal_amt, eset->number_format.combat_text) + " " + eset->resource_stats.list[i].text_combat_heal, h.src_stats->pos, CombatText::MSG_BUFF);
+						h.src_stats->resource_stats[i] = std::min(h.src_stats->resource_stats[i] + steal_amt, h.src_stats->getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE));
+					}
+				}
 			}
 		}
 
 		// deal return damage
-		if (!h.src_stats->effects.immunity_damage_reflect && stats.get(Stats::RETURN_DAMAGE) > 0) {
-			int dmg_return = static_cast<int>(static_cast<float>(dmg * stats.get(Stats::RETURN_DAMAGE)) / 100.f);
+		if (stats.get(Stats::RETURN_DAMAGE) > 0) {
+			if (Math::percentChanceF(h.src_stats->get(Stats::RESIST_DAMAGE_REFLECT))) {
+				comb->addString(msg->get("Resist"), stats.pos, CombatText::MSG_MISS);
+			}
+			else {
+				float dmg_return = (dmg * stats.get(Stats::RETURN_DAMAGE)) / 100.f;
+				dmg_return = eset->combat.resourceRound(dmg_return);
 
-			if (dmg_return == 0)
-				dmg_return = 1;
+				// swap the source type when dealing return damage
+				int return_source_type = Power::SOURCE_TYPE_NEUTRAL;
+				if (h.source_type == Power::SOURCE_TYPE_HERO || h.source_type == Power::SOURCE_TYPE_ALLY)
+					return_source_type = Power::SOURCE_TYPE_ENEMY;
+				else if (h.source_type == Power::SOURCE_TYPE_ENEMY)
+					return_source_type = stats.hero ? Power::SOURCE_TYPE_HERO : Power::SOURCE_TYPE_ALLY;
 
-			// swap the source type when dealing return damage
-			int return_source_type = Power::SOURCE_TYPE_NEUTRAL;
-			if (h.source_type == Power::SOURCE_TYPE_HERO || h.source_type == Power::SOURCE_TYPE_ALLY)
-				return_source_type = Power::SOURCE_TYPE_ENEMY;
-			else if (h.source_type == Power::SOURCE_TYPE_ENEMY)
-				return_source_type = stats.hero ? Power::SOURCE_TYPE_HERO : Power::SOURCE_TYPE_ALLY;
-
-			h.src_stats->takeDamage(dmg_return, !StatBlock::TAKE_DMG_CRIT, return_source_type);
-			comb->addInt(dmg_return, h.src_stats->pos, CombatText::MSG_GIVEDMG);
+				h.src_stats->takeDamage(dmg_return, !StatBlock::TAKE_DMG_CRIT, return_source_type);
+				comb->addFloat(dmg_return, h.src_stats->pos, CombatText::MSG_GIVEDMG);
+			}
 		}
 	}
 
@@ -583,7 +609,7 @@ bool Entity::takeHit(Hazard &h) {
 		stats.effects.removeEffectID(powers->powers[h.power_index].remove_effects);
 
 		// post power
-		if (h.power->post_power > 0 && Math::percentChance(h.power->post_power_chance)) {
+		if (h.power->post_power > 0 && Math::percentChanceF(h.power->post_power_chance)) {
 			powers->activate(h.power->post_power, h.src_stats, stats.pos);
 		}
 	}
@@ -624,7 +650,7 @@ bool Entity::takeHit(Hazard &h) {
 
 		// don't go through a hit animation if stunned or successfully poised
 		// however, critical hits ignore poise
-		bool chance_poise = Math::percentChance(stats.get(Stats::POISE));
+		bool chance_poise = Math::percentChanceF(stats.get(Stats::POISE));
 
 		if(stats.cooldown_hit.isEnd()) {
 			stats.cooldown_hit.reset(Timer::BEGIN);
@@ -651,7 +677,7 @@ bool Entity::takeHit(Hazard &h) {
 			PowerID block_post_power = powers->powers[stats.block_power].post_power;
 
 			if (block_post_power != 0 && stats.getPowerCooldown(block_post_power) == 0) {
-				if (Math::percentChance(powers->powers[stats.block_power].post_power_chance)) {
+				if (Math::percentChanceF(powers->powers[stats.block_power].post_power_chance)) {
 					powers->activate(powers->powers[stats.block_power].post_power, &stats, stats.pos);
 					stats.setPowerCooldown(block_post_power, powers->powers[block_post_power].cooldown);
 				}
