@@ -38,6 +38,17 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "UtilsMath.h"
 #include "UtilsParsing.h"
 
+EventComponent::EventComponent()
+	: type(NONE)
+	, s("")
+	, status(0)
+	, id(0)
+{
+	for (size_t x = 0; x < EventComponent::DATA_COUNT; ++x) {
+		data[x].Int = 0;
+	}
+}
+
 /**
  * Class: Event
  */
@@ -210,61 +221,64 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 
 		// x,y are src, if s=="hero" we target the hero,
 		// else we'll use values in a,b as coordinates
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
+		e->data[1].Int = Parse::popFirstInt(val);
 
+		e->data[4].Bool = false;
 		std::string dest = Parse::popFirstString(val);
 		if (dest == "hero") {
-			e->s = "hero";
+			e->data[4].Bool = true;
 		}
 		else {
-			e->a = Parse::toInt(dest);
-			e->b = Parse::popFirstInt(val);
+			e->data[2].Int = Parse::toInt(dest);
+			e->data[3].Int = Parse::popFirstInt(val);
 		}
 	}
 	else if (key == "power_damage") {
-		// @ATTR event.power_damage|int, int : Min, Max|Range of power damage
+		// @ATTR event.power_damage|float, float : Min, Max|Range of power damage
 		e->type = EventComponent::POWER_DAMAGE;
 
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
+		e->data[0].Float = Parse::popFirstFloat(val);
+		e->data[1].Float = Parse::popFirstFloat(val);
 	}
 	else if (key == "intermap") {
 		// @ATTR event.intermap|filename, int, int : Map file, X, Y|Jump to specific map at location specified.
 		e->type = EventComponent::INTERMAP;
 
 		e->s = Parse::popFirstString(val);
-		e->x = -1;
-		e->y = -1;
+		e->data[0].Int = -1;
+		e->data[1].Int = -1;
 
 		std::string test_x = Parse::popFirstString(val);
 		if (!test_x.empty()) {
-			e->x = Parse::toInt(test_x);
-			e->y = Parse::popFirstInt(val);
+			e->data[0].Int = Parse::toInt(test_x);
+			e->data[1].Int = Parse::popFirstInt(val);
 		}
+
+		e->data[2].Bool = false; // not a map list
 	}
 	else if (key == "intermap_random") {
 		// @ATTR event.intermap_random|filename|Pick a random map from a map list file and teleport to it.
 		e->type = EventComponent::INTERMAP;
 
 		e->s = Parse::popFirstString(val);
-		e->z = 1; // flag that tells an intermap event that it contains a map list
+		e->data[2].Bool = true; // flag that tells an intermap event that it contains a map list
 	}
 	else if (key == "intramap") {
 		// @ATTR event.intramap|int, int : X, Y|Jump to specific position within current map.
 		e->type = EventComponent::INTRAMAP;
 
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
+		e->data[1].Int = Parse::popFirstInt(val);
 	}
 	else if (key == "mapmod") {
 		// @ATTR event.mapmod|list(predefined_string, int, int, int) : Layer, X, Y, Tile ID|Modify map tiles
 		e->type = EventComponent::MAPMOD;
 
 		e->s = Parse::popFirstString(val);
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
-		e->z = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
+		e->data[1].Int = Parse::popFirstInt(val);
+		e->data[2].Int = Parse::popFirstInt(val);
 
 		// add repeating mapmods
 		if (evnt) {
@@ -274,9 +288,9 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 				e = &evnt->components.back();
 				e->type = EventComponent::MAPMOD;
 				e->s = repeat_val;
-				e->x = Parse::popFirstInt(val);
-				e->y = Parse::popFirstInt(val);
-				e->z = Parse::popFirstInt(val);
+				e->data[0].Int = Parse::popFirstInt(val);
+				e->data[1].Int = Parse::popFirstInt(val);
+				e->data[2].Int = Parse::popFirstInt(val);
 
 				repeat_val = Parse::popFirstString(val);
 			}
@@ -287,17 +301,21 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		e->type = EventComponent::SOUNDFX;
 
 		e->s = Parse::popFirstString(val);
-		e->x = e->y = -1;
-		e->z = static_cast<int>(false);
+		e->data[0].Int = -1;
+		e->data[1].Int = -1;
+		e->data[2].Bool = false;
 
 		std::string s = Parse::popFirstString(val);
-		if (s != "") e->x = Parse::toInt(s);
+		if (!s.empty())
+			e->data[0].Int = Parse::toInt(s);
 
 		s = Parse::popFirstString(val);
-		if (s != "") e->y = Parse::toInt(s);
+		if (!s.empty())
+			e->data[1].Int = Parse::toInt(s);
 
 		s = Parse::popFirstString(val);
-		if (s != "") e->z = static_cast<int>(Parse::toBool(s));
+		if (!s.empty())
+			e->data[2].Bool = Parse::toBool(s);
 	}
 	else if (key == "loot") {
 		// @ATTR event.loot|list(loot)|Add loot to the event.
@@ -309,11 +327,11 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.loot_count|int, int : Min, Max|Sets the minimum (and optionally, the maximum) amount of loot this event can drop. Overrides the global drop_max setting.
 		e->type = EventComponent::LOOT_COUNT;
 
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
-		if (e->x != 0 || e->y != 0) {
-			e->x = std::max(e->x, 1);
-			e->y = std::max(e->y, e->x);
+		e->data[0].Int = Parse::popFirstInt(val);
+		e->data[1].Int = Parse::popFirstInt(val);
+		if (e->data[0].Int != 0 || e->data[1].Int != 0) {
+			e->data[0].Int = std::max(e->data[0].Int, 1);
+			e->data[1].Int = std::max(e->data[1].Int, e->data[0].Int);
 		}
 	}
 	else if (key == "msg") {
@@ -326,7 +344,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.shakycam|duration|Makes the camera shake for this duration in 'ms' or 's'.
 		e->type = EventComponent::SHAKYCAM;
 
-		e->x = Parse::toDuration(val);
+		e->data[0].Int = Parse::toDuration(val);
 	}
 	else if (key == "requires_status") {
 		// @ATTR event.requires_status|list(string)|Event requires list of statuses
@@ -370,25 +388,25 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.requires_level|int|Event requires hero level
 		e->type = EventComponent::REQUIRES_LEVEL;
 
-		e->x = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
 	}
 	else if (key == "requires_not_level") {
 		// @ATTR event.requires_not_level|int|Event requires not hero level
 		e->type = EventComponent::REQUIRES_NOT_LEVEL;
 
-		e->x = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
 	}
 	else if (key == "requires_currency") {
 		// @ATTR event.requires_currency|int|Event requires atleast this much currency
 		e->type = EventComponent::REQUIRES_CURRENCY;
 
-		e->x = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
 	}
 	else if (key == "requires_not_currency") {
 		// @ATTR event.requires_not_currency|int|Event requires no more than this much currency
 		e->type = EventComponent::REQUIRES_NOT_CURRENCY;
 
-		e->x = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
 	}
 	else if (key == "requires_item") {
 		// @ATTR event.requires_item|list(item_id)|Event requires specific item (not equipped). Quantity can be specified by appending ":Q" to the item_id, where Q is an integer.
@@ -396,7 +414,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 
 		ItemStack item_stack = Parse::toItemQuantityPair(Parse::popFirstString(val));
 		e->id = item_stack.item;
-		e->x = item_stack.quantity;
+		e->data[0].Int = item_stack.quantity;
 
 		// add repeating requires_item
 		if (evnt) {
@@ -407,7 +425,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 				e->type = EventComponent::REQUIRES_ITEM;
 				item_stack = Parse::toItemQuantityPair(repeat_val);
 				e->id = item_stack.item;
-				e->x = item_stack.quantity;
+				e->data[0].Int = item_stack.quantity;
 
 				repeat_val = Parse::popFirstString(val);
 			}
@@ -419,7 +437,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 
 		ItemStack item_stack = Parse::toItemQuantityPair(Parse::popFirstString(val));
 		e->id = item_stack.item;
-		e->x = item_stack.quantity;
+		e->data[0].Int = item_stack.quantity;
 
 		// add repeating requires_not_item
 		if (evnt) {
@@ -430,7 +448,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 				e->type = EventComponent::REQUIRES_NOT_ITEM;
 				item_stack = Parse::toItemQuantityPair(repeat_val);
 				e->id = item_stack.item;
-				e->x = item_stack.quantity;
+				e->data[0].Int = item_stack.quantity;
 
 				repeat_val = Parse::popFirstString(val);
 			}
@@ -490,7 +508,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.remove_currency|int|Removes specified amount of currency from hero inventory
 		e->type = EventComponent::REMOVE_CURRENCY;
 
-		e->x = std::max(Parse::toInt(val), 0);
+		e->data[0].Int = std::max(Parse::toInt(val), 0);
 	}
 	else if (key == "remove_item") {
 		// @ATTR event.remove_item|list(item_id)|Removes specified item from hero inventory. Quantity can be specified by appending ":Q" to the item_id, where Q is an integer.
@@ -498,7 +516,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 
 		ItemStack item_stack = Parse::toItemQuantityPair(Parse::popFirstString(val));
 		e->id = item_stack.item;
-		e->x = item_stack.quantity;
+		e->data[0].Int = item_stack.quantity;
 
 		// add repeating remove_item
 		if (evnt) {
@@ -509,7 +527,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 				e->type = EventComponent::REMOVE_ITEM;
 				item_stack = Parse::toItemQuantityPair(repeat_val);
 				e->id = item_stack.item;
-				e->x = item_stack.quantity;
+				e->data[0].Int = item_stack.quantity;
 
 				repeat_val = Parse::popFirstString(val);
 			}
@@ -519,13 +537,13 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.reward_xp|int|Reward hero with specified amount of experience points.
 		e->type = EventComponent::REWARD_XP;
 
-		e->x = std::max(Parse::toInt(val), 0);
+		e->data[0].Int = std::max(Parse::toInt(val), 0);
 	}
 	else if (key == "reward_currency") {
 		// @ATTR event.reward_currency|int|Reward hero with specified amount of currency.
 		e->type = EventComponent::REWARD_CURRENCY;
 
-		e->x = std::max(Parse::toInt(val), 0);
+		e->data[0].Int = std::max(Parse::toInt(val), 0);
 	}
 	else if (key == "reward_item") {
 		// @ATTR event.reward_item|(list(item_id)|Reward hero with a specified item. Quantity can be specified by appending ":Q" to the item_id, where Q is an integer. To maintain backwards compatibility, the quantity must be defined for at least the first item in the list in order to use this syntax.
@@ -538,11 +556,11 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		if (!check_pair) {
 			// item:quantity syntax not detected, falling back to the old syntax
 			e->id = item_stack.item;
-			e->x = std::max(Parse::popFirstInt(val), 1);
+			e->data[0].Int = std::max(Parse::popFirstInt(val), 1);
 		}
 		else {
 			e->id = item_stack.item;
-			e->x = item_stack.quantity;
+			e->data[0].Int = item_stack.quantity;
 
 			// add repeating reward_item
 			if (evnt) {
@@ -553,7 +571,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 					e->type = EventComponent::REWARD_ITEM;
 					item_stack = Parse::toItemQuantityPair(repeat_val);
 					e->id = item_stack.item;
-					e->x = item_stack.quantity;
+					e->data[0].Int = item_stack.quantity;
 
 					repeat_val = Parse::popFirstString(val);
 				}
@@ -570,11 +588,11 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.reward_loot_count|int, int : Min, Max|Sets the minimum (and optionally, the maximum) amount of loot that reward_loot can give the hero. Defaults to 1.
 		e->type = EventComponent::REWARD_LOOT_COUNT;
 
-		e->x = std::max(Parse::popFirstInt(val), 1);
-		e->y = std::max(Parse::popFirstInt(val), e->x);
+		e->data[0].Int = std::max(Parse::popFirstInt(val), 1);
+		e->data[1].Int = std::max(Parse::popFirstInt(val), e->data[0].Int);
 	}
 	else if (key == "restore") {
-		// @ATTR event.restore|["hp", "mp", "hpmp", "status", "all"]|Restore the hero's HP, MP, and/or status.
+		// @ATTR event.restore|list(["hp", "mp", "hpmp", "status", "all", predefined_string])|Restore the hero's HP, MP, and/or status. Resource stat base IDs are also valid.
 		e->type = EventComponent::RESTORE;
 
 		e->s = val;
@@ -590,8 +608,8 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		e->type = EventComponent::SPAWN;
 
 		e->s = Parse::popFirstString(val);
-		e->x = Parse::popFirstInt(val);
-		e->y = Parse::popFirstInt(val);
+		e->data[0].Int = Parse::popFirstInt(val);
+		e->data[1].Int = Parse::popFirstInt(val);
 
 		// add repeating spawn
 		if (evnt) {
@@ -602,8 +620,8 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 				e->type = EventComponent::SPAWN;
 
 				e->s = repeat_val;
-				e->x = Parse::popFirstInt(val);
-				e->y = Parse::popFirstInt(val);
+				e->data[0].Int = Parse::popFirstInt(val);
+				e->data[1].Int = Parse::popFirstInt(val);
 
 				repeat_val = Parse::popFirstString(val);
 			}
@@ -613,7 +631,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.stash|bool|If true, the Stash menu if opened.
 		e->type = EventComponent::STASH;
 
-		e->x = static_cast<int>(Parse::toBool(val));
+		e->data[0].Bool = Parse::toBool(val);
 	}
 	else if (key == "npc") {
 		// @ATTR event.npc|filename|Filename of an NPC to start dialog with.
@@ -637,13 +655,13 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		// @ATTR event.repeat|bool|If true, the event to be triggered again.
 		e->type = EventComponent::REPEAT;
 
-		e->x = static_cast<int>(Parse::toBool(val));
+		e->data[0].Bool = Parse::toBool(val);
 	}
 	else if (key == "save_game") {
 		// @ATTR event.save_game|bool|If true, the game is saved when the event is triggered. The respawn position is set to where the player is standing.
 		e->type = EventComponent::SAVE_GAME;
 
-		e->x = static_cast<int>(Parse::toBool(val));
+		e->data[0].Bool = Parse::toBool(val);
 	}
 	else if (key == "book") {
 		// @ATTR event.book|filename|Opens a book by filename.
@@ -658,10 +676,10 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		e->s = val;
 	}
 	else if (key == "chance_exec") {
-		// @ATTR event.chance_exec|int|Percentage chance that this event will execute when triggered.
+		// @ATTR event.chance_exec|float|Percentage chance that this event will execute when triggered.
 		e->type = EventComponent::CHANCE_EXEC;
 
-		e->x = Parse::popFirstInt(val);
+		e->data[0].Float = Parse::popFirstFloat(val);
 	}
 	else if (key == "respec") {
 		// @ATTR event.respec|["xp", "stats", "powers"], bool : Respec mode, Ignore class defaults|Resets various aspects of the character's progression. Resetting "xp" also resets "stats". Resetting "stats" also resets "powers".
@@ -671,23 +689,23 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 		std::string use_engine_defaults = Parse::popFirstString(val);
 
 		if (mode == "xp") {
-			e->x = 3;
+			e->data[0].Int = 3;
 		}
 		else if (mode == "stats") {
-			e->x = 2;
+			e->data[0].Int = 2;
 		}
 		else if (mode == "powers") {
-			e->x = 1;
+			e->data[0].Int = 1;
 		}
 
 		if (!use_engine_defaults.empty())
-			e->y = static_cast<int>(Parse::toBool(use_engine_defaults));
+			e->data[1].Bool = Parse::toBool(use_engine_defaults);
 	}
 	else if (key == "show_on_minimap") {
 		// @ATTR event.show_on_minimap|bool|If true, this event will be shown on the minimap if it is the appropriate type (e.g. an intermap teleport).
 		e->type = EventComponent::SHOW_ON_MINIMAP;
 
-		e->x = static_cast<int>(Parse::toBool(val));
+		e->data[0].Bool = Parse::toBool(val);
 	}
 	else if (key == "parallax_layers") {
 		// @ATTR event.parallax_layers|filename|Filename of a parallax layers definition to load.
@@ -701,7 +719,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 
 		std::string mode = Parse::popFirstString(val);
 		if (mode == "append") {
-			e->x = EventComponent::RANDOM_STATUS_MODE_APPEND;
+			e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_APPEND;
 
 			e->status = camp->registerStatus(Parse::popFirstString(val));
 
@@ -712,7 +730,7 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 					evnt->components.push_back(EventComponent());
 					e = &evnt->components.back();
 					e->type = EventComponent::RANDOM_STATUS;
-					e->x = EventComponent::RANDOM_STATUS_MODE_APPEND;
+					e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_APPEND;
 					e->status = camp->registerStatus(repeat_val);
 
 					repeat_val = Parse::popFirstString(val);
@@ -720,13 +738,13 @@ bool EventManager::loadEventComponentString(std::string &key, std::string &val,
 			}
 		}
 		else if (mode == "clear")
-			e->x = EventComponent::RANDOM_STATUS_MODE_CLEAR;
+			e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_CLEAR;
 		else if (mode == "roll")
-			e->x = EventComponent::RANDOM_STATUS_MODE_ROLL;
+			e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_ROLL;
 		else if (mode == "set")
-			e->x = EventComponent::RANDOM_STATUS_MODE_SET;
+			e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_SET;
 		else if (mode == "unset")
-			e->x = EventComponent::RANDOM_STATUS_MODE_UNSET;
+			e->data[0].Int = EventComponent::RANDOM_STATUS_MODE_UNSET;
 		else
 			Utils::logError("EventManager: '%s' is not a valid random_status action.", mode.c_str());
 	}
@@ -760,7 +778,7 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 	// need to know this for early returns
 	EventComponent *ec_repeat = ev.getComponent(EventComponent::REPEAT);
 	if (ec_repeat) {
-		ev.keep_after_trigger = ec_repeat->x == 0 ? false : true;
+		ev.keep_after_trigger = ec_repeat->data[0].Bool;
 	}
 
 	// Delay event execution
@@ -782,7 +800,7 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 	// if chance_exec roll fails, don't execute the event
 	// we respect the value of "repeat", even if the event doesn't execute
 	EventComponent *ec_chance_exec = ev.getComponent(EventComponent::CHANCE_EXEC);
-	if (ec_chance_exec && !Math::percentChance(ec_chance_exec->x)) {
+	if (ec_chance_exec && !Math::percentChanceF(ec_chance_exec->data[0].Float)) {
 		return !ev.keep_after_trigger;
 	}
 
@@ -798,28 +816,28 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 			camp->unsetStatus(ec->status);
 		}
 		else if (ec->type == EventComponent::INTERMAP) {
-			if (ec->z == 1) {
+			if (ec->data[2].Bool) {
 				// this is intermap_random
 				std::string map_list = ec->s;
 				EventComponent random_ec = getRandomMapFromFile(map_list);
 
 				ec->s = random_ec.s;
-				ec->x = random_ec.x;
-				ec->y = random_ec.y;
+				ec->data[0].Int = random_ec.data[0].Int;
+				ec->data[1].Int = random_ec.data[1].Int;
 			}
 
 			if (Filesystem::fileExists(mods->locate(ec->s))) {
 				mapr->teleportation = true;
 				mapr->teleport_mapname = ec->s;
 
-				if (ec->x == -1 && ec->y == -1) {
+				if (ec->data[0].Int == -1 && ec->data[1].Int == -1) {
 					// the teleport destination will be set to the map's hero_pos once the map is loaded
 					mapr->teleport_destination.x = -1;
 					mapr->teleport_destination.y = -1;
 				}
 				else {
-					mapr->teleport_destination.x = static_cast<float>(ec->x) + 0.5f;
-					mapr->teleport_destination.y = static_cast<float>(ec->y) + 0.5f;
+					mapr->teleport_destination.x = static_cast<float>(ec->data[0].Int) + 0.5f;
+					mapr->teleport_destination.y = static_cast<float>(ec->data[1].Int) + 0.5f;
 				}
 			}
 			else {
@@ -831,38 +849,38 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 		else if (ec->type == EventComponent::INTRAMAP) {
 			mapr->teleportation = true;
 			mapr->teleport_mapname = "";
-			mapr->teleport_destination.x = static_cast<float>(ec->x) + 0.5f;
-			mapr->teleport_destination.y = static_cast<float>(ec->y) + 0.5f;
+			mapr->teleport_destination.x = static_cast<float>(ec->data[0].Int) + 0.5f;
+			mapr->teleport_destination.y = static_cast<float>(ec->data[1].Int) + 0.5f;
 		}
 		else if (ec->type == EventComponent::MAPMOD) {
 			if (ec->s == "collision") {
-				if (ec->x >= 0 && ec->x < mapr->w && ec->y >= 0 && ec->y < mapr->h) {
-					mapr->collider.colmap[ec->x][ec->y] = static_cast<unsigned short>(ec->z);
+				if (ec->data[0].Int >= 0 && ec->data[0].Int < mapr->w && ec->data[1].Int >= 0 && ec->data[1].Int < mapr->h) {
+					mapr->collider.colmap[ec->data[0].Int][ec->data[1].Int] = static_cast<unsigned short>(ec->data[2].Int);
 					mapr->map_change = true;
 				}
 				else
-					Utils::logError("EventManager: Mapmod at position (%d, %d) is out of bounds 0-255.", ec->x, ec->y);
+					Utils::logError("EventManager: Mapmod at position (%d, %d) is out of bounds 0-255.", ec->data[0].Int, ec->data[1].Int);
 			}
 			else {
 				size_t index = static_cast<size_t>(distance(mapr->layernames.begin(), find(mapr->layernames.begin(), mapr->layernames.end(), ec->s)));
-				if (!mapr->isValidTile(ec->z))
-					Utils::logError("EventManager: Mapmod at position (%d, %d) contains invalid tile id (%d).", ec->x, ec->y, ec->z);
+				if (!mapr->isValidTile(ec->data[2].Int))
+					Utils::logError("EventManager: Mapmod at position (%d, %d) contains invalid tile id (%d).", ec->data[0].Int, ec->data[1].Int, ec->data[2].Int);
 				else if (index >= mapr->layers.size())
-					Utils::logError("EventManager: Mapmod at position (%d, %d) is on an invalid layer.", ec->x, ec->y);
-				else if (ec->x >= 0 && ec->x < mapr->w && ec->y >= 0 && ec->y < mapr->h)
-					mapr->layers[index][ec->x][ec->y] = static_cast<unsigned short>(ec->z);
+					Utils::logError("EventManager: Mapmod at position (%d, %d) is on an invalid layer.", ec->data[0].Int, ec->data[1].Int);
+				else if (ec->data[0].Int >= 0 && ec->data[0].Int < mapr->w && ec->data[1].Int >= 0 && ec->data[1].Int < mapr->h)
+					mapr->layers[index][ec->data[0].Int][ec->data[1].Int] = static_cast<unsigned short>(ec->data[2].Int);
 				else
-					Utils::logError("EventManager: Mapmod at position (%d, %d) is out of bounds 0-255.", ec->x, ec->y);
+					Utils::logError("EventManager: Mapmod at position (%d, %d) is out of bounds 0-255.", ec->data[0].Int, ec->data[1].Int);
 			}
 		}
 		else if (ec->type == EventComponent::SOUNDFX) {
 			FPoint pos(0,0);
 			bool loop = false;
 
-			if (ec->x != -1 && ec->y != -1) {
-				if (ec->x != 0 && ec->y != 0) {
-					pos.x = static_cast<float>(ec->x) + 0.5f;
-					pos.y = static_cast<float>(ec->y) + 0.5f;
+			if (ec->data[0].Int != -1 && ec->data[1].Int != -1) {
+				if (ec->data[0].Int != 0 && ec->data[1].Int != 0) {
+					pos.x = static_cast<float>(ec->data[0].Int) + 0.5f;
+					pos.y = static_cast<float>(ec->data[1].Int) + 0.5f;
 				}
 			}
 			else if (ev.location.x != 0 && ev.location.y != 0) {
@@ -870,7 +888,7 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 				pos.y = static_cast<float>(ev.location.y) + 0.5f;
 			}
 
-			if (ev.activate_type == Event::ACTIVATE_ON_LOAD || ec->z != 0)
+			if (ev.activate_type == Event::ACTIVATE_ON_LOAD || ec->data[2].Bool)
 				loop = true;
 
 			SoundID sid = snd->load(ec->s, "MapRenderer background soundfx");
@@ -881,38 +899,38 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 		else if (ec->type == EventComponent::LOOT) {
 			EventComponent *ec_lootcount = ev.getComponent(EventComponent::LOOT_COUNT);
 			if (ec_lootcount) {
-				mapr->loot_count.x = ec_lootcount->x;
-				mapr->loot_count.y = ec_lootcount->y;
+				mapr->loot_count.x = ec_lootcount->data[0].Int;
+				mapr->loot_count.y = ec_lootcount->data[1].Int;
 			}
 			else {
 				mapr->loot_count.x = 0;
 				mapr->loot_count.y = 0;
 			}
 
-			ec->x = ev.hotspot.x;
-			ec->y = ev.hotspot.y;
+			ec->data[0].Int = ev.hotspot.x; // LOOT_EC_POSX
+			ec->data[1].Int = ev.hotspot.y; // LOOT_EC_POSY
 			mapr->loot.push_back(*ec);
 		}
 		else if (ec->type == EventComponent::MSG) {
 			pc->logMsg(ec->s, Avatar::MSG_UNIQUE);
 		}
 		else if (ec->type == EventComponent::SHAKYCAM) {
-			mapr->cam.shake_timer.setDuration(ec->x);
+			mapr->cam.shake_timer.setDuration(ec->data[0].Int);
 		}
 		else if (ec->type == EventComponent::REMOVE_CURRENCY) {
-			camp->removeCurrency(ec->x);
+			camp->removeCurrency(ec->data[0].Int);
 		}
 		else if (ec->type == EventComponent::REMOVE_ITEM) {
-			camp->removeItem(ItemStack(ec->id, ec->x));
+			camp->removeItem(ItemStack(ec->id, ec->data[0].Int));
 		}
 		else if (ec->type == EventComponent::REWARD_XP) {
-			camp->rewardXP(ec->x, CampaignManager::XP_SHOW_MSG);
+			camp->rewardXP(static_cast<float>(ec->data[0].Int), CampaignManager::XP_SHOW_MSG);
 		}
 		else if (ec->type == EventComponent::REWARD_CURRENCY) {
-			camp->rewardCurrency(ec->x);
+			camp->rewardCurrency(ec->data[0].Int);
 		}
 		else if (ec->type == EventComponent::REWARD_ITEM) {
-			camp->rewardItem(ItemStack(ec->id, ec->x));
+			camp->rewardItem(ItemStack(ec->id, ec->data[0].Int));
 		}
 		else if (ec->type == EventComponent::REWARD_LOOT) {
 			std::vector<EventComponent> random_table;
@@ -920,8 +938,8 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 
 			EventComponent *ec_lootcount = ev.getComponent(EventComponent::REWARD_LOOT_COUNT);
 			if (ec_lootcount) {
-				random_table_count.x = ec_lootcount->x;
-				random_table_count.y = ec_lootcount->y;
+				random_table_count.x = ec_lootcount->data[0].Int;
+				random_table_count.y = ec_lootcount->data[1].Int;
 			}
 
 			random_table.push_back(EventComponent());
@@ -944,8 +962,8 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 		}
 		else if (ec->type == EventComponent::SPAWN) {
 			Point spawn_pos;
-			spawn_pos.x = ec->x;
-			spawn_pos.y = ec->y;
+			spawn_pos.x = ec->data[0].Int;
+			spawn_pos.y = ec->data[1].Int;
 			entitym->spawn(ec->s, spawn_pos);
 		}
 		else if (ec->type == EventComponent::POWER) {
@@ -954,14 +972,14 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 
 			if (ec_path) {
 				// targets hero option
-				if (ec_path->s == "hero") {
+				if (ec_path->data[4].Bool) {
 					target.x = pc->stats.pos.x;
 					target.y = pc->stats.pos.y;
 				}
 				// targets fixed path option
 				else {
-					target.x = static_cast<float>(ec_path->a) + 0.5f;
-					target.y = static_cast<float>(ec_path->b) + 0.5f;
+					target.x = static_cast<float>(ec_path->data[2].Int) + 0.5f;
+					target.y = static_cast<float>(ec_path->data[3].Int) + 0.5f;
 				}
 			}
 			// no path specified, targets self location
@@ -971,11 +989,11 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 			}
 
 			// ec->id is power id
-			// ec->x is statblock index
-			mapr->activatePower(ec->id, ec->x, target);
+			// ec->data[0] is statblock index
+			mapr->activatePower(ec->id, ec->data[0].Int, target);
 		}
 		else if (ec->type == EventComponent::STASH) {
-			mapr->stash = ec->x == 0 ? false : true;
+			mapr->stash = ec->data[0].Bool;
 			if (mapr->stash) {
 				mapr->stash_pos.x = static_cast<float>(ev.location.x) + 0.5f;
 				mapr->stash_pos.y = static_cast<float>(ev.location.y) + 0.5f;
@@ -993,13 +1011,13 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 			mapr->cutscene_file = ec->s;
 		}
 		else if (ec->type == EventComponent::REPEAT) {
-			ev.keep_after_trigger = ec->x == 0 ? false : true;
+			ev.keep_after_trigger = ec->data[0].Bool;
 		}
 		else if (ec->type == EventComponent::SAVE_GAME) {
-			mapr->save_game = ec->x == 0 ? false : true;
+			mapr->save_game = ec->data[0].Bool;
 		}
 		else if (ec->type == EventComponent::NPC_ID) {
-			mapr->npc_id = ec->x;
+			mapr->npc_id = ec->data[0].Int;
 		}
 		else if (ec->type == EventComponent::BOOK) {
 			mapr->show_book = ec->s;
@@ -1011,16 +1029,16 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 				executeScript(ec->s, pc->stats.pos.x, pc->stats.pos.y);
 		}
 		else if (ec->type == EventComponent::RESPEC) {
-			bool use_engine_defaults = static_cast<bool>(ec->y);
+			bool use_engine_defaults = ec->data[1].Bool;
 			EngineSettings::HeroClasses::HeroClass* pc_class;
 			pc_class = eset->hero_classes.getByName(pc->stats.character_class);
 
-			if (ec->x == 3) {
+			if (ec->data[0].Int == 3) {
 				// xp
 				pc->stats.level = 1;
 				pc->stats.xp = 0;
 			}
-			if (ec->x >= 2) {
+			if (ec->data[0].Int >= 2) {
 				// stats
 				for (size_t j = 0; j < eset->primary_stats.list.size(); ++j) {
 					pc->stats.primary[j] = 1;
@@ -1036,7 +1054,7 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 				menu->inv->applyEquipment();
 				pc->stats.logic();
 			}
-			if (ec->x >= 1) {
+			if (ec->data[0].Int >= 1) {
 				// powers
 				pc->stats.powers_list.clear();
 				pc->stats.powers_passive.clear();
@@ -1063,15 +1081,15 @@ bool EventManager::executeEventInternal(Event &ev, bool skip_delay) {
 			mapr->setMapParallax(ec->s);
 		}
 		else if (ec->type == EventComponent::RANDOM_STATUS) {
-			if (ec->x == EventComponent::RANDOM_STATUS_MODE_APPEND)
+			if (ec->data[0].Int == EventComponent::RANDOM_STATUS_MODE_APPEND)
 				camp->randomStatusAppend(ec->status);
-			else if (ec->x == EventComponent::RANDOM_STATUS_MODE_CLEAR)
+			else if (ec->data[0].Int == EventComponent::RANDOM_STATUS_MODE_CLEAR)
 				camp->randomStatusClear();
-			else if (ec->x == EventComponent::RANDOM_STATUS_MODE_ROLL)
+			else if (ec->data[0].Int == EventComponent::RANDOM_STATUS_MODE_ROLL)
 				camp->randomStatusRoll();
-			else if (ec->x == EventComponent::RANDOM_STATUS_MODE_SET)
+			else if (ec->data[0].Int == EventComponent::RANDOM_STATUS_MODE_SET)
 				camp->randomStatusSet();
-			else if (ec->x == EventComponent::RANDOM_STATUS_MODE_UNSET)
+			else if (ec->data[0].Int == EventComponent::RANDOM_STATUS_MODE_UNSET)
 				camp->randomStatusUnset();
 		}
 	}
@@ -1124,7 +1142,7 @@ void EventManager::executeScript(const std::string& filename, float x, float y)
 			// create StatBlocks if we need them
 			EventComponent *ec_power = script_evnt.front().getComponent(EventComponent::POWER);
 			if (ec_power) {
-				ec_power->x = mapr->addEventStatBlock(script_evnt.front());
+				ec_power->data[0].Int = mapr->addEventStatBlock(script_evnt.front());
 			}
 
 			if (script_evnt.front().delay.getDuration() > 0) {
@@ -1163,13 +1181,13 @@ EventComponent EventManager::getRandomMapFromFile(const std::string& fname) {
 				EventComponent ec;
 				ec.s = Parse::popFirstString(infile.val);
 				if (ec_list.empty() || ec.s != mapr->getFilename()) {
-					ec.x = -1;
-					ec.y = -1;
+					ec.data[0].Int = -1;
+					ec.data[1].Int = -1;
 
 					std::string test_x = Parse::popFirstString(infile.val);
 					if (!test_x.empty()) {
-						ec.x = Parse::toInt(test_x);
-						ec.y = Parse::popFirstInt(infile.val);
+						ec.data[0].Int = Parse::toInt(test_x);
+						ec.data[1].Int = Parse::popFirstInt(infile.val);
 					}
 
 					ec_list.push_back(ec);
