@@ -51,6 +51,7 @@ public:
 	unsigned long time_played;
 
 	std::vector<int> equipped;
+	int active_equipment_set;
 	GameSlotPreview preview;
 	Timer preview_turn_timer;
 
@@ -66,6 +67,10 @@ public:
 
 class GameStateLoad : public GameState {
 private:
+	enum {
+		DELETE_CONFIRM_OPTION_NO = 0,
+		DELETE_CONFIRM_OPTION_YES = 1,
+	};
 
 	void loadGraphics();
 	void loadPortrait(int slot);
@@ -128,6 +133,8 @@ private:
 	int portrait_align;
 	int gameslot_align;
 
+	std::vector<int> equip_sets;
+
 public:
 	GameStateLoad();
 	~GameStateLoad();
