@@ -75,6 +75,7 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "SoundManager.h"
 #include "UtilsParsing.h"
 #include "WidgetLabel.h"
+#include "XPScaling.h"
 
 #include <cassert>
 
@@ -106,6 +107,7 @@ GameStatePlay::GameStatePlay()
 	menu = new MenuManager();
 	npcs = new NPCManager();
 	quests = new QuestLog(menu->questlog);
+	xp_scaling = new XPScaling();
 
 	// load the config file for character titles
 	loadTitles();
@@ -860,13 +862,6 @@ void GameStatePlay::logic() {
 		menu->act->checkAction(pc->action_queue);
 		pc->logic();
 
-		// Transform powers change the actionbar layout,
-		// so we need to prevent accidental clicks if a new power is placed under the slot we clicked on.
-		// It's a bit hacky, but it works
-		if (pc->isTransforming()) {
-			menu->act->resetSlots();
-		}
-
 		// transfer hero data to enemies, for AI use
 		if (pc->stats.get(Stats::STEALTH) > 100) entitym->hero_stealth = 100;
 		else entitym->hero_stealth = pc->stats.get(Stats::STEALTH);
@@ -1107,6 +1102,7 @@ GameStatePlay::~GameStatePlay() {
 	delete items;
 	delete powers;
 	delete fow;
+	delete xp_scaling;
 
 	delete enemyg;
 
@@ -1123,5 +1119,6 @@ GameStatePlay::~GameStatePlay() {
 	menu_powers = NULL;
 	powers = NULL;
 	fow = NULL;
+	xp_scaling = NULL;
 }
 
