@@ -73,10 +73,8 @@ Item::Item()
 	, type("")
 	, icon(0)
 	, book_is_readable(true)
-	, dmg_min((eset ? eset->damage_types.list.size() : 0), 0)
-	, dmg_max((eset ? eset->damage_types.list.size() : 0), 0)
-	, abs_min(0)
-	, abs_max(0)
+	, base_dmg((eset ? eset->damage_types.list.size() : 0))
+	, base_abs()
 	, requires_level(0)
 	, requires_class("")
 	, sfx("")
@@ -201,7 +199,7 @@ void ItemManager::loadItems(const std::string& filename) {
 			}
 		}
 		else if (infile.key == "dmg") {
-			// @ATTR dmg|predefined_string, int, int : Damage type, Min, Max|Defines the item's base damage type and range. Max may be ommitted and will default to Min.
+			// @ATTR dmg|predefined_string, float, float : Damage type, Min, Max|Defines the item's base damage type and range. Max may be ommitted and will default to Min.
 			std::string dmg_type_str = Parse::popFirstString(infile.val);
 
 			size_t dmg_type = eset->damage_types.list.size();
@@ -216,20 +214,20 @@ void ItemManager::loadItems(const std::string& filename) {
 				infile.error("ItemManager: '%s' is not a known damage type id.", dmg_type_str.c_str());
 			}
 			else {
-				items[id].dmg_min[dmg_type] = Parse::popFirstInt(infile.val);
+				items[id].base_dmg[dmg_type].min = Parse::popFirstFloat(infile.val);
 				if (infile.val.length() > 0)
-					items[id].dmg_max[dmg_type] = Parse::popFirstInt(infile.val);
+					items[id].base_dmg[dmg_type].max = Parse::popFirstFloat(infile.val);
 				else
-					items[id].dmg_max[dmg_type] = items[id].dmg_min[dmg_type];
+					items[id].base_dmg[dmg_type].max = items[id].base_dmg[dmg_type].min;
 			}
 		}
 		else if (infile.key == "abs") {
-			// @ATTR abs|int, int : Min, Max|Defines the item absorb value, if only min is specified the absorb value is fixed.
-			items[id].abs_min = Parse::popFirstInt(infile.val);
+			// @ATTR abs|float, float : Min, Max|Defines the item absorb value, if only min is specified the absorb value is fixed.
+			items[id].base_abs.min = Parse::popFirstFloat(infile.val);
 			if (infile.val.length() > 0)
-				items[id].abs_max = Parse::popFirstInt(infile.val);
+				items[id].base_abs.max = Parse::popFirstFloat(infile.val);
 			else
-				items[id].abs_max = items[id].abs_min;
+				items[id].base_abs.max = items[id].base_abs.min;
 		}
 		else if (infile.key == "requires_level") {
 			// @ATTR requires_level|int|The hero's level must match or exceed this value in order to equip this item.
@@ -238,24 +236,23 @@ void ItemManager::loadItems(const std::string& filename) {
 		else if (infile.key == "requires_stat") {
 			// @ATTR requires_stat|repeatable(predefined_string, int) : Primary stat name, Value|Make item require specific stat level ex. requires_stat=physical,6 will require hero to have level 6 in physical stats
 			if (clear_req_stat) {
-				items[id].req_stat.clear();
-				items[id].req_val.clear();
+				items[id].requires_stat.clear();
 				clear_req_stat = false;
 			}
+
 			std::string s = Parse::popFirstString(infile.val);
 			size_t req_stat_index = eset->primary_stats.getIndexByID(s);
 			if (req_stat_index != eset->primary_stats.list.size())
-				items[id].req_stat.push_back(req_stat_index);
+				items[id].requires_stat[req_stat_index] = Parse::popFirstInt(infile.val);
 			else
 				infile.error("ItemManager: '%s' is not a valid primary stat.", s.c_str());
-			items[id].req_val.push_back(Parse::popFirstInt(infile.val));
 		}
 		else if (infile.key == "requires_class") {
 			// @ATTR requires_class|predefined_string|The hero's base class (engine/classes.txt) must match for this item to be equipped.
 			items[id].requires_class = infile.val;
 		}
 		else if (infile.key == "bonus") {
-			// @ATTR bonus|repeatable(stat_id, int) : Stat ID, Value|Adds a bonus to the item by stat ID, example: bonus=hp, 50
+			// @ATTR bonus|repeatable(stat_id, float) : Stat ID, Value|Adds a bonus to the item by stat ID, example: bonus=hp,50
 			if (clear_bonus) {
 				items[id].bonus.clear();
 				clear_bonus = false;
@@ -267,8 +264,9 @@ void ItemManager::loadItems(const std::string& filename) {
 		else if (infile.key == "bonus_power_level") {
 			// @ATTR bonus_power_level|repeatable(power_id, int) : Base power, Bonus levels|Grants bonus levels to a given base power.
 			BonusData bdata;
+			bdata.type = BonusData::POWER_LEVEL;
 			bdata.power_id = Parse::toPowerID(Parse::popFirstString(infile.val));
-			bdata.value = Parse::popFirstInt(infile.val);
+			bdata.value = Parse::popFirstFloat(infile.val);
 			items[id].bonus.push_back(bdata);
 		}
 		else if (infile.key == "soundfx") {
@@ -363,7 +361,7 @@ void ItemManager::loadItems(const std::string& filename) {
 				infile.error("ItemManager: '%s' is not a valid value for 'no_stash'. Use 'ignore', 'private', 'shared', or 'all'.", temp.c_str());
 		}
 		else if (infile.key == "script") {
-			// @ATTR item.script|filename|Loads and executes a script file when the item is activated from the player's inventory.
+			// @ATTR script|filename|Loads and executes a script file when the item is activated from the player's inventory.
 			items[id].script = Parse::popFirstString(infile.val);
 		}
 		else {
@@ -570,7 +568,7 @@ void ItemManager::loadSets(const std::string& filename) {
 			item_sets[id].color = Parse::toRGB(infile.val);
 		}
 		else if (infile.key == "bonus") {
-			// @ATTR bonus|repeatable(int, stat_id, int) : Required set item count, Stat ID, Value|Bonus to append to items in the set.
+			// @ATTR bonus|repeatable(int, stat_id, float) : Required set item count, Stat ID, Value|Bonus to append to items in the set.
 			if (clear_bonus) {
 				item_sets[id].bonus.clear();
 				clear_bonus = false;
@@ -583,9 +581,10 @@ void ItemManager::loadSets(const std::string& filename) {
 		else if (infile.key == "bonus_power_level") {
 			// @ATTR bonus_power_level|repeatable(int, power_id, int) : Required set item count, Base power, Bonus levels|Grants bonus levels to a given base power.
 			SetBonusData bonus;
+			bonus.type = BonusData::POWER_LEVEL;
 			bonus.requirement = Parse::popFirstInt(infile.val);
 			bonus.power_id = Parse::toPowerID(Parse::popFirstString(infile.val));
-			bonus.value = Parse::popFirstInt(infile.val);
+			bonus.value = Parse::popFirstFloat(infile.val);
 			item_sets[id].bonus.push_back(bonus);
 		}
 		else {
@@ -597,93 +596,152 @@ void ItemManager::loadSets(const std::string& filename) {
 
 void ItemManager::parseBonus(BonusData& bdata, FileParser& infile) {
 	std::string bonus_str = Parse::popFirstString(infile.val);
-	bdata.value = Parse::popFirstInt(infile.val);
+	std::string bonus_value_str = Parse::popFirstString(infile.val);
+
+	if (!bonus_value_str.empty()) {
+		if (bonus_value_str[bonus_value_str.size() - 1] == '%') {
+			bdata.is_multiplier = true;
+			bonus_value_str.resize(bonus_value_str.size() - 1);
+			bdata.value = Parse::toFloat(bonus_value_str) / 100;
+		}
+		else {
+			bdata.value = Parse::toFloat(bonus_value_str);
+		}
+	}
 
 	if (bonus_str == "speed") {
-		bdata.is_speed = true;
+		bdata.type = BonusData::SPEED;
 		return;
 	}
 	else if (bonus_str == "attack_speed") {
-		bdata.is_attack_speed = true;
+		bdata.type = BonusData::ATTACK_SPEED;
 		return;
 	}
 
-	for (int i=0; i<Stats::COUNT; ++i) {
+	// TODO deprecated
+	if (bonus_str == "hp_percent") {
+		infile.error("ItemManager: 'hp_percent' is deprecated. Converting to 'hp'.");
+		bdata.type = BonusData::STAT;
+		bdata.index = Stats::HP_MAX;
+		bdata.is_multiplier = true;
+		bdata.value = (bdata.value + 100) / 100;
+		return;
+	}
+	else if (bonus_str == "mp_percent") {
+		infile.error("ItemManager: 'mp_percent' is deprecated. Converting to 'mp'.");
+		bdata.type = BonusData::STAT;
+		bdata.index = Stats::MP_MAX;
+		bdata.is_multiplier = true;
+		bdata.value = (bdata.value + 100) / 100;
+		return;
+	}
+
+	for (size_t i = 0; i < Stats::COUNT; ++i) {
 		if (bonus_str == Stats::KEY[i]) {
-			bdata.stat_index = static_cast<Stats::STAT>(i);
+			bdata.type = BonusData::STAT;
+			bdata.index = i;
 			return;
 		}
 	}
 
 	for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
 		if (bonus_str == eset->damage_types.list[i].min) {
-			bdata.damage_index_min = static_cast<int>(i);
+			bdata.type = BonusData::DAMAGE_MIN;
+			bdata.index = i;
 			return;
 		}
 		else if (bonus_str == eset->damage_types.list[i].max) {
-			bdata.damage_index_max = static_cast<int>(i);
+			bdata.type = BonusData::DAMAGE_MAX;
+			bdata.index = i;
 			return;
 		}
 	}
 
-	for (unsigned i=0; i<eset->elements.list.size(); ++i) {
+	for (size_t i = 0; i < eset->elements.list.size(); ++i) {
 		if (bonus_str == eset->elements.list[i].resist_id) {
-			bdata.resist_index = i;
+			bdata.type = BonusData::RESIST_ELEMENT;
+			bdata.index = i;
 			return;
 		}
 	}
 
 	for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 		if (bonus_str == eset->primary_stats.list[i].id) {
-			bdata.base_index = static_cast<int>(i);
+			bdata.type = BonusData::PRIMARY_STAT;
+			bdata.index = i;
+			if (bdata.is_multiplier) {
+				// primary stat bonus can't be multipliers. Re-parse as standard bonus
+				bdata.is_multiplier = false;
+				bdata.value = Parse::toFloat(bonus_value_str);
+				infile.error("ItemManager: Primary stat bonus can't be percentage.");
+			}
 			return;
 		}
 	}
 
+	for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+		for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+			if (bonus_str == eset->resource_stats.list[i].ids[j]) {
+				bdata.type = BonusData::RESOURCE_STAT;
+				bdata.index = i;
+				bdata.sub_index = j;
+				return;
+			}
+		}
+	}
+
 	infile.error("ItemManager: Unknown bonus type '%s'.", bonus_str.c_str());
 }
 
 void ItemManager::getBonusString(std::stringstream& ss, BonusData* bdata) {
-	if (bdata->is_speed) {
-		ss << msg->get("%d%% Speed", bdata->value);
+	if (bdata->type == BonusData::SPEED) {
+		ss << msg->getv("%s%% Speed", Utils::floatToString(bdata->value, eset->number_format.item_tooltips).c_str());
 		return;
 	}
-	else if (bdata->is_attack_speed) {
-		ss << msg->get("%d%% Attack Speed", bdata->value);
+	else if (bdata->type == BonusData::ATTACK_SPEED) {
+		ss << msg->getv("%s%% Attack Speed", Utils::floatToString(bdata->value, eset->number_format.item_tooltips).c_str());
 		return;
 	}
 
-	if (bdata->value > 0)
-		ss << "+" << bdata->value;
+	if (bdata->is_multiplier)
+		ss << Utils::floatToString(bdata->value, eset->number_format.item_tooltips + 2) << "×";
+	else if (bdata->value > 0)
+		ss << "+" << Utils::floatToString(bdata->value, eset->number_format.item_tooltips);
 	else
-		ss << bdata->value;
+		ss << Utils::floatToString(bdata->value, eset->number_format.item_tooltips);
 
-	if (bdata->stat_index != -1) {
-		if (Stats::PERCENT[bdata->stat_index])
+	if (bdata->type == BonusData::STAT) {
+		if (!bdata->is_multiplier && Stats::PERCENT[bdata->index])
 			ss << "%";
 
-		ss << " " << Stats::NAME[bdata->stat_index];
+		ss << " " << Stats::NAME[bdata->index];
 	}
-	else if (bdata->damage_index_min != -1) {
-		ss << " " << eset->damage_types.list[bdata->damage_index_min].name_min;
+	else if (bdata->type == BonusData::DAMAGE_MIN) {
+		ss << " " << eset->damage_types.list[bdata->index].name_min;
 	}
-	else if (bdata->damage_index_max != -1) {
-		ss << " " << eset->damage_types.list[bdata->damage_index_max].name_max;
+	else if (bdata->type == BonusData::DAMAGE_MAX) {
+		ss << " " << eset->damage_types.list[bdata->index].name_max;
 	}
-	else if (bdata->resist_index != -1) {
-		ss << "% " << msg->get("Resistance (%s)", eset->elements.list[bdata->resist_index].name);
+	else if (bdata->type == BonusData::RESIST_ELEMENT) {
+		if (!bdata->is_multiplier)
+			ss << "%";
+
+		ss << " " << msg->getv("Resistance (%s)", eset->elements.list[bdata->index].name.c_str());
 	}
-	else if (bdata->base_index > -1 && static_cast<size_t>(bdata->base_index) < eset->primary_stats.list.size()) {
-		ss << " " << eset->primary_stats.list[bdata->base_index].name;
+	else if (bdata->type == BonusData::PRIMARY_STAT) {
+		ss << " " << eset->primary_stats.list[bdata->index].name;
 	}
 	else if (powers && bdata->power_id > 0) {
 		ss << " " << powers->powers[bdata->power_id].name;
 		if (menu && menu->pow) {
 			std::string req_str = menu->pow->getItemBonusPowerReqString(bdata->power_id);
 			if (!req_str.empty())
-				ss << " (" << msg->get("Requires %s", req_str) << ")";
+				ss << " (" << msg->getv("Requires %s", req_str.c_str()) << ")";
 		}
 	}
+	else if (bdata->type == BonusData::RESOURCE_STAT) {
+		ss << " " << eset->resource_stats.list[bdata->index].text[bdata->sub_index];
+	}
 }
 
 void ItemManager::playSound(ItemID item, const Point& pos) {
@@ -747,7 +805,7 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 
 	// level
 	if (items[stack.item].level != 0) {
-		tip.addText(msg->get("Level %d", items[stack.item].level));
+		tip.addText(msg->getv("Level %d", items[stack.item].level));
 	}
 
 	// type
@@ -760,7 +818,7 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 		color = font->getColor(FontEngine::COLOR_WIDGET_NORMAL);
 		for (size_t i=0; i<item_qualities.size(); ++i) {
 			if (item_qualities[i].id == items[stack.item].quality) {
-				tip.addColoredText(msg->get("Quality: %s", msg->get(item_qualities[i].name)), color);
+				tip.addColoredText(msg->getv("Quality: %s", msg->get(item_qualities[i].name).c_str()), color);
 				break;
 			}
 		}
@@ -768,26 +826,32 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 
 	// damage
 	for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
-		if (items[stack.item].dmg_max[i] > 0) {
+		if (items[stack.item].base_dmg[i].max > 0) {
 			std::stringstream dmg_str;
 			dmg_str << eset->damage_types.list[i].name;
-			if (items[stack.item].dmg_min[i] < items[stack.item].dmg_max[i]) {
-				dmg_str << ": " << items[stack.item].dmg_min[i] << "-" << items[stack.item].dmg_max[i];
+			if (items[stack.item].base_dmg[i].min < items[stack.item].base_dmg[i].max) {
+				dmg_str << ": " << Utils::floatToString(items[stack.item].base_dmg[i].min, eset->number_format.item_tooltips) << "-" << Utils::floatToString(items[stack.item].base_dmg[i].max, eset->number_format.item_tooltips);
 				tip.addText(dmg_str.str());
 			}
 			else {
-				dmg_str << ": " << items[stack.item].dmg_max[i];
+				dmg_str << ": " << Utils::floatToString(items[stack.item].base_dmg[i].max, eset->number_format.item_tooltips);
 				tip.addText(dmg_str.str());
 			}
 		}
 	}
 
 	// absorb
-	if (items[stack.item].abs_max > 0) {
-		if (items[stack.item].abs_min < items[stack.item].abs_max)
-			tip.addText(msg->get("Absorb: %d-%d", items[stack.item].abs_min, items[stack.item].abs_max));
-		else
-			tip.addText(msg->get("Absorb: %d", items[stack.item].abs_max));
+	if (items[stack.item].base_abs.max > 0) {
+		std::stringstream abs_str;
+		abs_str << msg->get("Absorb");
+		if (items[stack.item].base_abs.min < items[stack.item].base_abs.max) {
+			abs_str << ": " << Utils::floatToString(items[stack.item].base_abs.min, eset->number_format.item_tooltips) << "-" << Utils::floatToString(items[stack.item].base_abs.max, eset->number_format.item_tooltips);
+			tip.addText(abs_str.str());
+		}
+		else {
+			abs_str << ": " << Utils::floatToString(items[stack.item].base_abs.max, eset->number_format.item_tooltips);
+			tip.addText(abs_str.str());
+		}
 	}
 
 	// bonuses
@@ -797,12 +861,18 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 
 		BonusData* bdata = &items[stack.item].bonus[bonus_counter];
 
-		if (bdata->is_speed || bdata->is_attack_speed) {
+		if (bdata->type == BonusData::SPEED || bdata->type == BonusData::ATTACK_SPEED) {
 			if (bdata->value >= 100)
 				color = font->getColor(FontEngine::COLOR_ITEM_BONUS);
 			else
 				color = font->getColor(FontEngine::COLOR_ITEM_PENALTY);
 		}
+		else if (bdata->is_multiplier) {
+			if (bdata->value >= 1)
+				color = font->getColor(FontEngine::COLOR_ITEM_BONUS);
+			else
+				color = font->getColor(FontEngine::COLOR_ITEM_PENALTY);
+		}
 		else {
 			if (bdata->value > 0)
 				color = font->getColor(FontEngine::COLOR_ITEM_BONUS);
@@ -827,18 +897,19 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 		else
 			color = font->getColor(FontEngine::COLOR_WIDGET_NORMAL);
 
-		tip.addColoredText(msg->get("Requires Level %d", items[stack.item].requires_level), color);
+		tip.addColoredText(msg->getv("Requires Level %d", items[stack.item].requires_level), color);
 	}
 
 	// base stat requirement
-	for (unsigned i=0; i<items[stack.item].req_stat.size(); ++i) {
-		if (items[stack.item].req_val[i] > 0) {
-			if (stats->get_primary(items[stack.item].req_stat[i]) < items[stack.item].req_val[i])
+	std::map<size_t, int>::iterator it;
+	for (it = items[stack.item].requires_stat.begin(); it != items[stack.item].requires_stat.end(); ++it) {
+		if (it->second > 0) {
+			if (stats->get_primary(it->first) < it->second)
 				color = font->getColor(FontEngine::COLOR_REQUIREMENTS_NOT_MET);
 			else
 				color = font->getColor(FontEngine::COLOR_WIDGET_NORMAL);
 
-			tip.addColoredText(msg->get("Requires %s %d", eset->primary_stats.list[items[stack.item].req_stat[i]].name, items[stack.item].req_val[i]), color);
+			tip.addColoredText(msg->getv("Requires %s %d", eset->primary_stats.list[it->first].name.c_str(), it->second), color);
 		}
 	}
 
@@ -849,7 +920,7 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 		else
 			color = font->getColor(FontEngine::COLOR_WIDGET_NORMAL);
 
-		tip.addColoredText(msg->get("Requires Class: %s", msg->get(items[stack.item].requires_class)), color);
+		tip.addColoredText(msg->getv("Requires Class: %s", msg->get(items[stack.item].requires_class).c_str()), color);
 	}
 
 	// buy or sell price
@@ -865,9 +936,9 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 				color = currency_color;
 
 			if (items[stack.item].max_quantity <= 1)
-				tip.addColoredText(msg->get("Buy Price: %d %s", price_per_unit, eset->loot.currency), color);
+				tip.addColoredText(msg->getv("Buy Price: %d %s", price_per_unit, eset->loot.currency.c_str()), color);
 			else
-				tip.addColoredText(msg->get("Buy Price: %d %s each", price_per_unit, eset->loot.currency), color);
+				tip.addColoredText(msg->getv("Buy Price: %d %s each", price_per_unit, eset->loot.currency.c_str()), color);
 		}
 		else if (context == VENDOR_SELL) {
 			price_per_unit = items[stack.item].getSellPrice(stack.can_buyback);
@@ -877,9 +948,9 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 				color = currency_color;
 
 			if (items[stack.item].max_quantity <= 1)
-				tip.addColoredText(msg->get("Buy Price: %d %s", price_per_unit, eset->loot.currency), color);
+				tip.addColoredText(msg->getv("Buy Price: %d %s", price_per_unit, eset->loot.currency.c_str()), color);
 			else
-				tip.addColoredText(msg->get("Buy Price: %d %s each", price_per_unit, eset->loot.currency), color);
+				tip.addColoredText(msg->getv("Buy Price: %d %s each", price_per_unit, eset->loot.currency.c_str()), color);
 		}
 		else if (context == PLAYER_INV) {
 			price_per_unit = items[stack.item].getSellPrice(DEFAULT_SELL_PRICE);
@@ -887,9 +958,9 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 				price_per_unit = 1;
 
 			if (items[stack.item].max_quantity <= 1)
-				tip.addColoredText(msg->get("Sell Price: %d %s", price_per_unit, eset->loot.currency), currency_color);
+				tip.addColoredText(msg->getv("Sell Price: %d %s", price_per_unit, eset->loot.currency.c_str()), currency_color);
 			else
-				tip.addColoredText(msg->get("Sell Price: %d %s each", price_per_unit, eset->loot.currency), currency_color);
+				tip.addColoredText(msg->getv("Sell Price: %d %s each", price_per_unit, eset->loot.currency.c_str()), currency_color);
 		}
 	}
 
@@ -907,7 +978,7 @@ TooltipData ItemManager::getTooltip(ItemStack stack, StatBlock *stats, int conte
 
 			SetBonusData* bdata = &set.bonus[bonus_counter];
 
-			ss << msg->get("%d items:", bdata->requirement) << ' ';
+			ss << msg->getv("%d items:", bdata->requirement) << ' ';
 
 			getBonusString(ss, bdata);
 			if (bdata->requirement <= set_count)
@@ -964,14 +1035,14 @@ void ItemManager::getTooltipInputHint(TooltipData& tip, ItemStack stack, int con
 	// input hint for consumables/books
 	if (show_activate_msg) {
 		if (!items[stack.item].book.empty() && items[stack.item].book_is_readable) {
-			tip.addColoredText(msg->get("Press [%s] to read", activate_bind_str), font->getColor(FontEngine::COLOR_ITEM_BONUS));
+			tip.addColoredText(msg->getv("Press [%s] to read", activate_bind_str.c_str()), font->getColor(FontEngine::COLOR_ITEM_BONUS));
 		}
 		else if (menu->inv->canActivateItem(stack.item)) {
-			tip.addColoredText(msg->get("Press [%s] to use", activate_bind_str), font->getColor(FontEngine::COLOR_ITEM_BONUS));
+			tip.addColoredText(msg->getv("Press [%s] to use", activate_bind_str.c_str()), font->getColor(FontEngine::COLOR_ITEM_BONUS));
 		}
 	}
 	if (show_more_msg) {
-		tip.addColoredText(msg->get("Press [%s] for more options", more_bind_str), font->getColor(FontEngine::COLOR_ITEM_BONUS));
+		tip.addColoredText(msg->getv("Press [%s] for more options", more_bind_str.c_str()), font->getColor(FontEngine::COLOR_ITEM_BONUS));
 	}
 }
 
@@ -987,8 +1058,9 @@ bool ItemManager::requirementsMet(const StatBlock *stats, ItemID item) {
 	}
 
 	// base stats
-	for (unsigned i=0; i < items[item].req_stat.size(); ++i) {
-		if (stats->get_primary(items[item].req_stat[i]) < items[item].req_val[i])
+	std::map<size_t, int>::iterator it;
+	for (it = items[item].requires_stat.begin(); it != items[item].requires_stat.end(); ++it) {
+		if (stats->get_primary(it->first) < it->second)
 			return false;
 	}
 
