@@ -1,6 +1,7 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
 Copyright © 2012 Stefan Beller
+Copyright © 2013-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -16,15 +17,15 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
-#pragma once
 #ifndef LOOT_H
 #define LOOT_H
 
 #include "CommonIncludes.h"
 #include "ItemManager.h"
-#include "Settings.h"
 #include "TooltipData.h"
 
+class WidgetTooltip;
+
 class Loot {
 private:
 	std::string gfx;
@@ -34,13 +35,18 @@ public:
 	FPoint pos;
 	Animation *animation;
 	TooltipData tip;
+	WidgetTooltip *wtip;
+	bool tip_visible;
+	bool dropped_by_hero;
+	bool on_ground;
+	bool sound_played;
 
 	Loot();
 	Loot(const Loot &other);
 	Loot& operator= (const Loot &other);
 	~Loot();
 
-	void loadAnimation(std::string _gfx);
+	void loadAnimation(const std::string& _gfx);
 
 	/**
 	 * If an item is flying, it hasn't completed its "flying loot" animation.
