@@ -136,7 +136,7 @@ int Map::load(const std::string& fname) {
 		EventComponent *ec_power = events[i].getComponent(EventComponent::POWER);
 		if (ec_power) {
 			// store the index of this StatBlock so that we can find it when the event is activated
-			ec_power->x = addEventStatBlock(events[i]);
+			ec_power->data[0].Int = addEventStatBlock(events[i]);
 		}
 	}
 
@@ -325,9 +325,8 @@ void Map::loadEnemyGroup(FileParser &infile, Map_Group *group) {
 		group->numbermax = std::max(std::max(0, Parse::toInt(Parse::popFirstString(infile.val))), group->numbermin);
 	}
 	else if (infile.key == "chance") {
-		// @ATTR enemygroup.chance|int|Percentage of chance
-		float n = static_cast<float>(std::max(0, Parse::popFirstInt(infile.val))) / 100.0f;
-		group->chance = std::min(1.0f, std::max(0.0f, n));
+		// @ATTR enemygroup.chance|float|Initial percentage chance that this enemy group will be able to spawn enemies.
+		group->chance = std::min(100.0f, std::max(0.0f, Parse::popFirstFloat(infile.val)));
 	}
 	else if (infile.key == "direction") {
 		// @ATTR enemygroup.direction|direction|Direction that enemies will initially face.
@@ -384,28 +383,28 @@ void Map::loadEnemyGroup(FileParser &infile, Map_Group *group) {
 		// @ATTR enemygroup.requires_level|int|Player level must be equal or greater to load enemy group
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_LEVEL;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		group->requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_not_level") {
 		// @ATTR enemygroup.requires_not_level|int|Player level must be lesser to load enemy group
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_NOT_LEVEL;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		group->requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_currency") {
 		// @ATTR enemygroup.requires_currency|int|Player currency must be equal or greater to load enemy group
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_CURRENCY;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		group->requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_not_currency") {
 		// @ATTR enemygroup.requires_not_currency|int|Player currency must be lesser to load enemy group
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_NOT_CURRENCY;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		group->requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_item") {
@@ -416,7 +415,7 @@ void Map::loadEnemyGroup(FileParser &infile, Map_Group *group) {
 			EventComponent ec;
 			ec.type = EventComponent::REQUIRES_ITEM;
 			ec.id = item_stack.item;
-			ec.x = item_stack.quantity;
+			ec.data[0].Int = item_stack.quantity;
 			group->requirements.push_back(ec);
 		}
 	}
@@ -428,7 +427,7 @@ void Map::loadEnemyGroup(FileParser &infile, Map_Group *group) {
 			EventComponent ec;
 			ec.type = EventComponent::REQUIRES_NOT_ITEM;
 			ec.id = item_stack.item;
-			ec.x = item_stack.quantity;
+			ec.data[0].Int = item_stack.quantity;
 			group->requirements.push_back(ec);
 		}
 	}
@@ -466,6 +465,35 @@ void Map::loadEnemyGroup(FileParser &infile, Map_Group *group) {
 			group->invincible_requirements.push_back(ec);
 		}
 	}
+	else if (infile.key == "spawn_level") {
+		// @ATTR enemygroup.spawn_level|["default", "fixed", "level", "stat"], int, int, predefined_string : Mode, Enemy Level, Ratio, Primary stat|The level of spawned creatures. The need for the last three parameters depends on the mode being used. The "default" mode will just use the entity's normal level and doesn't require any additional parameters. The "fixed" mode only requires the enemy level as a parameter. The "stat" and "level" modes also require the ratio as a parameter. The ratio adjusts the scaling of the entity level. For example, spawn_level=stat,1,2,physical will set the spawned entity level to 1/2 the player's Physical stat. Only the "stat" mode requires the last parameter, which is simply the ID of the primary stat that should be used for scaling.
+		std::string mode = Parse::popFirstString(infile.val);
+		if (mode == "default") group->spawn_level.mode = SpawnLevel::MODE_DEFAULT;
+		else if (mode == "fixed") group->spawn_level.mode = SpawnLevel::MODE_FIXED;
+		else if (mode == "stat") group->spawn_level.mode = SpawnLevel::MODE_STAT;
+		else if (mode == "level") group->spawn_level.mode = SpawnLevel::MODE_LEVEL;
+		else infile.error("Map: Unknown spawn level mode '%s'", mode.c_str());
+
+		if (group->spawn_level.mode != SpawnLevel::MODE_DEFAULT) {
+			group->spawn_level.count = static_cast<float>(Parse::popFirstInt(infile.val));
+
+			if(group->spawn_level.mode != SpawnLevel::MODE_FIXED) {
+				group->spawn_level.ratio = Parse::popFirstFloat(infile.val);
+
+				if(group->spawn_level.mode == SpawnLevel::MODE_STAT) {
+					std::string stat = Parse::popFirstString(infile.val);
+					size_t prim_stat_index = eset->primary_stats.getIndexByID(stat);
+
+					if (prim_stat_index != eset->primary_stats.list.size()) {
+						group->spawn_level.stat = prim_stat_index;
+					}
+					else {
+						infile.error("Map: '%s' is not a valid primary stat.", stat.c_str());
+					}
+				}
+			}
+		}
+	}
 	else {
 		infile.error("Map: '%s' is not a valid key.", infile.key.c_str());
 	}
@@ -509,28 +537,28 @@ void Map::loadNPC(FileParser &infile) {
 		// @ATTR npc.requires_level|int|Player level must be equal or greater to load NPC
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_LEVEL;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		map_npcs.back().requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_not_level") {
 		// @ATTR npc.requires_not_level|int|Player level must be lesser to load NPC
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_NOT_LEVEL;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		map_npcs.back().requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_currency") {
 		// @ATTR npc.requires_currency|int|Player currency must be equal or greater to load NPC
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_CURRENCY;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		map_npcs.back().requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_not_currency") {
 		// @ATTR npc.requires_not_currency|int|Player currency must be lesser to load NPC
 		EventComponent ec;
 		ec.type = EventComponent::REQUIRES_NOT_CURRENCY;
-		ec.x = Parse::popFirstInt(infile.val);
+		ec.data[0].Int = Parse::popFirstInt(infile.val);
 		map_npcs.back().requirements.push_back(ec);
 	}
 	else if (infile.key == "requires_item") {
@@ -541,7 +569,7 @@ void Map::loadNPC(FileParser &infile) {
 			EventComponent ec;
 			ec.type = EventComponent::REQUIRES_ITEM;
 			ec.id = item_stack.item;
-			ec.x = item_stack.quantity;
+			ec.data[0].Int = item_stack.quantity;
 			map_npcs.back().requirements.push_back(ec);
 		}
 	}
@@ -553,7 +581,7 @@ void Map::loadNPC(FileParser &infile) {
 			EventComponent ec;
 			ec.type = EventComponent::REQUIRES_NOT_ITEM;
 			ec.id = item_stack.item;
-			ec.x = item_stack.quantity;
+			ec.data[0].Int = item_stack.quantity;
 			map_npcs.back().requirements.push_back(ec);
 		}
 	}
@@ -589,8 +617,8 @@ int Map::addEventStatBlock(Event &evnt) {
 	EventComponent *ec_path = evnt.getComponent(EventComponent::POWER_PATH);
 	if (ec_path) {
 		// source is power path start
-		statb->pos.x = static_cast<float>(ec_path->x) + 0.5f;
-		statb->pos.y = static_cast<float>(ec_path->y) + 0.5f;
+		statb->pos.x = static_cast<float>(ec_path->data[0].Int) + 0.5f;
+		statb->pos.y = static_cast<float>(ec_path->data[1].Int) + 0.5f;
 	}
 	else {
 		// source is event location
@@ -602,10 +630,10 @@ int Map::addEventStatBlock(Event &evnt) {
 	if (ec_damage) {
 		for (size_t i = 0; i < eset->damage_types.count; ++i) {
 			if (i % 2 == 0) {
-				statb->starting[Stats::COUNT + i] = ec_damage->x; // min
+				statb->starting[Stats::COUNT + i] = ec_damage->data[0].Float; // min
 			}
 			else {
-				statb->starting[Stats::COUNT + i] = ec_damage->y; // max
+				statb->starting[Stats::COUNT + i] = ec_damage->data[1].Float; // max
 			}
 		}
 	}
@@ -619,8 +647,13 @@ int Map::addEventStatBlock(Event &evnt) {
 	// create a temporary EffectDef for immunity; will be used for map StatBlocks
 	EffectDef immunity_effect;
 	immunity_effect.id = "MAP_EVENT_IMMUNITY";
-	immunity_effect.type = Effect::IMMUNITY;
-	statb->effects.addEffect(immunity_effect, 0, 0, Power::SOURCE_TYPE_ENEMY, EffectManager::NO_POWER);
+	immunity_effect.type = Effect::RESIST_ALL;
+
+	EffectParams immunity_params;
+	immunity_params.magnitude = 100;
+	immunity_params.source_type = Power::SOURCE_TYPE_ENEMY;
+
+	statb->effects.addEffect(statb, immunity_effect, immunity_params);
 
 	// ensure the statblock will be alive
 	statb->hp = statb->starting[Stats::HP_MAX] = statb->current[Stats::HP_MAX] = 1;
