@@ -116,6 +116,8 @@ bool MapRenderer::enemyGroupPlaceEnemy(float x, float y, const Map_Group &g) {
 				group_member.waypoints = g.waypoints;
 			}
 
+			group_member.spawn_level = g.spawn_level;
+
 			enemies.push(group_member);
 		}
 		return true;
@@ -125,8 +127,7 @@ bool MapRenderer::enemyGroupPlaceEnemy(float x, float y, const Map_Group &g) {
 
 void MapRenderer::pushEnemyGroup(Map_Group &g) {
 	// activate at all?
-	float activate_chance = static_cast<float>(rand() % 100) / 100.0f;
-	if (activate_chance > g.chance) {
+	if (!Math::percentChanceF(g.chance)) {
 		return;
 	}
 
@@ -1208,7 +1209,7 @@ void MapRenderer::checkHotspots() {
 				if (npc) {
 					is_npc = true;
 
-					Point p = Utils::mapToScreen(float(npc->x), float(npc->y), cam.shake.x, cam.shake.y);
+					Point p = Utils::mapToScreen(float(npc->data[0].Int), float(npc->data[1].Int), cam.shake.x, cam.shake.y);
 					p = centerTile(p);
 
 					Rect dest;
