@@ -56,7 +56,7 @@ private:
 
 	void drawRenderable(std::vector<Renderable>::iterator r_cursor);
 
-	void renderIsoLayer(const Map_Layer& layerdata);
+	void renderIsoLayer(const Map_Layer& layerdata, const TileSet& tile_set);
 
 	// renders only objects
 	void renderIsoBackObjects(std::vector<Renderable> &r);
@@ -65,7 +65,7 @@ private:
 	void renderIsoFrontObjects(std::vector<Renderable> &r);
 	void renderIso(std::vector<Renderable> &r, std::vector<Renderable> &r_dead);
 
-	void renderOrthoLayer(const Map_Layer& layerdata);
+	void renderOrthoLayer(const Map_Layer& layerdata, const TileSet& tile_set);
 	void renderOrthoBackObjects(std::vector<Renderable> &r);
 	void renderOrthoFrontObjects(std::vector<Renderable> &r);
 	void renderOrtho(std::vector<Renderable> &r, std::vector<Renderable> &r_dead);
