@@ -238,23 +238,23 @@ void MenuActionBar::align() {
 	// set keybinding labels
 	for (unsigned i = 0; i < static_cast<unsigned>(SLOT_MAIN1); i++) {
 		if (i < slots.size() && slots[i]) {
-			labels[i] = msg->get("Hotkey: %s", inpt->getBindingString(i + Input::BAR_1));
+			labels[i] = msg->getv("Hotkey: %s", inpt->getBindingString(i + Input::BAR_1).c_str());
 		}
 	}
 
 	for (unsigned i = SLOT_MAIN1; i < static_cast<unsigned>(SLOT_MAX); i++) {
 		if (i < slots.size() && slots[i]) {
 			if (settings->mouse_move && ((i == SLOT_MAIN2 && settings->mouse_move_swap) || (i == SLOT_MAIN1 && !settings->mouse_move_swap))) {
-				labels[i] = msg->get("Hotkey: %s", inpt->getBindingString(Input::SHIFT) + " + " + inpt->getBindingString(i - SLOT_MAIN1 + Input::MAIN1));
+				labels[i] = msg->getv("Hotkey: %s", std::string(inpt->getBindingString(Input::SHIFT) + " + " + inpt->getBindingString(i - SLOT_MAIN1 + Input::MAIN1)).c_str());
 			}
 			else {
-				labels[i] = msg->get("Hotkey: %s", inpt->getBindingString(i - SLOT_MAIN1 + Input::MAIN1));
+				labels[i] = msg->getv("Hotkey: %s", inpt->getBindingString(i - SLOT_MAIN1 + Input::MAIN1).c_str());
 			}
 		}
 	}
 	for (unsigned i=0; i<menu_labels.size(); i++) {
 		menus[i]->setPos(window_area.x, window_area.y);
-		menu_labels[i] = msg->get("Hotkey: %s", inpt->getBindingString(i + Input::CHARACTER));
+		menu_labels[i] = msg->getv("Hotkey: %s", inpt->getBindingString(i + Input::CHARACTER).c_str());
 	}
 }
 
@@ -633,13 +633,25 @@ void MenuActionBar::checkAction(std::vector<ActionData> &action_queue) {
 		if (action.power > 0) {
 			const Power& power = powers->powers[action.power];
 
+			bool not_enough_resources = false;
 			if (pc->stats.mp < power.requires_mp && slot_fail_cooldown[i] == 0) {
-				slot_fail_cooldown[i] = settings->max_frames_per_sec;
 				pc->logMsg(msg->get("Not enough MP."), Avatar::MSG_NORMAL);
+				not_enough_resources = true;
+			}
+			for (size_t j = 0; j < eset->resource_stats.list.size(); ++j) {
+				if (pc->stats.resource_stats[j] < power.requires_resource_stat[j] && slot_fail_cooldown[i] == 0) {
+					pc->logMsg(eset->resource_stats.list[j].text_log_low, Avatar::MSG_NORMAL);
+					not_enough_resources = true;
+				}
+			}
+
+			if (not_enough_resources) {
+				slot_fail_cooldown[i] = settings->max_frames_per_sec;
 				snd->play(sfx_unable_to_cast, "ACT_NO_MP", snd->NO_POS, !snd->LOOP);
 				continue;
 			}
-			else if (!slot_enabled[i]) {
+
+			if (!slot_enabled[i]) {
 				continue;
 			}
 
@@ -754,10 +766,6 @@ void MenuActionBar::set(std::vector<PowerID> power_id, bool skip_empty) {
 	updated = true;
 }
 
-void MenuActionBar::resetSlots() {
-	// TODO remove
-}
-
 /**
  * Set a target depending on how a power was triggered
  */
