@@ -121,7 +121,7 @@ void MenuActiveEffects::logic() {
 					effect_icons[most_recent_id].stacksLabel->setMaxWidth(eset->resolutions.icon_size);
 				}
 
-				effect_icons[most_recent_id].stacksLabel->setText(msg->get("x%d", effect_icons[most_recent_id].stacks));
+				effect_icons[most_recent_id].stacksLabel->setText(msg->getv("x%d", effect_icons[most_recent_id].stacks));
 
 				continue;
 			}
@@ -149,9 +149,9 @@ void MenuActiveEffects::logic() {
 		ei.overlay.w = eset->resolutions.icon_size;
 
 		if (ed.type == Effect::SHIELD) {
-			ei.overlay.y = (eset->resolutions.icon_size * ed.magnitude) / ed.magnitude_max;
-			ei.current = ed.magnitude;
-			ei.max = ed.magnitude_max;
+			ei.overlay.y = static_cast<int>((eset->resolutions.icon_size * ed.magnitude) / ed.magnitude_max);
+			ei.current = static_cast<int>(ed.magnitude);
+			ei.max = static_cast<int>(ed.magnitude_max);
 		}
 		else if (ed.type == Effect::HEAL) {
 			ei.overlay.y = eset->resolutions.icon_size;
@@ -216,13 +216,13 @@ void MenuActiveEffects::renderTooltips(const Point& position) {
 				tip_data.addText(ss.str());
 			}
 			else if (effect_icons[i].max > 0) {
-				ss << msg->get("Remaining:") << " " << Utils::getDurationString(effect_icons[i].current, 1);
+				ss << msg->get("Remaining:") << " " << Utils::getDurationString(effect_icons[i].current, eset->number_format.durations);
 				tip_data.addText(ss.str());
 			}
 
 			if(effect_icons[i].type != Effect::SHIELD){
 				if(effect_icons[i].stacks > 1){
-					tip_data.addText(msg->get("x%d stacks", effect_icons[i].stacks));
+					tip_data.addText(msg->getv("x%d stacks", effect_icons[i].stacks));
 				}
 			}
 
