@@ -81,14 +81,15 @@ MenuCharacter::MenuCharacter()
 		cstat[i+2].label->setText(eset->primary_stats.list[i].name);
 	}
 
-	show_stat.resize(Stats::COUNT + eset->damage_types.count + eset->elements.list.size());
+	show_stat.resize(Stats::COUNT + eset->damage_types.count + eset->elements.list.size() + eset->resource_stats.stat_count);
 	for (size_t i = 0; i < Stats::COUNT + eset->damage_types.count + eset->elements.list.size(); i++) {
 		show_stat[i] = true;
 	}
 
-	// these two are hidden by default, as they are currently unused
-	show_stat[Stats::HP_PERCENT] = false;
-	show_stat[Stats::MP_PERCENT] = false;
+	// some stats are hidden by default
+	for (int i = Stats::RESIST_DAMAGE_OVER_TIME; i < Stats::COUNT; ++i) {
+		show_stat[i] = false;
+	}
 
 	// Upgrade buttons
 	primary_up.resize(eset->primary_stats.list.size());
@@ -189,27 +190,7 @@ MenuCharacter::MenuCharacter()
 
 			// @ATTR show_stat|stat_id, bool : Stat ID, Visible|Hide the matching stat ID in the statlist if set to false.
 			else if (infile.key == "show_stat") {
-				std::string stat_name = Parse::popFirstString(infile.val);
-
-				for (int i=0; i<Stats::COUNT; ++i) {
-					if (stat_name == Stats::KEY[i]) {
-						show_stat[i] = Parse::toBool(Parse::popFirstString(infile.val));
-						break;
-					}
-				}
-				for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
-					if (stat_name == eset->damage_types.list[i].min) {
-						show_stat[Stats::COUNT + (i*2)] = Parse::toBool(Parse::popFirstString(infile.val));
-					}
-					else if (stat_name == eset->damage_types.list[i].max) {
-						show_stat[Stats::COUNT + (i*2) + 1] = Parse::toBool(Parse::popFirstString(infile.val));
-					}
-				}
-				for (size_t i = 0; i < eset->elements.list.size(); ++i) {
-					if (stat_name == eset->elements.list[i].resist_id) {
-						show_stat[Stats::COUNT + eset->damage_types.count + i] = Parse::toBool(Parse::popFirstString(infile.val));
-					}
-				}
+				parseShowStat(infile);
 			}
 
 			// @ATTR name_max_width|int|The maxiumum width, in pixels, that the character name can occupy until it is abbreviated.
@@ -312,7 +293,7 @@ void MenuCharacter::refreshStats() {
 	}
 
 	if (skill_points >= 1) {
-		labelUnspent->setText(msg->get("Available stat points: %d", skill_points));
+		labelUnspent->setText(msg->getv("Available stat points: %d", skill_points));
 	}
 	else {
 		labelUnspent->setText("");
@@ -320,16 +301,32 @@ void MenuCharacter::refreshStats() {
 
 	// scrolling stat list
 	unsigned stat_index = 0;
+	size_t resource_offset_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+
 	for (int i=0; i<Stats::COUNT; ++i) {
 		if (!show_stat[i]) continue;
 
+		// insert resource stats (execpt stealing) before accuracy
+		if (i == Stats::ACCURACY) {
+			for (size_t j = 0; j < eset->resource_stats.list.size(); ++j) {
+				for (size_t k = 0; k < EngineSettings::ResourceStats::STAT_STEAL; ++k) {
+					if (show_stat[resource_offset_index + (j * EngineSettings::ResourceStats::STAT_COUNT) + k]) {
+						ss.str("");
+						ss << eset->resource_stats.list[j].text[k] << ": " << Utils::floatToString(pc->stats.getResourceStat(j, k), eset->number_format.character_menu);
+						statList->set(stat_index, ss.str(), resourceStatTooltip(j, k));
+						stat_index++;
+					}
+				}
+			}
+		}
+
 		// insert damage stats before absorb min
 		if (i == Stats::ABS_MIN) {
 			for (size_t j = 0; j < eset->damage_types.list.size(); ++j) {
 				if (show_stat[Stats::COUNT + (j*2)]) {
 					// min
 					ss.str("");
-					ss << eset->damage_types.list[j].name_min << ": " << pc->stats.getDamageMin(j);
+					ss << eset->damage_types.list[j].name_min << ": " << Utils::floatToString(pc->stats.getDamageMin(j), eset->number_format.character_menu);
 					statList->set(stat_index, ss.str(), damageTooltip(j*2));
 					stat_index++;
 				}
@@ -337,7 +334,7 @@ void MenuCharacter::refreshStats() {
 				if (show_stat[Stats::COUNT + (j*2) + 1]) {
 					// max
 					ss.str("");
-					ss << eset->damage_types.list[j].name_max << ": " << pc->stats.getDamageMax(j);
+					ss << eset->damage_types.list[j].name_max << ": " << Utils::floatToString(pc->stats.getDamageMax(j), eset->number_format.character_menu);
 					statList->set(stat_index, ss.str(), damageTooltip((j*2) + 1));
 					stat_index++;
 				}
@@ -345,20 +342,32 @@ void MenuCharacter::refreshStats() {
 		}
 
 		ss.str("");
-		ss << Stats::NAME[i] << ": " << pc->stats.get(static_cast<Stats::STAT>(i));
+		ss << Stats::NAME[i] << ": " << Utils::floatToString(pc->stats.get(static_cast<Stats::STAT>(i)), 2);
 		if (Stats::PERCENT[i]) ss << "%";
 
 		statList->set(stat_index, ss.str(), statTooltip(i));
 		stat_index++;
 	}
 
+	// insert resource stealing stats after HP/MP steal
+	for (size_t j = 0; j < eset->resource_stats.list.size(); ++j) {
+		for (size_t k = EngineSettings::ResourceStats::STAT_STEAL; k < EngineSettings::ResourceStats::STAT_COUNT; ++k) {
+			if (show_stat[resource_offset_index + (j * EngineSettings::ResourceStats::STAT_COUNT) + k]) {
+				ss.str("");
+				ss << eset->resource_stats.list[j].text[k] << ": " << Utils::floatToString(pc->stats.getResourceStat(j, k), eset->number_format.character_menu) << "%";
+				statList->set(stat_index, ss.str(), resourceStatTooltip(j, k));
+				stat_index++;
+			}
+		}
+	}
+
 	if (show_resists) {
 		for (size_t i=0; i<eset->elements.list.size(); ++i) {
 			if (!show_stat[Stats::COUNT + eset->damage_types.count + i])
 				continue;
 
 			ss.str("");
-			ss << msg->get("Resistance (%s)", eset->elements.list[i].name) << ": " << (pc->stats.getResist(i)) << "%";
+			ss << msg->getv("Resistance (%s)", eset->elements.list[i].name.c_str()) << ": " << Utils::floatToString(pc->stats.getResist(i), eset->number_format.character_menu) << "%";
 			statList->set(stat_index, ss.str(), resistTooltip(i));
 			stat_index++;
 		}
@@ -370,17 +379,38 @@ void MenuCharacter::refreshStats() {
 	cstat[CSTAT_NAME].tip.addText(pc->stats.getLongClass());
 
 	cstat[CSTAT_LEVEL].tip.clear();
-	cstat[CSTAT_LEVEL].tip.addText(msg->get("XP: %d", pc->stats.xp));
+	cstat[CSTAT_LEVEL].tip.addText(msg->getv("XP: %lu", pc->stats.xp));
 	if (pc->stats.level < eset->xp.getMaxLevel()) {
-		cstat[CSTAT_LEVEL].tip.addText(msg->get("Next: %d", eset->xp.getLevelXP(pc->stats.level + 1)));
+		cstat[CSTAT_LEVEL].tip.addText(msg->getv("Next: %lu", eset->xp.getLevelXP(pc->stats.level + 1)));
 	}
 
 	for (size_t j = 2; j < cstat.size(); ++j) {
 		cstat[j].tip.clear();
 		cstat[j].tip.addText(cstat[j].label->getText());
-		cstat[j].tip.addText(msg->get("base (%d), bonus (%d)", *(base_stats[j-2]), *(base_stats_add[j-2])));
+		cstat[j].tip.addText(msg->getv("base (%d), bonus (%d)", *(base_stats[j-2]), *(base_stats_add[j-2])));
+
 		bool have_bonus = false;
+		size_t elements_offset = Stats::COUNT + eset->damage_types.count;
+		size_t resource_stat_offset = elements_offset + eset->elements.list.size();
+
 		for (int i = 0; i < Stats::COUNT; ++i) {
+			// insert resource stats (execpt stealing) before accuracy
+			if (i == Stats::ACCURACY) {
+				for (size_t k = 0; k < eset->resource_stats.list.size(); ++k) {
+					for (size_t l = 0; l < EngineSettings::ResourceStats::STAT_STEAL; ++l) {
+						size_t resource_index = resource_stat_offset + (k * EngineSettings::ResourceStats::STAT_COUNT) + l;
+
+						if (base_bonus[j-2]->at(resource_index) > 0 && show_stat[resource_index]) {
+							if (!have_bonus) {
+								cstat[j].tip.addText("\n" + msg->get("Related stats:"));
+								have_bonus = true;
+							}
+							cstat[j].tip.addText(eset->resource_stats.list[k].text[l]);
+						}
+					}
+				}
+			}
+
 			// damage types are displayed before absorb
 			if (i == Stats::ABS_MIN) {
 				for (size_t k = 0; k < eset->damage_types.list.size(); ++k) {
@@ -413,15 +443,28 @@ void MenuCharacter::refreshStats() {
 			}
 		}
 
-		for (size_t i = 0; i < eset->elements.list.size(); ++i) {
-			size_t resist_index = Stats::COUNT + eset->damage_types.count + i;
+		// insert resource stealing stats after MP steal
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t k = EngineSettings::ResourceStats::STAT_STEAL; k < EngineSettings::ResourceStats::STAT_COUNT; ++k) {
+				size_t resource_index = resource_stat_offset + (i * EngineSettings::ResourceStats::STAT_COUNT) + k;
 
-			if (base_bonus[j-2]->at(resist_index) > 0 && show_stat[resist_index]) {
+				if (base_bonus[j-2]->at(resource_index) > 0 && show_stat[resource_index]) {
+					if (!have_bonus) {
+						cstat[j].tip.addText("\n" + msg->get("Related stats:"));
+						have_bonus = true;
+					}
+					cstat[j].tip.addText(eset->resource_stats.list[i].text[k]);
+				}
+			}
+		}
+
+		for (size_t i = 0; i < eset->elements.list.size(); ++i) {
+			if (base_bonus[j-2]->at(elements_offset + i) > 0 && show_stat[elements_offset + i]) {
 				if (!have_bonus) {
 					cstat[j].tip.addText("\n" + msg->get("Related stats:"));
 					have_bonus = true;
 				}
-				cstat[j].tip.addText(msg->get("Resistance (%s)", eset->elements.list[i].name));
+				cstat[j].tip.addText(msg->getv("Resistance (%s)", eset->elements.list[i].name.c_str()));
 			}
 		}
 	}
@@ -444,11 +487,11 @@ std::string MenuCharacter::statTooltip(int stat) {
 	std::string tooltip_text;
 
 	if (pc->stats.per_level[stat] > 0)
-		tooltip_text += msg->get("Each level grants %d.", pc->stats.per_level[stat]) + ' ';
+		tooltip_text += msg->getv("Each level grants %s.", Utils::floatToString(pc->stats.per_level[stat], eset->number_format.character_menu).c_str()) + ' ';
 
 	for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 		if (pc->stats.per_primary[i][stat] > 0)
-			tooltip_text += msg->get("Each point of %s grants %d.", eset->primary_stats.list[i].name, pc->stats.per_primary[i][stat]) + ' ';
+			tooltip_text += msg->getv("Each point of %s grants %s.", eset->primary_stats.list[i].name.c_str(), Utils::floatToString(pc->stats.per_primary[i][stat], eset->number_format.character_menu).c_str()) + ' ';
 	}
 
 	std::string full_tooltip = "";
@@ -468,11 +511,11 @@ std::string MenuCharacter::damageTooltip(size_t dmg_type) {
 	std::string tooltip_text;
 
 	if (pc->stats.per_level[Stats::COUNT + dmg_type] > 0)
-		tooltip_text += msg->get("Each level grants %d.", pc->stats.per_level[Stats::COUNT + dmg_type]) + ' ';
+		tooltip_text += msg->getv("Each level grants %s.", Utils::floatToString(pc->stats.per_level[Stats::COUNT + dmg_type], eset->number_format.character_menu).c_str()) + ' ';
 
 	for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 		if (pc->stats.per_primary[i][Stats::COUNT + dmg_type] > 0)
-			tooltip_text += msg->get("Each point of %s grants %d.", eset->primary_stats.list[i].name, pc->stats.per_primary[i][Stats::COUNT + dmg_type]) + ' ';
+			tooltip_text += msg->getv("Each point of %s grants %s.", eset->primary_stats.list[i].name.c_str(), Utils::floatToString(pc->stats.per_primary[i][Stats::COUNT + dmg_type], eset->number_format.character_menu).c_str()) + ' ';
 	}
 
 	size_t real_dmg_type = dmg_type / 2;
@@ -495,14 +538,14 @@ std::string MenuCharacter::resistTooltip(size_t resist_type) {
 	size_t resist_index = Stats::COUNT + eset->damage_types.count + resist_type;
 
 	if (pc->stats.per_level[resist_index] > 0)
-		tooltip_text += msg->get("Each level grants %d.", pc->stats.per_level[resist_index]) + ' ';
+		tooltip_text += msg->getv("Each level grants %s.", Utils::floatToString(pc->stats.per_level[resist_index], eset->number_format.character_menu).c_str()) + ' ';
 
 	for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 		if (pc->stats.per_primary[i][resist_index] > 0)
-			tooltip_text += msg->get("Each point of %s grants %d.", eset->primary_stats.list[i].name, pc->stats.per_primary[i][resist_index]) + ' ';
+			tooltip_text += msg->getv("Each point of %s grants %s.", eset->primary_stats.list[i].name.c_str(), Utils::floatToString(pc->stats.per_primary[i][resist_index], eset->number_format.character_menu).c_str()) + ' ';
 	}
 
-	std::string full_tooltip = msg->get("Reduces the damage taken from \"%s\" elemental attacks.", eset->elements.list[resist_type].name);
+	std::string full_tooltip = msg->getv("Reduces the damage taken from \"%s\" elemental attacks.", eset->elements.list[resist_type].name.c_str());
 	if (tooltip_text != "") {
 		full_tooltip += "\n" + tooltip_text;
 	}
@@ -510,6 +553,31 @@ std::string MenuCharacter::resistTooltip(size_t resist_type) {
 	return full_tooltip;
 }
 
+std::string MenuCharacter::resourceStatTooltip(size_t resource_index, size_t stat_index) {
+	std::string tooltip_text;
+	size_t offset_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+	size_t resource_stat_index = offset_index + (resource_index * EngineSettings::ResourceStats::STAT_COUNT) + stat_index;
+
+	if (pc->stats.per_level[resource_stat_index] > 0)
+		tooltip_text += msg->getv("Each level grants %s.", Utils::floatToString(pc->stats.per_level[resource_stat_index], eset->number_format.character_menu).c_str()) + ' ';
+
+	for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
+		if (pc->stats.per_primary[i][resource_stat_index] > 0)
+			tooltip_text += msg->getv("Each point of %s grants %s.", eset->primary_stats.list[i].name.c_str(), Utils::floatToString(pc->stats.per_primary[i][resource_stat_index], eset->number_format.character_menu).c_str()) + ' ';
+	}
+
+	std::string full_tooltip = "";
+	std::string text_desc = eset->resource_stats.list[resource_index].text_desc[stat_index];
+
+	if (!text_desc.empty())
+		full_tooltip += text_desc;
+	if (!full_tooltip.empty() && !tooltip_text.empty())
+		full_tooltip += "\n";
+	full_tooltip += tooltip_text;
+
+	return full_tooltip;
+}
+
 void MenuCharacter::logic() {
 	if (!visible) return;
 
@@ -637,6 +705,49 @@ bool MenuCharacter::checkSkillPoints() {
 	return (spent < ((pc->stats.level - 1) * pc->stats.stat_points_per_level) && spent < pc->stats.max_spendable_stat_points);
 }
 
+void MenuCharacter::parseShowStat(FileParser& infile) {
+	std::string stat_name = Parse::popFirstString(infile.val);
+	bool value = Parse::toBool(Parse::popFirstString(infile.val));
+	size_t offset_index = 0;
+
+	for (int i=0; i<Stats::COUNT; ++i) {
+		if (stat_name == Stats::KEY[i]) {
+			show_stat[i] = value;
+			return;
+		}
+	}
+	offset_index += Stats::COUNT;
+
+	for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
+		if (stat_name == eset->damage_types.list[i].min) {
+			show_stat[offset_index + (i*2)] = value;
+			return;
+		}
+		else if (stat_name == eset->damage_types.list[i].max) {
+			show_stat[offset_index + (i*2) + 1] = value;
+			return;
+		}
+	}
+	offset_index += eset->damage_types.count;
+
+	for (size_t i = 0; i < eset->elements.list.size(); ++i) {
+		if (stat_name == eset->elements.list[i].resist_id) {
+			show_stat[offset_index + i] = value;
+			return;
+		}
+	}
+	offset_index += eset->elements.list.size();
+
+	for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+		for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+			if (stat_name == eset->resource_stats.list[i].ids[j]) {
+				show_stat[offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + j] = value;
+				return;
+			}
+		}
+	}
+}
+
 MenuCharacter::~MenuCharacter() {
 	delete closeButton;
 	delete labelCharacter;
