@@ -1431,7 +1431,7 @@ void MenuConfig::placeLabeledWidgetAuto(int tab, int cfg_index) {
 }
 
 void MenuConfig::refreshWidgets() {
-	tab_control->setMainArea(((settings->view_w - eset->resolutions.frame_w)/2) + tab_offset.x, ((settings->view_h - eset->resolutions.frame_h)/2) + tab_offset.y);
+	tab_control->setMainArea(((settings->view_w - eset->resolutions.frame_w)/2) + tab_offset.x, ((settings->view_h - eset->resolutions.frame_h)/2) + tab_offset.y, eset->resolutions.frame_w);
 
 	frame.x = ((settings->view_w - eset->resolutions.frame_w)/2) + frame_offset.x;
 	frame.y = ((settings->view_h - eset->resolutions.frame_h)/2) + tab_control->getTabHeight() + frame_offset.y;
@@ -1549,6 +1549,10 @@ std::string MenuConfig::createModTooltip(Mod *mod) {
 
 		ret = mod->name + '\n';
 
+		if (mod->is_game_mod) {
+			ret += msg->get("Core mod") + '\n';
+		}
+
 		std::string mod_description = mod->getLocaleDescription(settings->language);
 		if (!mod_description.empty()) {
 			ret += '\n';
@@ -1733,6 +1737,14 @@ void MenuConfig::resetSelectedTab() {
 	keybind_tip_timer.reset(Timer::END);
 }
 
+int MenuConfig::getActiveTab() {
+	return tab_control->getActiveTab();
+}
+
+void MenuConfig::setActiveTab(unsigned tab) {
+	tab_control->setActiveTab(tab);
+}
+
 void MenuConfig::cleanup() {
 	if (background) {
 		delete background;
