@@ -1,6 +1,8 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
 Copyright © 2012 Igor Paliychuk
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -16,35 +18,38 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
-
-#pragma once
 #ifndef MENU_CONFIRM_H
 #define MENU_CONFIRM_H
 
 #include "CommonIncludes.h"
 #include "Menu.h"
-#include "WidgetButton.h"
+#include "WidgetLabel.h"
+
+class WidgetButton;
+class WidgetHorizontalList;
 
 class MenuConfirm : public Menu {
 protected:
-
-	WidgetButton *buttonConfirm;
-	WidgetButton *buttonClose;
+	WidgetButton *button_close;
 	WidgetLabel label;
-	TabList  tablist;
 
-	std::string boxMsg;
-	bool hasConfirmButton;
+	std::string title;
+
 public:
-	MenuConfirm(const std::string&, const std::string&);
+	MenuConfirm();
 	~MenuConfirm();
 
-	void update();
 	void logic();
+	void align();
 	virtual void render();
 
-	bool confirmClicked;
-	bool cancelClicked;
+	void setTitle(const std::string& s);
+	void show();
+
+	WidgetHorizontalList *action_list;
+
+	bool clicked_confirm;
+	bool clicked_cancel;
 };
 
 #endif
