@@ -1,5 +1,7 @@
 /*
 Copyright © 2011-2012 kitano
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -19,34 +21,34 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class MenuExit
  */
 
-#pragma once
-#ifndef MENU_EXIT_h
+#ifndef MENU_EXIT_H
 #define MENU_EXIT_H
 
 #include "CommonIncludes.h"
 #include "Menu.h"
-#include "WidgetButton.h"
+
+class MenuConfig;
 
 class MenuExit : public Menu {
 protected:
-	void loadGraphics();
-
-	WidgetButton *buttonExit;
-	WidgetButton *buttonClose;
-	WidgetLabel label;
-	TabList	tablist;
-
+	MenuConfig* menu_config;
 	bool exitClicked;
 
 public:
 	MenuExit();
 	~MenuExit();
-
-	void update();
+	void align();
 	void logic();
 	virtual void render();
 
-	bool isExitRequested() { return exitClicked; }
+	bool isExitRequested() {
+		return exitClicked;
+	}
+
+	void disableSave();
+	void handleCancel();
+
+	bool reload_music;
 };
 
 #endif
