@@ -271,20 +271,20 @@ void MenuInventory::logic() {
 		// remove a % of currency
 		if (eset->death_penalty.currency > 0) {
 			if (currency > 0)
-				removeCurrency((currency * eset->death_penalty.currency) / 100);
-			death_message += msg->get("Lost %d%% of %s.", eset->death_penalty.currency, eset->loot.currency) + ' ';
+				removeCurrency(static_cast<int>((static_cast<float>(currency) * eset->death_penalty.currency) / 100.f));
+			death_message += msg->getv("Lost %s%% of %s.", Utils::floatToString(eset->death_penalty.currency, eset->number_format.death_penalty).c_str(), eset->loot.currency.c_str()) + ' ';
 		}
 
 		// remove a % of either total xp or xp since the last level
 		if (eset->death_penalty.xp > 0) {
 			if (pc->stats.xp > 0)
-				pc->stats.xp -= (pc->stats.xp * eset->death_penalty.xp) / 100;
-			death_message += msg->get("Lost %d%% of total XP.", eset->death_penalty.xp) + ' ';
+				pc->stats.xp -= static_cast<int>((static_cast<float>(pc->stats.xp) * eset->death_penalty.xp) / 100.f);
+			death_message += msg->getv("Lost %s%% of total XP.", Utils::floatToString(eset->death_penalty.xp, eset->number_format.death_penalty).c_str()) + ' ';
 		}
 		else if (eset->death_penalty.xp_current > 0) {
 			if (pc->stats.xp - eset->xp.getLevelXP(pc->stats.level) > 0)
-				pc->stats.xp -= ((pc->stats.xp - eset->xp.getLevelXP(pc->stats.level)) * eset->death_penalty.xp_current) / 100;
-			death_message += msg->get("Lost %d%% of current level XP.", eset->death_penalty.xp_current) + ' ';
+				pc->stats.xp -= static_cast<int>((static_cast<float>(pc->stats.xp - eset->xp.getLevelXP(pc->stats.level)) * eset->death_penalty.xp_current) / 100.f);
+			death_message += msg->getv("Lost %s%% of current level XP.", Utils::floatToString(eset->death_penalty.xp_current, eset->number_format.death_penalty).c_str()) + ' ';
 		}
 
 		// prevent down-leveling from removing too much xp
@@ -310,7 +310,7 @@ void MenuInventory::logic() {
 			if (!removable_items.empty()) {
 				size_t random_item = static_cast<size_t>(rand()) % removable_items.size();
 				remove(removable_items[random_item], 1);
-				death_message += msg->get("Lost %s.",items->getItemName(removable_items[random_item]));
+				death_message += msg->getv("Lost %s.",items->getItemName(removable_items[random_item]).c_str());
 			}
 		}
 
@@ -367,6 +367,12 @@ void MenuInventory::logic() {
 			applyEquipment();
 			clearHighlight();
 		}
+		else if (inpt->pressing[Input::EQUIPMENT_SWAP_PREV] && !inpt->lock[Input::EQUIPMENT_SWAP_PREV]) {
+			inpt->lock[Input::EQUIPMENT_SWAP_PREV] = true;
+			applyPreviousEquipmentSet();
+			applyEquipment();
+			clearHighlight();
+		}
 	}
 
 	tap_to_activate_timer.tick();
@@ -395,7 +401,7 @@ void MenuInventory::render() {
 	label_inventory.render();
 
 	if (!label_currency.isHidden()) {
-		label_currency.setText(msg->get("%d %s", currency, eset->loot.currency));
+		label_currency.setText(msg->getv("%d %s", currency, eset->loot.currency.c_str()));
 		label_currency.render();
 	}
 
@@ -440,7 +446,7 @@ void MenuInventory::renderTooltips(const Point& position) {
 		if (position.x >= window_area.x + help_pos.x && position.y >= window_area.y+help_pos.y && position.x < window_area.x+help_pos.x+help_pos.w && position.y < window_area.y+help_pos.y+help_pos.h) {
 			tip_data.addText(msg->get("Pick up item(s):") + " " + inpt->getBindingString(Input::MAIN1));
 			tip_data.addText(msg->get("Use or equip item:") + " " + inpt->getBindingString(Input::MAIN2) + "\n");
-			tip_data.addText(msg->get("%s modifiers", inpt->getBindingString(Input::MAIN1)));
+			tip_data.addText(msg->getv("%s modifiers", inpt->getBindingString(Input::MAIN1).c_str()));
 			tip_data.addText(msg->get("Select a quantity of item:") + " " + inpt->getBindingString(Input::SHIFT));
 
 			if (inv_ctrl == CTRL_STASH)
@@ -997,7 +1003,7 @@ bool MenuInventory::buy(ItemStack stack, int tab, bool dragging) {
 		return true;
 	}
 	else {
-		pc->logMsg(msg->get("Not enough %s.", eset->loot.currency), Avatar::MSG_NORMAL);
+		pc->logMsg(msg->getv("Not enough %s.", eset->loot.currency.c_str()), Avatar::MSG_NORMAL);
 		drop_stack.push(stack);
 		return false;
 	}
@@ -1072,8 +1078,8 @@ void MenuInventory::applyEquipment() {
 				unsigned bonus_counter = 0;
 				while (bonus_counter < item.bonus.size()) {
 					for (size_t j = 0; j < eset->primary_stats.list.size(); ++j) {
-						if (item.bonus[bonus_counter].base_index == static_cast<int>(j))
-							pc->stats.primary_additional[j] += item.bonus[bonus_counter].value;
+						if (item.bonus[bonus_counter].type == BonusData::PRIMARY_STAT && item.bonus[bonus_counter].index == j)
+							pc->stats.primary_additional[j] += static_cast<int>(item.bonus[bonus_counter].value);
 					}
 
 					bonus_counter++;
@@ -1107,8 +1113,8 @@ void MenuInventory::applyEquipment() {
 				if (temp_set.bonus[bonus_counter].requirement != quantity[k]) continue;
 
 				for (size_t j = 0; j < eset->primary_stats.list.size(); ++j) {
-					if (temp_set.bonus[bonus_counter].base_index == static_cast<int>(j))
-						pc->stats.primary_additional[j] += temp_set.bonus[bonus_counter].value;
+					if (temp_set.bonus[bonus_counter].type == BonusData::PRIMARY_STAT && temp_set.bonus[bonus_counter].index == j)
+						pc->stats.primary_additional[j] += static_cast<int>(temp_set.bonus[bonus_counter].value);
 				}
 			}
 		}
@@ -1198,9 +1204,9 @@ void MenuInventory::applyItemStats() {
 
 	// reset additional values
 	for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
-		pc->stats.dmg_min_add[i] = pc->stats.dmg_max_add[i] = 0;
+		pc->stats.item_base_dmg[i].min = pc->stats.item_base_dmg[i].max = 0;
 	}
-	pc->stats.absorb_min_add = pc->stats.absorb_max_add = 0;
+	pc->stats.item_base_abs.min = pc->stats.item_base_abs.max = 0;
 
 	// apply stats from all items
 	for (int i=0; i<MAX_EQUIPPED; i++) {
@@ -1210,8 +1216,8 @@ void MenuInventory::applyItemStats() {
 
 			// apply base stats
 			for (size_t j = 0; j < eset->damage_types.list.size(); ++j) {
-				pc->stats.dmg_min_add[j] += item.dmg_min[j];
-				pc->stats.dmg_max_add[j] += item.dmg_max[j];
+				pc->stats.item_base_dmg[j].min += item.base_dmg[j].min;
+				pc->stats.item_base_dmg[j].max += item.base_dmg[j].max;
 			}
 
 			// set equip flags
@@ -1220,8 +1226,8 @@ void MenuInventory::applyItemStats() {
 			}
 
 			// apply absorb bonus
-			pc->stats.absorb_min_add += item.abs_min;
-			pc->stats.absorb_max_add += item.abs_max;
+			pc->stats.item_base_abs.min += item.base_abs.min;
+			pc->stats.item_base_abs.max += item.base_abs.max;
 
 			// apply various bonuses
 			unsigned bonus_counter = 0;
@@ -1273,35 +1279,44 @@ void MenuInventory::applyItemSetBonuses() {
 void MenuInventory::applyBonus(const BonusData* bdata) {
 	EffectDef ed;
 
-	if (bdata->is_speed) {
+	if (bdata->type == BonusData::SPEED) {
 		ed.id = "speed";
 	}
-	else if (bdata->is_attack_speed) {
+	else if (bdata->type == BonusData::ATTACK_SPEED) {
 		ed.id = "attack_speed";
 	}
-	else if (bdata->stat_index != -1) {
-		ed.id = Stats::KEY[bdata->stat_index];
+	else if (bdata->type == BonusData::STAT) {
+		ed.id = Stats::KEY[bdata->index];
 	}
-	else if (bdata->damage_index_min != -1) {
-		ed.id = eset->damage_types.list[bdata->damage_index_min].min;
+	else if (bdata->type == BonusData::DAMAGE_MIN) {
+		ed.id = eset->damage_types.list[bdata->index].min;
 	}
-	else if (bdata->damage_index_max != -1) {
-		ed.id = eset->damage_types.list[bdata->damage_index_max].max;
+	else if (bdata->type == BonusData::DAMAGE_MAX) {
+		ed.id = eset->damage_types.list[bdata->index].max;
 	}
-	else if (bdata->resist_index != -1) {
-		ed.id = eset->elements.list[bdata->resist_index].resist_id;
+	else if (bdata->type == BonusData::RESIST_ELEMENT) {
+		ed.id = eset->elements.list[bdata->index].resist_id;
 	}
-	else if (bdata->base_index > -1 && static_cast<size_t>(bdata->base_index) < eset->primary_stats.list.size()) {
-		ed.id = eset->primary_stats.list[bdata->base_index].id;
+	else if (bdata->type == BonusData::PRIMARY_STAT) {
+		ed.id = eset->primary_stats.list[bdata->index].id;
 	}
 	else if (bdata->power_id > 0) {
-		menu->pow->addBonusLevels(bdata->power_id, bdata->value);
+		menu->pow->addBonusLevels(bdata->power_id, static_cast<int>(bdata->value));
 		return; // don't add item effect
 	}
+	else if (bdata->type == BonusData::RESOURCE_STAT) {
+		ed.id = eset->resource_stats.list[bdata->index].ids[bdata->sub_index];
+	}
 
 	ed.type = Effect::getTypeFromString(ed.id);
 
-	pc->stats.effects.addItemEffect(ed, 0, bdata->value);
+	EffectParams ep;
+	ep.magnitude = bdata->value;
+	ep.is_multiplier = bdata->is_multiplier;
+	ep.source_type = Power::SOURCE_TYPE_HERO;
+	ep.is_from_item = true;
+
+	pc->stats.effects.addEffect(&pc->stats, ed, ep);
 }
 
 void MenuInventory::applyEquipmentSet(unsigned set) {
@@ -1314,7 +1329,7 @@ void MenuInventory::applyEquipmentSet(unsigned set) {
 
 	if (active_equipment_set > 0 && prev_equipment_set != active_equipment_set) {
 		if (!visible && menu && menu->hudlog) {
-			menu->hudlog->add(msg->get("Equipped set %d.", static_cast<int>(active_equipment_set)), MenuHUDLog::MSG_NORMAL);
+			menu->hudlog->add(msg->getv("Equipped set %d.", static_cast<int>(active_equipment_set)), MenuHUDLog::MSG_NORMAL);
 		}
 	}
 }
@@ -1543,9 +1558,11 @@ bool MenuInventory::canActivateItem(ItemID item) {
 int MenuInventory::getEquippedSetCount(size_t set_id) {
 	int quantity = 0;
 	for (int i=0; i<MAX_EQUIPPED; i++) {
-		ItemID item_id = inventory[EQUIPMENT].storage[i].item;
-		if (items->items[item_id].set == set_id) {
-			quantity++;
+		if (isActive(i)) {
+			ItemID item_id = inventory[EQUIPMENT].storage[i].item;
+			if (items->items[item_id].set == set_id) {
+				quantity++;
+			}
 		}
 	}
 	return quantity;
