@@ -51,7 +51,7 @@ void MenuItemStorage::initGrid(int _slot_number, const Rect& _area, int _nb_cols
 	grid_pos.x = _area.x;
 	grid_pos.y = _area.y;
 	for (int i = 0; i < _slot_number; i++) {
-		WidgetSlot *slot = new WidgetSlot(WidgetSlot::NO_ICON, Input::ACCEPT);
+		WidgetSlot *slot = new WidgetSlot(WidgetSlot::NO_ICON);
 		slots.push_back(slot);
 	}
 	nb_cols = _nb_cols;
@@ -69,7 +69,7 @@ void MenuItemStorage::initGrid(int _slot_number, const Rect& _area, int _nb_cols
 void MenuItemStorage::initFromList(int _slot_number, const std::vector<Rect>& _area, const std::vector<std::string>& _slot_type) {
 	ItemStorage::init( _slot_number);
 	for (int i = 0; i < _slot_number; i++) {
-		WidgetSlot *slot = new WidgetSlot(WidgetSlot::NO_ICON, Input::ACCEPT);
+		WidgetSlot *slot = new WidgetSlot(WidgetSlot::NO_ICON);
 		slot->pos = _area[i];
 		slot->setBasePos(slot->pos.x, slot->pos.y, Utils::ALIGN_TOPLEFT);
 		slots.push_back(slot);
@@ -145,18 +145,19 @@ int MenuItemStorage::slotOver(const Point& position) {
 	}
 	else if (nb_cols == 0) {
 		for (unsigned int i=0; i<slots.size(); i++) {
-			if (Utils::isWithinRect(slots[i]->pos, position)) return i;
+			if (slots[i]->visible)
+				if (Utils::isWithinRect(slots[i]->pos, position)) return i;
 		}
 	}
 	return -1;
 }
 
-TooltipData MenuItemStorage::checkTooltip(const Point& position, StatBlock *stats, int context) {
+TooltipData MenuItemStorage::checkTooltip(const Point& position, StatBlock *stats, int context, bool input_hint) {
 	TooltipData tip;
 	int slot = slotOver(position);
 
 	if (slot > -1 && storage[slot].item > 0) {
-		return items->getTooltip(storage[slot], stats, context);
+		return items->getTooltip(storage[slot], stats, context, input_hint);
 	}
 	return tip;
 }
@@ -181,7 +182,7 @@ ItemStack MenuItemStorage::click(const Point& position) {
 
 	if (drag_prev_slot > -1) {
 		item = storage[drag_prev_slot];
-		if (settings->touchscreen) {
+		if (inpt->mode == InputState::MODE_TOUCHSCREEN) {
 			if (!slots[drag_prev_slot]->in_focus && !item.empty()) {
 				slots[drag_prev_slot]->in_focus = true;
 				current_slot = slots[drag_prev_slot];
@@ -189,13 +190,13 @@ ItemStack MenuItemStorage::click(const Point& position) {
 				drag_prev_slot = -1;
 				return item;
 			}
-			else {
+			else if (item.empty()) {
 				slots[drag_prev_slot]->defocus();
 				current_slot = NULL;
 			}
 		}
 		if (!item.empty()) {
-			if (item.quantity > 1 && !inpt->pressing[Input::CTRL] && (inpt->pressing[Input::SHIFT] || !inpt->usingMouse() || inpt->touch_locked)) {
+			if (item.quantity > 1 && !inpt->pressing[Input::CTRL] && (inpt->pressing[Input::SHIFT] || !inpt->usingMouse() || inpt->mode == InputState::MODE_TOUCHSCREEN)) {
 				// we use an external menu to let the player pick the desired quantity
 				// we will subtract from this stack after they've made their decision
 				return item;
@@ -214,15 +215,13 @@ ItemStack MenuItemStorage::click(const Point& position) {
 
 void MenuItemStorage::itemReturn(ItemStack stack) {
 	add( stack, drag_prev_slot);
-	if (drag_prev_slot != -1) {
-		slots[drag_prev_slot]->checked = false;
-	}
 	drag_prev_slot = -1;
 }
 
 void MenuItemStorage::highlightMatching(const std::string& type) {
 	for (int i=0; i<slot_number; i++) {
-		if (slot_type[i] == type) highlight[i] = true;
+		if (slots[i]->visible)
+			if (slot_type[i] == type) highlight[i] = true;
 	}
 }
 
