@@ -202,7 +202,7 @@ void MenuPowers::align() {
 	closeButton->pos.y = window_area.y+close_pos.y;
 
 	if (tab_control) {
-		tab_control->setMainArea(window_area.x + tab_area.x, window_area.y + tab_area.y);
+		tab_control->setMainArea(window_area.x + tab_area.x, window_area.y + tab_area.y, tab_area.w);
 	}
 
 	for (size_t i = 0; i < slots.size(); i++) {
@@ -338,7 +338,7 @@ void MenuPowers::loadPowerTree(const std::string &filename) {
 			}
 
 			// Initialize the tab control.
-			tab_control->setMainArea(window_area.x + tab_area.x, window_area.y + tab_area.y);
+			tab_control->setMainArea(window_area.x + tab_area.x, window_area.y + tab_area.y, tab_area.w);
 		}
 	}
 
@@ -889,7 +889,7 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		std::stringstream ss;
 		ss << pwr.name;
 		if (pcell && pcell->upgrade_level > 0) {
-			ss << " (" << msg->get("Level %d", pcell->upgrade_level);
+			ss << " (" << msg->getv("Level %d", pcell->upgrade_level);
 			int bonus_levels = power_cell[pcell->group].getBonusLevels();
 			if (bonus_levels > 0)
 				ss << ", +" << bonus_levels;
@@ -908,15 +908,21 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 
 	// add mana cost
 	if (pwr.requires_mp > 0) {
-		tip_data->addText(msg->get("Costs %d MP", pwr.requires_mp));
+		tip_data->addText(msg->getv("Costs %s MP", Utils::floatToString(pwr.requires_mp, eset->number_format.power_tooltips).c_str()));
 	}
 	// add health cost
 	if (pwr.requires_hp > 0) {
-		tip_data->addText(msg->get("Costs %d HP", pwr.requires_hp));
+		tip_data->addText(msg->getv("Costs %s HP", Utils::floatToString(pwr.requires_hp, eset->number_format.power_tooltips).c_str()));
+	}
+	// add resource stat cost
+	for (size_t i = 0; i < pwr.requires_resource_stat.size(); ++i) {
+		if (pwr.requires_resource_stat[i] > 0) {
+			tip_data->addText(eset->resource_stats.list[i].text_tooltip_cost + ": " + Utils::floatToString(pwr.requires_resource_stat[i], eset->number_format.power_tooltips));
+		}
 	}
 	// add cooldown time
 	if (pwr.cooldown > 0) {
-		tip_data->addText(msg->get("Cooldown:") + " " + Utils::getDurationString(pwr.cooldown, 2));
+		tip_data->addText(msg->get("Cooldown:") + " " + Utils::getDurationString(pwr.cooldown, eset->number_format.durations));
 	}
 
 	for (size_t i=0; i<pwr.post_effects.size(); ++i) {
@@ -935,17 +941,20 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		    Effect::typeIsDmgMin(effect_type) ||
 		    Effect::typeIsDmgMax(effect_type) ||
 		    Effect::typeIsResist(effect_type) ||
-		    Effect::typeIsPrimary(effect_type))
+		    Effect::typeIsPrimary(effect_type) ||
+		    Effect::typeIsResourceStat(effect_type))
 		{
-			if (pwr.post_effects[i].magnitude > 0) {
-				ss << "+";
-			}
-			ss << pwr.post_effects[i].magnitude;
+			if (pwr.post_effects[i].is_multiplier)
+				ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips + 2) << "×";
+			else if (pwr.post_effects[i].magnitude > 0)
+				ss << "+" << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips);
+			else
+				ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips);
 		}
 
 		if (Effect::typeIsStat(effect_type)) {
 			int index = Effect::getStatFromType(effect_type);
-			if (Stats::PERCENT[index]) {
+			if (Stats::PERCENT[index] && !pwr.post_effects[i].is_multiplier) {
 				ss << "%";
 			}
 			ss << " " << Stats::NAME[index];
@@ -960,65 +969,65 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		}
 		else if (Effect::typeIsResist(effect_type)) {
 			size_t index = Effect::getResistFromType(effect_type);
-			ss << "% " << msg->get("Resistance (%s)", eset->elements.list[index].name);
+			if (!pwr.post_effects[i].is_multiplier) {
+				ss << "%";
+			}
+			ss << " " << msg->getv("Resistance (%s)", eset->elements.list[index].name.c_str());
 		}
 		else if (Effect::typeIsPrimary(effect_type)) {
 			size_t index = Effect::getPrimaryFromType(effect_type);
 			ss << " " << eset->primary_stats.list[index].name;
 		}
+		else if (Effect::typeIsResourceStat(effect_type)) {
+			size_t index = Effect::getResourceStatFromType(effect_type);
+			size_t sub_index = Effect::getResourceStatSubIndexFromType(effect_type);
+
+			if (!pwr.post_effects[i].is_multiplier && (sub_index == EngineSettings::ResourceStats::STAT_STEAL || sub_index == EngineSettings::ResourceStats::STAT_RESIST_STEAL)) {
+				ss << "%";
+			}
+			ss << " " << eset->resource_stats.list[index].text[sub_index];
+		}
+		else if (Effect::typeIsResourceEffect(effect_type)) {
+			size_t index = Effect::getResourceStatFromType(effect_type);
+			size_t sub_index = Effect::getResourceStatSubIndexFromType(effect_type);
+
+			if (sub_index == EngineSettings::ResourceStats::STAT_HEAL) {
+				ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << eset->resource_stats.list[index].text_tooltip_heal;
+			}
+			else if (sub_index == EngineSettings::ResourceStats::STAT_HEAL_PERCENT) {
+				ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << "% " << eset->resource_stats.list[index].text_tooltip_heal;
+			}
+		}
 		else if (effect_type == Effect::DAMAGE) {
-			ss << pwr.post_effects[i].magnitude << " " << msg->get("Damage per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << msg->get("Damage per second");
 		}
 		else if (effect_type == Effect::DAMAGE_PERCENT) {
-			ss << pwr.post_effects[i].magnitude << "% " << msg->get("Damage per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << "% " << msg->get("Damage per second");
 		}
 		else if (effect_type == Effect::HPOT) {
-			ss << pwr.post_effects[i].magnitude << " " << msg->get("HP per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << msg->get("HP per second");
 		}
 		else if (effect_type == Effect::HPOT_PERCENT) {
-			ss << pwr.post_effects[i].magnitude << "% " << msg->get("HP per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << "% " << msg->get("HP per second");
 		}
 		else if (effect_type == Effect::MPOT) {
-			ss << pwr.post_effects[i].magnitude << " " << msg->get("MP per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << msg->get("MP per second");
 		}
 		else if (effect_type == Effect::MPOT_PERCENT) {
-			ss << pwr.post_effects[i].magnitude << "% " << msg->get("MP per second");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << "% " << msg->get("MP per second");
 		}
 		else if (effect_type == Effect::SPEED) {
 			if (pwr.post_effects[i].magnitude == 0)
 				ss << msg->get("Immobilize");
 			else
-				ss << msg->get("%d%% Speed", pwr.post_effects[i].magnitude);
+				ss << msg->getv("%s%% Speed", Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips).c_str());
 		}
 		else if (effect_type == Effect::ATTACK_SPEED) {
-			ss << msg->get("%d%% Attack Speed", pwr.post_effects[i].magnitude);
+			ss << msg->getv("%s%% Attack Speed", Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips).c_str());
 		}
-		else if (effect_type == Effect::IMMUNITY) {
-			ss << msg->get("Immunity");
+		else if (effect_type == Effect::RESIST_ALL) {
+			ss << "+" << pwr.post_effects[i].magnitude << "% " << msg->get("Resistance to all negative effects");
 		}
-		else if (effect_type == Effect::IMMUNITY_DAMAGE) {
-			ss << msg->get("Immunity to damage over time");
-		}
-		else if (effect_type == Effect::IMMUNITY_SLOW) {
-			ss << msg->get("Immunity to slow");
-		}
-		else if (effect_type == Effect::IMMUNITY_STUN) {
-			ss << msg->get("Immunity to stun");
-		}
-		else if (effect_type == Effect::IMMUNITY_HP_STEAL) {
-			ss << msg->get("Immunity to HP steal");
-		}
-		else if (effect_type == Effect::IMMUNITY_MP_STEAL) {
-			ss << msg->get("Immunity to MP steal");
-		}
-		else if (effect_type == Effect::IMMUNITY_KNOCKBACK) {
-			ss << msg->get("Immunity to knockback");
-		}
-		else if (effect_type == Effect::IMMUNITY_DAMAGE_REFLECT) {
-			ss << msg->get("Immunity to damage reflection");
-		}
-
-		// TODO Effect::IMMUNITY_STAT_DEBUFF?
 
 		else if (effect_type == Effect::STUN) {
 			ss << msg->get("Stun");
@@ -1040,21 +1049,21 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 				continue;
 
 			if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_MULTIPLY) {
-				int magnitude = pc->stats.getDamageMax(pwr.base_damage) * pwr.mod_damage_value_min / 100;
-				ss << magnitude;
+				float magnitude = pc->stats.getDamageMax(pwr.base_damage) * pwr.mod_damage_value_min / 100;
+				ss << Utils::floatToString(magnitude, eset->number_format.power_tooltips);
 			}
 			else if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_ADD) {
-				int magnitude = pc->stats.getDamageMax(pwr.base_damage) + pwr.mod_damage_value_min;
-				ss << magnitude;
+				float magnitude = pc->stats.getDamageMax(pwr.base_damage) + pwr.mod_damage_value_min;
+				ss << Utils::floatToString(magnitude, eset->number_format.power_tooltips);
 			}
 			else if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_ABSOLUTE) {
 				if (pwr.mod_damage_value_max == 0 || pwr.mod_damage_value_min == pwr.mod_damage_value_max)
-					ss << pwr.mod_damage_value_min;
+					ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips);
 				else
-					ss << pwr.mod_damage_value_min << "-" << pwr.mod_damage_value_max;
+					ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(pwr.mod_damage_value_max, eset->number_format.power_tooltips);
 			}
 			else {
-				ss << pc->stats.getDamageMax(pwr.base_damage);
+				ss << Utils::floatToString(pc->stats.getDamageMax(pwr.base_damage), eset->number_format.power_tooltips);
 			}
 
 			ss << " " << msg->get("Magical Shield");
@@ -1063,38 +1072,38 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 			if (pwr.base_damage == eset->damage_types.list.size())
 				continue;
 
-			int mag_min = pc->stats.getDamageMin(pwr.base_damage);
-			int mag_max = pc->stats.getDamageMax(pwr.base_damage);
+			float mag_min = pc->stats.getDamageMin(pwr.base_damage);
+			float mag_max = pc->stats.getDamageMax(pwr.base_damage);
 
 			if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_MULTIPLY) {
 				mag_min = mag_min * pwr.mod_damage_value_min / 100;
 				mag_max = mag_max * pwr.mod_damage_value_min / 100;
-				ss << mag_min << "-" << mag_max;
+				ss << Utils::floatToString(mag_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(mag_max, eset->number_format.power_tooltips);
 			}
 			else if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_ADD) {
 				mag_min = mag_min + pwr.mod_damage_value_min;
 				mag_max = mag_max + pwr.mod_damage_value_min;
-				ss << mag_min << "-" << mag_max;
+				ss << Utils::floatToString(mag_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(mag_max, eset->number_format.power_tooltips);
 			}
 			else if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_ABSOLUTE) {
 				if (pwr.mod_damage_value_max == 0 || pwr.mod_damage_value_min == pwr.mod_damage_value_max)
-					ss << pwr.mod_damage_value_min;
+					ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips);
 				else
-					ss << pwr.mod_damage_value_min << "-" << pwr.mod_damage_value_max;
+					ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(pwr.mod_damage_value_max, eset->number_format.power_tooltips);
 			}
 			else {
-				ss << mag_min << "-" << mag_max;
+				ss << Utils::floatToString(mag_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(mag_max, eset->number_format.power_tooltips);
 			}
 
 			ss << " " << msg->get("Healing");
 		}
 		else if (effect_type == Effect::KNOCKBACK) {
-			ss << pwr.post_effects[i].magnitude << " " << msg->get("Knockback");
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << msg->get("Knockback");
 		}
 		else if (effect_ptr && !effect_ptr->name.empty() && pwr.post_effects[i].magnitude > 0) {
 			if (effect_ptr->can_stack)
 				ss << "+";
-			ss << pwr.post_effects[i].magnitude << " " << msg->get(effect_ptr->name);
+			ss << Utils::floatToString(pwr.post_effects[i].magnitude, eset->number_format.power_tooltips) << " " << msg->get(effect_ptr->name);
 		}
 		else if (pwr.post_effects[i].magnitude == 0) {
 			// nothing
@@ -1103,17 +1112,17 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		if (!ss.str().empty()) {
 			if (pwr.post_effects[i].duration > 0) {
 				if (effect_type == Effect::DEATH_SENTENCE) {
-					ss << ": " << Utils::getDurationString(pwr.post_effects[i].duration, 2);
+					ss << ": " << Utils::getDurationString(pwr.post_effects[i].duration, eset->number_format.durations);
 				}
 				else {
-					ss << " (" << Utils::getDurationString(pwr.post_effects[i].duration, 2) << ")";
+					ss << " (" << Utils::getDurationString(pwr.post_effects[i].duration, eset->number_format.durations) << ")";
 				}
 
 				if (pwr.post_effects[i].chance != 100)
 					ss << " ";
 			}
 			if (pwr.post_effects[i].chance != 100) {
-				ss << "(" << msg->get("%d%% chance", pwr.post_effects[i].chance) << ")";
+				ss << "(" << msg->getv("%s%% chance", Utils::floatToString(pwr.post_effects[i].chance, eset->number_format.power_tooltips).c_str()) << ")";
 			}
 
 			tip_data->addColoredText(ss.str(), font->getColor(FontEngine::COLOR_MENU_BONUS));
@@ -1129,10 +1138,10 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 				ss << "+";
 
 			if (pwr.mod_damage_value_max == 0 || pwr.mod_damage_value_min == pwr.mod_damage_value_max) {
-				ss << pwr.mod_damage_value_min;
+				ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips);
 			}
 			else {
-				ss << pwr.mod_damage_value_min << "-" << pwr.mod_damage_value_max;
+				ss << Utils::floatToString(pwr.mod_damage_value_min, eset->number_format.power_tooltips) << "-" << Utils::floatToString(pwr.mod_damage_value_max, eset->number_format.power_tooltips);
 			}
 
 			if (pwr.mod_damage_mode == Power::STAT_MODIFIER_MODE_MULTIPLY) {
@@ -1158,7 +1167,7 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 			if (pwr.mod_accuracy_mode == Power::STAT_MODIFIER_MODE_ADD && pwr.mod_accuracy_value > 0)
 				ss << "+";
 
-			ss << pwr.mod_accuracy_value;
+			ss << Utils::floatToString(pwr.mod_accuracy_value, eset->number_format.power_tooltips);
 
 			if (pwr.mod_accuracy_mode == Power::STAT_MODIFIER_MODE_MULTIPLY) {
 				ss << "%";
@@ -1178,7 +1187,7 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 			if (pwr.mod_crit_mode == Power::STAT_MODIFIER_MODE_ADD && pwr.mod_crit_value > 0)
 				ss << "+";
 
-			ss << pwr.mod_crit_value;
+			ss << Utils::floatToString(pwr.mod_crit_value, eset->number_format.power_tooltips);
 
 			if (pwr.mod_crit_mode == Power::STAT_MODIFIER_MODE_MULTIPLY) {
 				ss << "%";
@@ -1203,12 +1212,12 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		}
 		if (pwr.trait_crits_impaired > 0) {
 			ss.str("");
-			ss << msg->get("%d%% Chance to crit slowed targets", pwr.trait_crits_impaired);
+			ss << msg->getv("%s%% Chance to crit slowed targets", Utils::floatToString(pwr.trait_crits_impaired, eset->number_format.power_tooltips).c_str());
 			tip_data->addColoredText(ss.str(), font->getColor(FontEngine::COLOR_MENU_BONUS));
 		}
 		if (pwr.trait_elemental > -1) {
 			ss.str("");
-			ss << msg->get("Elemental Damage (%s)", eset->elements.list[pwr.trait_elemental].name);
+			ss << msg->getv("Elemental Damage (%s)", eset->elements.list[pwr.trait_elemental].name.c_str());
 			tip_data->addColoredText(ss.str(), font->getColor(FontEngine::COLOR_MENU_BONUS));
 		}
 	}
@@ -1217,7 +1226,7 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 	for (it = pwr.requires_flags.begin(); it != pwr.requires_flags.end(); ++it) {
 		for (size_t i = 0; i < eset->equip_flags.list.size(); ++i) {
 			if ((*it) == eset->equip_flags.list[i].id) {
-				tip_data->addText(msg->get("Requires a %s", msg->get(eset->equip_flags.list[i].name)));
+				tip_data->addText(msg->getv("Requires a %s", msg->get(eset->equip_flags.list[i].name).c_str()));
 			}
 		}
 	}
@@ -1227,18 +1236,18 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 		for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 			if (pcell->requires_primary[i] > 0) {
 				if (pc->stats.get_primary(i) < pcell->requires_primary[i])
-					tip_data->addColoredText(msg->get("Requires %s %d", eset->primary_stats.list[i].name, pcell->requires_primary[i]), font->getColor(FontEngine::COLOR_MENU_PENALTY));
+					tip_data->addColoredText(msg->getv("Requires %s %d", eset->primary_stats.list[i].name.c_str(), pcell->requires_primary[i]), font->getColor(FontEngine::COLOR_MENU_PENALTY));
 				else
-					tip_data->addText(msg->get("Requires %s %d", eset->primary_stats.list[i].name, pcell->requires_primary[i]));
+					tip_data->addText(msg->getv("Requires %s %d", eset->primary_stats.list[i].name.c_str(), pcell->requires_primary[i]));
 			}
 		}
 
 		// Draw required Level Tooltip
 		if ((pcell->requires_level > 0) && pc->stats.level < pcell->requires_level) {
-			tip_data->addColoredText(msg->get("Requires Level %d", pcell->requires_level), font->getColor(FontEngine::COLOR_MENU_PENALTY));
+			tip_data->addColoredText(msg->getv("Requires Level %d", pcell->requires_level), font->getColor(FontEngine::COLOR_MENU_PENALTY));
 		}
 		else if ((pcell->requires_level > 0) && pc->stats.level >= pcell->requires_level) {
-			tip_data->addText(msg->get("Requires Level %d", pcell->requires_level));
+			tip_data->addText(msg->getv("Requires Level %d", pcell->requires_level));
 		}
 
 		for (size_t j=0; j < pcell->requires_power.size(); ++j) {
@@ -1248,17 +1257,17 @@ void MenuPowers::createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, Pow
 
 			std::string req_power_name;
 			if (req_cell->upgrade_level > 0)
-				req_power_name = powers->powers[req_cell->id].name + " (" + msg->get("Level %d", req_cell->upgrade_level) + ")";
+				req_power_name = powers->powers[req_cell->id].name + " (" + msg->getv("Level %d", req_cell->upgrade_level) + ")";
 			else
 				req_power_name = powers->powers[req_cell->id].name;
 
 
 			// Required Power Tooltip
 			if (!checkUnlocked(req_cell)) {
-				tip_data->addColoredText(msg->get("Requires Power: %s", req_power_name), font->getColor(FontEngine::COLOR_MENU_PENALTY));
+				tip_data->addColoredText(msg->getv("Requires Power: %s", req_power_name.c_str()), font->getColor(FontEngine::COLOR_MENU_PENALTY));
 			}
 			else {
-				tip_data->addText(msg->get("Requires Power: %s", req_power_name));
+				tip_data->addText(msg->getv("Requires Power: %s", req_power_name.c_str()));
 			}
 
 		}
@@ -1308,7 +1317,7 @@ void MenuPowers::createTooltipInputHint(TooltipData* tip_data, bool enable_activ
 		more_bind_str = inpt->getBindingString(Input::ACCEPT);
 	}
 	else {
-		show_activate_msg = true;
+		show_activate_msg = enable_activate_msg;
 		activate_bind_str = inpt->getBindingString(Input::MAIN2);
 	}
 
@@ -1317,11 +1326,11 @@ void MenuPowers::createTooltipInputHint(TooltipData* tip_data, bool enable_activ
 	}
 
 	if (show_activate_msg) {
-		tip_data->addColoredText(msg->get("Press [%s] to use", activate_bind_str), font->getColor(FontEngine::COLOR_ITEM_BONUS));
+		tip_data->addColoredText(msg->getv("Press [%s] to use", activate_bind_str.c_str()), font->getColor(FontEngine::COLOR_ITEM_BONUS));
 	}
 
 	if (show_more_msg) {
-		tip_data->addColoredText(msg->get("Press [%s] for more options", more_bind_str), font->getColor(FontEngine::COLOR_ITEM_BONUS));
+		tip_data->addColoredText(msg->getv("Press [%s] for more options", more_bind_str.c_str()), font->getColor(FontEngine::COLOR_ITEM_BONUS));
 	}
 }
 
@@ -1385,6 +1394,7 @@ void MenuPowers::renderPowers(int tab_num) {
 void MenuPowers::logic() {
 	if (!visible && tab_control && default_power_tab > -1) {
 		tab_control->setActiveTab(static_cast<unsigned>(default_power_tab));
+		tablist.setNextTabList(&tablist_pow[default_power_tab]);
 	}
 
 	setUnlockedPowers();
@@ -1519,7 +1529,7 @@ void MenuPowers::render() {
 	// stats
 	if (!label_unspent->isHidden()) {
 		if (points_left >= 1) {
-			label_unspent->setText(msg->get("Available skill points: %d", points_left));
+			label_unspent->setText(msg->getv("Available skill points: %d", points_left));
 		}
 		else {
 			label_unspent->setText("");
@@ -1727,7 +1737,7 @@ std::string MenuPowers::getItemBonusPowerReqString(PowerID power_index) {
 
 	std::string output = powers->powers[power_index].name;
 	if (pcell->upgrade_level > 0) {
-		output += " (" + msg->get("Level %d", pcell->upgrade_level) + ")";
+		output += " (" + msg->getv("Level %d", pcell->upgrade_level) + ")";
 	}
 
 	return output;
