@@ -92,9 +92,21 @@ public:
 	std::vector< std::pair<size_t, int> > bonus_levels;
 };
 
+class MenuPowersClick {
+public:
+	PowerID drag;
+	PowerID unlock;
+
+	MenuPowersClick()
+		: drag(0)
+		, unlock(0)
+	{}
+};
+
 class MenuPowers : public Menu {
 private:
 	static const bool UPGRADE_POWER_ALL_TABS = true;
+	static const bool TOOLTIP_SHOW_ACTIVATE_HINT = true;
 
 	void loadGraphics();
 	void loadTab(FileParser &infile);
@@ -117,6 +129,7 @@ private:
 	int getPointsUsed();
 
 	void createTooltip(TooltipData* tip_data, MenuPowersCell* pcell, PowerID power_index, bool show_unlock_prompt, int tooltip_length);
+	void createTooltipInputHint(TooltipData* tip_data, bool enable_activate_msg);
 	void renderPowers(int tab_num);
 
 	std::vector<MenuPowersCellGroup> power_cell;
@@ -142,6 +155,8 @@ private:
 
 	int default_power_tab;
 
+	std::vector<MenuPowersCell*> recently_locked_cells;
+
 public:
 	enum {
 		TOOLTIP_SHORT = 0,
@@ -159,8 +174,8 @@ public:
 	void render();
 
 	void renderTooltips(const Point& position);
-	PowerID click(const Point& mouse);
-	void upgradeBySlotIndex(int slot_index);
+	MenuPowersClick click(const Point& mouse);
+	void clickUnlock(PowerID power_index);
 
 	void setUnlockedPowers();
 	void resetToBasePowers();
