@@ -1,6 +1,7 @@
 /*
 Copyright © 2011-2012 Thane Brimhall
 Copyright © 2013 Henrik Andersson
+Copyright © 2015-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -26,7 +27,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * This class is primarily used for making sure FLARE is flexible and translatable.
  */
 
-#pragma once
 #ifndef MESSAGE_ENGINE_H
 #define MESSAGE_ENGINE_H
 
@@ -36,15 +36,11 @@ class MessageEngine {
 
 private:
 	std::map<std::string,std::string> messages;
-	std::string str(int i);
-	std::string unescape(std::string msg);
+	std::string unescape(const std::string& _val);
 public:
 	MessageEngine();
 	std::string get(const std::string& key);
-	std::string get(const std::string& key, int i);
-	std::string get(const std::string& key, const std::string& s);
-	std::string get(const std::string& key, int i, const std::string& s);
-	std::string get(const std::string& key, int i, int j);
+	std::string getv(const std::string key, ...);
 };
 
 #endif
