@@ -28,7 +28,8 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include <cassert>
 
 Mod::Mod()
-	: name("")
+	: is_game_mod(false)
+	, name("")
 	, description("")
 	, description_locale()
 	, game("")
@@ -63,6 +64,7 @@ Mod& Mod::operator=(const Mod &mod) {
 	if (this == &mod)
 		return *this;
 
+	is_game_mod = mod.is_game_mod;
 	name = mod.name;
 	description = mod.description;
 	description_locale = mod.description_locale;
@@ -169,7 +171,6 @@ void ModManager::loadModList() {
 	if (!cmd_line_mods || cmd_line_mods->empty()) {
 		std::ifstream infile;
 		std::string line;
-		std::string starts_with;
 
 		std::string place1 = Filesystem::convertSlashes(settings->path_conf + "mods.txt");
 		std::string place2 = Filesystem::convertSlashes(settings->path_data + "mods/mods.txt");
@@ -188,12 +189,8 @@ void ModManager::loadModList() {
 		while (infile.good()) {
 			line = Parse::getLine(infile);
 
-			// skip ahead if this line is empty
-			if (line.length() == 0) continue;
-
-			// skip comments
-			starts_with = line.at(0);
-			if (starts_with == "#") continue;
+			if (Parse::skipLine(line))
+				continue;
 
 			// add the mod if it exists in the mods folder
 			if (line != FALLBACK_MOD) {
@@ -329,7 +326,7 @@ void ModManager::setPaths() {
 Mod ModManager::loadMod(const std::string& name) {
 	Mod mod;
 	std::ifstream infile;
-	std::string starts_with, line, key, val;
+	std::string line, key, val;
 
 	mod.name = name;
 
@@ -340,16 +337,13 @@ Mod ModManager::loadMod(const std::string& name) {
 
 		while (infile.good()) {
 			line = Parse::getLine(infile);
+
+			if (Parse::skipLine(line))
+				continue;
+
 			key = "";
 			val = "";
 
-			// skip ahead if this line is empty
-			if (line.length() == 0) continue;
-
-			// skip comments
-			starts_with = line.at(0);
-			if (starts_with == "#") continue;
-
 			Parse::getKeyPair(line, key, val);
 
 			if (key == "description") {
@@ -410,15 +404,29 @@ Mod ModManager::loadMod(const std::string& name) {
 				Utils::logError("ModManager: Mod '%s' contains invalid key: '%s'", name.c_str(), key.c_str());
 			}
 		}
-		if (infile.good()) {
-			infile.close();
-			infile.clear();
-			break;
-		}
-		else {
-			infile.close();
-			infile.clear();
+		infile.close();
+		infile.clear();
+
+		path = Filesystem::convertSlashes(mod_paths[i] + "mods/" + name + "/engine/gameplay.txt");
+		infile.open(path.c_str(), std::ios::in);
+
+		while (infile.good()) {
+			line = Parse::getLine(infile);
+
+			if (Parse::skipLine(line))
+				continue;
+
+			key = "";
+			val = "";
+
+			Parse::getKeyPair(line, key, val);
+
+			if (key == "enable_playgame") {
+				mod.is_game_mod = Parse::toBool(val);
+			}
 		}
+		infile.close();
+		infile.clear();
 	}
 
 	// ensure that engine min version <= engine max version
