@@ -40,17 +40,19 @@ class Hazard;
 class PostEffect {
 public:
 	std::string id;
-	int magnitude;
+	float magnitude;
 	int duration;
-	int chance;
+	float chance;
 	bool target_src;
+	bool is_multiplier;
 
 	PostEffect()
 		: id("")
 		, magnitude(0)
 		, duration(0)
 		, chance(100)
-		, target_src(false) {
+		, target_src(false)
+		, is_multiplier(false) {
 	}
 };
 
@@ -77,29 +79,24 @@ public:
 class Power {
 public:
 	enum {
-		HPMPSTATE_ANY = 0,
-		HPMPSTATE_ALL = 1
+		RESOURCESTATE_ANY = 0,
+		RESOURCESTATE_ALL = 1,
+		RESOURCESTATE_ANY_HPMP = 2,
 	};
 	enum {
-		HPMPSTATE_IGNORE = 0,
-		HPMPSTATE_PERCENT = 1,
-		HPMPSTATE_NOT_PERCENT = 2
+		RESOURCESTATE_IGNORE = 0,
+		RESOURCESTATE_PERCENT = 1,
+		RESOURCESTATE_NOT_PERCENT = 2
 	};
-	class HPMPState {
+	class ResourceState {
 	public:
-		int mode;
-		int hp_state;
-		int mp_state;
-		int hp;
-		int mp;
-		HPMPState()
-			: mode(HPMPSTATE_ANY)
-			, hp_state(HPMPSTATE_IGNORE)
-			, mp_state(HPMPSTATE_IGNORE)
-			, hp(-1)
-			, mp(-1)
+		int state;
+		float value;
+		ResourceState()
+			: state(RESOURCESTATE_IGNORE)
+			, value(0)
 		{}
-		~HPMPState() {}
+		~ResourceState() {}
 	};
 
 	enum {
@@ -137,13 +134,6 @@ public:
 		SPAWN_LIMIT_MODE_UNLIMITED = 2
 	};
 
-	enum {
-		SPAWN_LEVEL_MODE_DEFAULT = 0,
-		SPAWN_LEVEL_MODE_FIXED = 1,
-		SPAWN_LEVEL_MODE_STAT = 2,
-		SPAWN_LEVEL_MODE_LEVEL = 3
-	};
-
 	enum {
 		STAT_MODIFIER_MODE_MULTIPLY = 0,
 		STAT_MODIFIER_MODE_ADD = 1,
@@ -184,8 +174,9 @@ public:
 
 	// power requirements
 	std::set<std::string> requires_flags; // checked against equip_flags granted from items
-	int requires_mp;
-	int requires_hp;
+	float requires_mp;
+	float requires_hp;
+	std::vector<float> requires_resource_stat;
 	bool sacrifice;
 	bool requires_los; // line of sight
 	bool requires_los_default;
@@ -195,7 +186,11 @@ public:
 	bool requires_targeting; // power only makes sense when using click-to-target
 	int requires_spawns;
 	int cooldown; // milliseconds before you can use the power again
-	HPMPState requires_max_hpmp;
+	ResourceState requires_hp_state;
+	ResourceState requires_mp_state;
+	std::vector<ResourceState> requires_resource_stat_state;
+	int requires_hpmp_state_mode;
+	int requires_resource_stat_state_mode;
 
 	// animation info
 	std::string animation_name;
@@ -233,22 +228,23 @@ public:
 	float combat_range;
 
 	int mod_accuracy_mode;
-	int mod_accuracy_value;
+	float mod_accuracy_value;
 
 	int mod_crit_mode;
-	int mod_crit_value;
+	float mod_crit_value;
 
 	int mod_damage_mode;
-	int mod_damage_value_min;
-	int mod_damage_value_max;//only used if mode is absolute
+	float mod_damage_value_min;
+	float mod_damage_value_max;//only used if mode is absolute
 
 	//steal effects (in %, eg. hp_steal=50 turns 50% damage done into HP regain.)
-	int hp_steal;
-	int mp_steal;
+	float hp_steal;
+	float mp_steal;
+	std::vector<float> resource_steal;
 
 	//missile traits
-	int missile_angle;
-	int angle_variance;
+	float missile_angle;
+	float angle_variance;
 	float speed_variance;
 
 	//repeater traits
@@ -256,7 +252,7 @@ public:
 
 	int trait_elemental; // enum. of elements
 	bool trait_armor_penetration;
-	int trait_crits_impaired; // crit bonus vs. movement impaired enemies (slowed, immobilized, stunned)
+	float trait_crits_impaired; // crit bonus vs. movement impaired enemies (slowed, immobilized, stunned)
 	bool trait_avoidance_ignore;
 
 	int transform_duration;
@@ -273,25 +269,21 @@ public:
 	std::vector<PostEffect> post_effects;
 
 	PowerID pre_power;
-	int pre_power_chance;
+	float pre_power_chance;
 	PowerID post_power;
-	int post_power_chance;
+	float post_power_chance;
 	PowerID wall_power;
-	int wall_power_chance;
+	float wall_power_chance;
 	bool wall_reflect;
 
 	// spawn info
 	std::string spawn_type;
 	int target_neighbor;
-	int spawn_limit_mode;
-	int spawn_limit_qty;
-	int spawn_limit_every;
+	uint8_t spawn_limit_mode;
+	float spawn_limit_count;
+	float spawn_limit_ratio;
 	size_t spawn_limit_stat;
-
-	int spawn_level_mode;
-	int spawn_level_qty;
-	int spawn_level_every;
-	size_t spawn_level_stat;
+	SpawnLevel spawn_level;
 
 	// targeting by movement type
 	bool target_movement_normal;
@@ -365,8 +357,9 @@ public:
 	PowerID verifyID(PowerID power_id, FileParser* infile, bool allow_zero);
 	bool checkNearestTargeting(const Power &pow, const StatBlock *src_stats, bool check_corpses);
 	bool checkRequiredItems(const Power &pow, const StatBlock *src_stats);
-	bool checkRequiredMaxHPMP(const Power &pow, const StatBlock *src_stats);
+	bool checkRequiredResourceState(const Power &pow, const StatBlock *src_stats);
 	bool checkCombatRange(PowerID power_index, StatBlock *src_stats, FPoint target);
+	bool checkPowerCost(const Power &pow, const StatBlock *src_stats);
 	PowerID checkReplaceByEffect(PowerID power_index, StatBlock *src_stats);
 
 	EffectDef* getEffectDef(const std::string& id);
