@@ -1,5 +1,6 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2014-2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -21,7 +22,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * Helper text to remind the player of active quests
  */
 
-#pragma once
 #ifndef QUEST_LOG_H
 #define QUEST_LOG_H
 
@@ -32,22 +32,30 @@ class MenuLog;
 
 class QuestLog {
 private:
+	class Quest {
+	public:
+		std::string name;
+		StatusID complete_status;
+	};
+
 	MenuLog *log;
 
 	// inner vector is a chain of events per quest, outer vector is a
 	// list of quests.
-	std::vector<std::vector<Event_Component> >quests;
+	std::vector<std::vector<EventComponent> >quest_sections;
+
+	std::vector<size_t> active_quest_ids;
+	std::vector<size_t> complete_quest_ids;
+	std::vector<Quest> quests;
 
 public:
-	QuestLog(MenuLog *_log);
+	explicit QuestLog(MenuLog *_log);
 	~QuestLog();
 	void loadAll();
-	void loadIndex(const std::string& filename);
 	void load(const std::string& filename);
 	void logic();
 	void createQuestList();
 	bool newQuestNotification;
-	bool resetQuestNotification;
 };
 
 #endif
