@@ -344,8 +344,6 @@ int SDLHardwareRenderDevice::createContextInternal() {
 					SDL_SetHintWithPriority(SDL_HINT_RENDER_SCALE_QUALITY, "1", SDL_HINT_OVERRIDE);
 				else
 					SDL_SetHintWithPriority(SDL_HINT_RENDER_SCALE_QUALITY, "0", SDL_HINT_OVERRIDE);
-
-				windowResize();
 			}
 
 			SDL_SetWindowMinimumSize(window, eset->resolutions.min_screen_w, eset->resolutions.min_screen_h);
@@ -392,7 +390,10 @@ int SDLHardwareRenderDevice::createContextInternal() {
 		}
 
 		windowResize();
+		is_initialized = (texture != NULL);
+	}
 
+	if (is_initialized) {
 		// update title bar text and icon
 		updateTitleBar();
 
@@ -682,7 +683,7 @@ void SDLHardwareRenderDevice::windowResize() {
 
 	if (texture) SDL_DestroyTexture(texture);
 	texture = SDL_CreateTexture(renderer, SDL_PIXELFORMAT_ARGB8888, SDL_TEXTUREACCESS_TARGET, settings->view_w, settings->view_h);
-	SDL_SetRenderTarget(renderer, texture);
+	if (texture) SDL_SetRenderTarget(renderer, texture);
 
 	settings->updateScreenVars();
 }
