@@ -46,6 +46,7 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "StatBlock.h"
 #include "UtilsMath.h"
 #include "UtilsParsing.h"
+#include "XPScaling.h"
 
 #include <limits>
 
@@ -59,7 +60,7 @@ const float StatBlock::DIRECTION_DELTA_Y[8] =   { 1,  0, -1, -1, -1,  0,  1,  1}
 const float StatBlock::SPEED_MULTIPLIER[8] = { static_cast<float>(1.0/M_SQRT2), 1.0f, static_cast<float>(1.0/M_SQRT2), 1.0f, static_cast<float>(1.0/M_SQRT2), 1.0f, static_cast<float>(1.0/M_SQRT2), 1.0f};
 
 size_t StatBlock::getFullStatCount() {
-	return Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+	return Stats::COUNT + eset->damage_types.count + eset->elements.list.size() + eset->resource_stats.stat_count;
 }
 
 StatBlock::StatBlock()
@@ -93,6 +94,7 @@ StatBlock::StatBlock()
 	, name("")
 	, level(0)
 	, xp(0)
+	, xp_scaling_table(0)
 	, level_up(false)
 	, check_title(false)
 	, stat_points_per_level(1)
@@ -104,14 +106,10 @@ StatBlock::StatBlock()
 	, character_class("")
 	, character_subclass("")
 	, hp(0)
-	, hp_f(0)
 	, mp(0)
-	, mp_f(0)
 	, speed_default(0.1f)
-	, dmg_min_add(eset->damage_types.list.size(), 0)
-	, dmg_max_add(eset->damage_types.list.size(), 0)
-	, absorb_min_add(0)
-	, absorb_max_add(0)
+	, item_base_dmg(eset->damage_types.list.size())
+	, item_base_abs()
 	, speed(0.1f)
 	, charge_speed(0.0f)
 	, transform_duration(0)
@@ -206,6 +204,10 @@ StatBlock::StatBlock()
 	}
 
 	cooldown.reset(Timer::END);
+
+	resource_stats.resize(eset->resource_stats.list.size());
+	prev_max_resource_stats.resize(eset->resource_stats.list.size());
+	prev_resource_stats.resize(eset->resource_stats.list.size());
 }
 
 StatBlock::~StatBlock() {
@@ -224,7 +226,7 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 		return true;
 	}
 	else if (infile->key == "cooldown") {
-		// @ATTR cooldown|int|Cooldown between attacks in 'ms' or 's'.
+		// @ATTR cooldown|duration|Cooldown between attacks in 'ms' or 's'.
 		cooldown.setDuration(Parse::toDuration(infile->val));
 		return true;
 	}
@@ -235,9 +237,10 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 		return true;
 	}
 	else if (infile->key == "stat") {
-		// @ATTR stat|stat_id, int : Stat ID, Value|The starting value for this stat.
+		// @ATTR stat|stat_id, float : Stat ID, Value|The starting value for this stat.
 		std::string stat = Parse::popFirstString(infile->val);
-		int value = Parse::popFirstInt(infile->val);
+		float value = Parse::popFirstFloat(infile->val);
+		size_t offset_index = 0;
 
 		for (int i=0; i<Stats::COUNT; ++i) {
 			if (Stats::KEY[i] == stat) {
@@ -245,29 +248,42 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 				return true;
 			}
 		}
+		offset_index += Stats::COUNT;
 
 		for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
 			if (eset->damage_types.list[i].min == stat) {
-				starting[Stats::COUNT + (i*2)] = value;
+				starting[offset_index + (i*2)] = value;
 				return true;
 			}
 			else if (eset->damage_types.list[i].max == stat) {
-				starting[Stats::COUNT + (i*2) + 1] = value;
+				starting[offset_index + (i*2) + 1] = value;
 				return true;
 			}
 		}
+		offset_index += eset->damage_types.count;
 
 		for (size_t i = 0; i < eset->elements.list.size(); ++i) {
 			if (eset->elements.list[i].resist_id == stat) {
-				starting[Stats::COUNT + eset->damage_types.count + i] = value;
+				starting[offset_index + i] = value;
 				return true;
 			}
 		}
+		offset_index += eset->elements.list.size();
+
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+				if (eset->resource_stats.list[i].ids[j] == stat) {
+					starting[offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + j] = value;
+					return true;
+				}
+			}
+		}
 	}
 	else if (infile->key == "stat_per_level") {
-		// @ATTR stat_per_level|stat_id, int : Stat ID, Value|The value for this stat added per level.
+		// @ATTR stat_per_level|stat_id, float : Stat ID, Value|The value for this stat added per level.
 		std::string stat = Parse::popFirstString(infile->val);
-		int value = Parse::popFirstInt(infile->val);
+		float value = Parse::popFirstFloat(infile->val);
+		size_t offset_index = 0;
 
 		for (int i=0; i<Stats::COUNT; i++) {
 			if (Stats::KEY[i] == stat) {
@@ -275,27 +291,39 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 				return true;
 			}
 		}
+		offset_index += Stats::COUNT;
 
 		for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
 			if (eset->damage_types.list[i].min == stat) {
-				per_level[Stats::COUNT + (i*2)] = value;
+				per_level[offset_index + (i*2)] = value;
 				return true;
 			}
 			else if (eset->damage_types.list[i].max == stat) {
-				per_level[Stats::COUNT + (i*2) + 1] = value;
+				per_level[offset_index + (i*2) + 1] = value;
 				return true;
 			}
 		}
+		offset_index += eset->damage_types.count;
 
 		for (size_t i = 0; i < eset->elements.list.size(); ++i) {
 			if (eset->elements.list[i].resist_id == stat) {
-				per_level[Stats::COUNT + eset->damage_types.count + i] = value;
+				per_level[offset_index + i] = value;
 				return true;
 			}
 		}
+		offset_index += eset->elements.list.size();
+
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+				if (eset->resource_stats.list[i].ids[j] == stat) {
+					per_level[offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + j] = value;
+					return true;
+				}
+			}
+		}
 	}
 	else if (infile->key == "stat_per_primary") {
-		// @ATTR stat_per_primary|predefined_string, stat_id, int : Primary Stat, Stat ID, Value|The value for this stat added for every point allocated to this primary stat.
+		// @ATTR stat_per_primary|predefined_string, stat_id, float : Primary Stat, Stat ID, Value|The value for this stat added for every point allocated to this primary stat.
 		std::string prim_stat = Parse::popFirstString(infile->val);
 		size_t prim_stat_index = eset->primary_stats.getIndexByID(prim_stat);
 		if (prim_stat_index == eset->primary_stats.list.size()) {
@@ -304,7 +332,8 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 		}
 
 		std::string stat = Parse::popFirstString(infile->val);
-		int value = Parse::popFirstInt(infile->val);
+		float value = Parse::popFirstFloat(infile->val);
+		size_t offset_index = 0;
 
 		for (int i=0; i<Stats::COUNT; i++) {
 			if (Stats::KEY[i] == stat) {
@@ -312,29 +341,41 @@ bool StatBlock::loadCoreStat(FileParser *infile) {
 				return true;
 			}
 		}
+		offset_index += Stats::COUNT;
 
 		for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
 			if (eset->damage_types.list[i].min == stat) {
-				per_primary[prim_stat_index][Stats::COUNT + (i*2)] = value;
+				per_primary[prim_stat_index][offset_index + (i*2)] = value;
 				return true;
 			}
 			else if (eset->damage_types.list[i].max == stat) {
-				per_primary[prim_stat_index][Stats::COUNT + (i*2) + 1] = value;
+				per_primary[prim_stat_index][offset_index + (i*2) + 1] = value;
 				return true;
 			}
 		}
+		offset_index += eset->damage_types.count;
 
 		for (size_t i = 0; i < eset->elements.list.size(); ++i) {
 			if (eset->elements.list[i].resist_id == stat) {
-				per_primary[prim_stat_index][Stats::COUNT + eset->damage_types.count + i] = value;
+				per_primary[prim_stat_index][offset_index + i] = value;
 				return true;
 			}
 		}
+		offset_index += eset->elements.list.size();
+
+		for (size_t i = 0; i < eset->resource_stats.list.size(); ++i) {
+			for (size_t j = 0; j < EngineSettings::ResourceStats::STAT_COUNT; ++j) {
+				if (eset->resource_stats.list[i].ids[j] == stat) {
+					per_primary[prim_stat_index][offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + j] = value;
+					return true;
+				}
+			}
+		}
 	}
 	else if (infile->key == "vulnerable") {
-		// @ATTR vulnerable|predefined_string, int : Element, Value|(Deprecated in v1.12.91; use a '..._resist' value with 'stat' instead) Percentage weakness to this element.
+		// @ATTR vulnerable|predefined_string, float : Element, Value|(Deprecated in v1.12.91; use a '..._resist' value with 'stat' instead) Percentage weakness to this element.
 		std::string element = Parse::popFirstString(infile->val);
-		int value = (Parse::popFirstInt(infile->val) * -1) + 100;
+		float value = (Parse::popFirstFloat(infile->val) * -1) + 100;
 
 		infile->error("StatBlock: 'vulnerable' is deprecated. Use 'stat=%s_resist,%d' instead.", element.c_str(), value);
 
@@ -590,6 +631,14 @@ void StatBlock::load(const std::string& filename) {
 		// enemy death rewards and events
 		// @ATTR xp|int|XP awarded upon death.
 		else if (infile.key == "xp") xp = num;
+
+		else if (infile.key == "xp_scaling") {
+			// @ATTR xp_scaling|filename|XP multiplier table file. See: "XPScaling".
+			if (xp_scaling) {
+				xp_scaling_table = xp_scaling->load(infile.val);
+			}
+		}
+
 		else if (infile.key == "loot") {
 			// @ATTR loot|repeatable(loot)|Possible loot that can be dropped on death.
 
@@ -641,10 +690,10 @@ void StatBlock::load(const std::string& filename) {
 
 		// @ATTR turn_delay|duration|Duration it takes for this creature to turn and face their target in 'ms' or 's'.
 		else if (infile.key == "turn_delay") turn_delay = Parse::toDuration(infile.val);
-		// @ATTR chance_pursue|int|Percentage change that the creature will chase their target.
-		else if (infile.key == "chance_pursue") chance_pursue = num;
-		// @ATTR chance_flee|int|Percentage chance that the creature will run away from their target.
-		else if (infile.key == "chance_flee") chance_flee = num;
+		// @ATTR chance_pursue|float|Percentage change that the creature will chase their target.
+		else if (infile.key == "chance_pursue") chance_pursue = fnum;
+		// @ATTR chance_flee|float|Percentage chance that the creature will run away from their target.
+		else if (infile.key == "chance_flee") chance_flee = fnum;
 
 		else if (infile.key == "power") {
 			// @ATTR power|["melee", "ranged", "beacon", "on_hit", "on_death", "on_half_dead", "on_join_combat", "on_debuff"], power_id, int : State, Power, Chance|A power that has a chance of being triggered in a certain state.
@@ -699,7 +748,7 @@ void StatBlock::load(const std::string& filename) {
 
 		// @ATTR threat_range|float, float: Engage distance, Stop distance|The first value is the radius of the area this creature will be able to start chasing the hero. The second, optional, value is the radius at which this creature will stop pursuing their target and defaults to double the first value.
 		else if (infile.key == "threat_range") {
-			threat_range = Parse::toFloat(Parse::popFirstString(infile.val));
+			threat_range = Parse::popFirstFloat(infile.val);
 
 			std::string tr_far = Parse::popFirstString(infile.val);
 			if (!tr_far.empty())
@@ -744,6 +793,11 @@ void StatBlock::load(const std::string& filename) {
 	hp = starting[Stats::HP_MAX];
 	mp = starting[Stats::MP_MAX];
 
+	size_t resource_offset_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		resource_stats[i] = starting[resource_offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + EngineSettings::ResourceStats::STAT_BASE];
+	}
+
 	if (!flee_range_defined)
 		flee_range = threat_range / 2;
 
@@ -753,7 +807,7 @@ void StatBlock::load(const std::string& filename) {
 /**
  * Reduce temphp first, then hp
  */
-void StatBlock::takeDamage(int dmg, bool crit, int source_type) {
+void StatBlock::takeDamage(float dmg, bool crit, int source_type) {
 	hp -= effects.damageShields(dmg);
 	if (hp <= 0) {
 		hp = 0;
@@ -793,9 +847,11 @@ void StatBlock::takeDamage(int dmg, bool crit, int source_type) {
 				// reward XP; adjust for party exp if necessary
 				float xp_multiplier = 1;
 				if (source_type == Power::SOURCE_TYPE_ALLY)
-					xp_multiplier = static_cast<float>(eset->misc.party_exp_percentage) / 100.0f;
+					xp_multiplier = eset->misc.party_exp_percentage / 100.0f;
 
-				camp->rewardXP(static_cast<int>((static_cast<float>(xp) * xp_multiplier)), !CampaignManager::XP_SHOW_MSG);
+				xp_multiplier *= xp_scaling->getMultiplier(this, &(pc->stats));
+
+				camp->rewardXP(static_cast<float>(xp) * xp_multiplier, !CampaignManager::XP_SHOW_MSG);
 
 				// drop loot
 				loot->addEnemyLoot(this);
@@ -839,6 +895,11 @@ void StatBlock::recalc() {
 
 	hp = get(Stats::HP_MAX);
 	mp = get(Stats::MP_MAX);
+
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		resource_stats[i] = getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE);
+	}
+
 }
 
 /**
@@ -847,7 +908,7 @@ void StatBlock::recalc() {
  */
 void StatBlock::calcBase() {
 	// bonuses are skipped for the default level 1 of a stat
-	const int lev0 = std::max(level - 1, 0);
+	const float lev0 = static_cast<float>(std::max(level - 1, 0));
 
 	if (per_primary.empty()) {
 		for (size_t i = 0; i < getFullStatCount(); ++i) {
@@ -856,8 +917,8 @@ void StatBlock::calcBase() {
 	}
 	else {
 		for (size_t j = 0; j < per_primary.size(); ++j) {
-			const int current_primary = std::max(get_primary(j) - 1, 0);
-			const std::vector<int>& per_primary_vec = per_primary[j];
+			const float current_primary = static_cast<float>(std::max(get_primary(j) - 1, 0));
+			const std::vector<float>& per_primary_vec = per_primary[j];
 			for (size_t i = 0; i < getFullStatCount(); ++i) {
 				if (j==0)
 					base[i] = starting[i] + (lev0 * per_level[i]);
@@ -868,16 +929,16 @@ void StatBlock::calcBase() {
 
 	// add damage from equipment and increase to minimum amounts
 	for (size_t i = 0; i < eset->damage_types.list.size(); ++i) {
-		base[Stats::COUNT + (i*2)] += dmg_min_add[i];
-		base[Stats::COUNT + (i*2) + 1] += dmg_max_add[i];
-		base[Stats::COUNT + (i*2)] = std::max(base[Stats::COUNT + (i*2)], 0);
+		base[Stats::COUNT + (i*2)] += item_base_dmg[i].min;
+		base[Stats::COUNT + (i*2) + 1] += item_base_dmg[i].max;
+		base[Stats::COUNT + (i*2)] = std::max(base[Stats::COUNT + (i*2)], 0.0f);
 		base[Stats::COUNT + (i*2) + 1] = std::max(base[Stats::COUNT + (i*2) + 1], base[Stats::COUNT + (i*2)]);
 	}
 
 	// add absorb from equipment and increase to minimum amounts
-	base[Stats::ABS_MIN] += absorb_min_add;
-	base[Stats::ABS_MAX] += absorb_max_add;
-	base[Stats::ABS_MIN] = std::max(base[Stats::ABS_MIN], 0);
+	base[Stats::ABS_MIN] += item_base_abs.min;
+	base[Stats::ABS_MAX] += item_base_abs.max;
+	base[Stats::ABS_MIN] = std::max(base[Stats::ABS_MIN], 0.0f);
 	base[Stats::ABS_MAX] = std::max(base[Stats::ABS_MAX], base[Stats::ABS_MIN]);
 }
 
@@ -887,11 +948,16 @@ void StatBlock::calcBase() {
 void StatBlock::applyEffects() {
 	// preserve hp/mp states
 	// max HP and MP can't drop below 1
-	prev_maxhp = std::max(get(Stats::HP_MAX), 1);
-	prev_maxmp = std::max(get(Stats::MP_MAX), 1);
+	prev_maxhp = std::max(get(Stats::HP_MAX), 1.0f);
+	prev_maxmp = std::max(get(Stats::MP_MAX), 1.0f);
 	prev_hp = hp;
 	prev_mp = mp;
 
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		prev_max_resource_stats[i] = std::max(getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE), 1.0f);
+		prev_resource_stats[i] = resource_stats[i];
+	}
+
 	// calculate primary stats
 	// refresh the character menu if there has been a change
 	for (size_t i = 0; i < primary.size(); ++i) {
@@ -904,19 +970,25 @@ void StatBlock::applyEffects() {
 	calcBase();
 
 	for (size_t i = 0; i < getFullStatCount(); ++i) {
-		current[i] = base[i] + effects.bonus[i];
+		current[i] = (base[i] + effects.bonus[i]) * effects.bonus_multiplier[i];
 	}
 
-	current[Stats::HP_MAX] += (current[Stats::HP_MAX] * current[Stats::HP_PERCENT]) / 100;
-	current[Stats::MP_MAX] += (current[Stats::MP_MAX] * current[Stats::MP_PERCENT]) / 100;
-
 	// max HP and MP can't drop below 1
-	current[Stats::HP_MAX] = std::max(get(Stats::HP_MAX), 1);
-	current[Stats::MP_MAX] = std::max(get(Stats::MP_MAX), 1);
+	current[Stats::HP_MAX] = std::max(get(Stats::HP_MAX), 1.0f);
+	current[Stats::MP_MAX] = std::max(get(Stats::MP_MAX), 1.0f);
 
 	if (hp > get(Stats::HP_MAX)) hp = get(Stats::HP_MAX);
 	if (mp > get(Stats::MP_MAX)) mp = get(Stats::MP_MAX);
 
+	size_t resource_offset_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		size_t current_index = resource_offset_index + (i * EngineSettings::ResourceStats::STAT_COUNT) + EngineSettings::ResourceStats::STAT_BASE;
+		current[current_index] = std::max(getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE), 1.0f);
+		if (resource_stats[i] > current[current_index]) {
+			resource_stats[i] = current[current_index];
+		}
+	}
+
 	speed = speed_default;
 }
 
@@ -957,14 +1029,18 @@ void StatBlock::logic() {
 	}
 
 	// preserve ratio on maxmp and maxhp changes
-	float ratio;
 	if (prev_maxhp != get(Stats::HP_MAX)) {
-		ratio = static_cast<float>(prev_hp) / static_cast<float>(prev_maxhp);
-		hp = static_cast<int>(ratio * static_cast<float>(get(Stats::HP_MAX)));
+		hp = (prev_hp / prev_maxhp) * get(Stats::HP_MAX);
 	}
 	if (prev_maxmp != get(Stats::MP_MAX)) {
-		ratio = static_cast<float>(prev_mp) / static_cast<float>(prev_maxmp);
-		mp = static_cast<int>(ratio * static_cast<float>(get(Stats::MP_MAX)));
+		mp = (prev_mp / prev_maxmp) * get(Stats::MP_MAX);
+	}
+
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		float resource_stat_max = getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE);
+		if (prev_max_resource_stats[i] != resource_stat_max) {
+			resource_stats[i] = (prev_resource_stats[i] / prev_max_resource_stats[i]) * resource_stat_max;
+		}
 	}
 
 	// handle cooldowns
@@ -974,31 +1050,37 @@ void StatBlock::logic() {
 		powers_ai[i].cooldown.tick();
 	}
 
-	// sync hp/mp with their floating point counterparts
-	if (static_cast<int>(hp_f) != hp)
-		hp_f = static_cast<float>(hp);
-	if (static_cast<int>(mp_f) != mp)
-		mp_f = static_cast<float>(mp);
-
 	// HP regen
 	if (hp <= get(Stats::HP_MAX) && hp > 0) {
 		float hp_regen_per_frame;
 		if (!in_combat && !hero_ally && !hero && pc->stats.alive) {
 			// enemies heal rapidly (full heal in 5 seconds) while not in combat
-			hp_regen_per_frame = static_cast<float>(get(Stats::HP_MAX)) / 5.f / settings->max_frames_per_sec;
+			hp_regen_per_frame = get(Stats::HP_MAX) / 5.f / settings->max_frames_per_sec;
 		}
 		else {
-			hp_regen_per_frame = static_cast<float>(get(Stats::HP_REGEN)) / 60.f / settings->max_frames_per_sec;
+			hp_regen_per_frame = get(Stats::HP_REGEN) / 60.f / settings->max_frames_per_sec;
 		}
-		hp_f += hp_regen_per_frame;
-		hp = std::max(0, std::min(static_cast<int>(hp_f), get(Stats::HP_MAX)));
+		hp += hp_regen_per_frame;
+		hp = std::max(0.0f, std::min(hp, get(Stats::HP_MAX)));
 	}
 
 	// MP regen
 	if (mp <= get(Stats::MP_MAX) && hp > 0) {
-		float mp_regen_per_frame = static_cast<float>(get(Stats::MP_REGEN)) / 60.f / settings->max_frames_per_sec;
-		mp_f += mp_regen_per_frame;
-		mp = std::max(0, std::min(static_cast<int>(mp_f), get(Stats::MP_MAX)));
+		float mp_regen_per_frame = get(Stats::MP_REGEN) / 60.f / settings->max_frames_per_sec;
+		mp += mp_regen_per_frame;
+		mp = std::max(0.0f, std::min(mp, get(Stats::MP_MAX)));
+	}
+
+	// resource stat regen
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		float resource_stat_max = getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE);
+		float resource_stat_regen = getResourceStat(i, EngineSettings::ResourceStats::STAT_REGEN);
+
+		if (resource_stats[i] <= resource_stat_max && hp > 0) {
+			float regen_per_frame = resource_stat_regen / 60.f / settings->max_frames_per_sec;
+			resource_stats[i] += regen_per_frame;
+			resource_stats[i] = std::max(0.0f, std::min(resource_stats[i], resource_stat_max));
+		}
 	}
 
 	// handle buff/debuff durations
@@ -1007,13 +1089,16 @@ void StatBlock::logic() {
 
 	// apply bleed
 	if (effects.damage > 0 && hp > 0) {
-		takeDamage(effects.damage, !StatBlock::TAKE_DMG_CRIT, effects.getDamageSourceType(Effect::DAMAGE));
-		comb->addInt(effects.damage, pos, CombatText::MSG_TAKEDMG);
+		float damage = effects.damage;
+		damage = eset->combat.resourceRound(damage);
+		takeDamage(damage, !StatBlock::TAKE_DMG_CRIT, effects.getDamageSourceType(Effect::DAMAGE));
+		comb->addFloat(damage, pos, CombatText::MSG_TAKEDMG);
 	}
 	if (effects.damage_percent > 0 && hp > 0) {
-		int damage = (get(Stats::HP_MAX)*effects.damage_percent)/100;
+		float damage = (get(Stats::HP_MAX) * effects.damage_percent) / 100;
+		damage = eset->combat.resourceRound(damage);
 		takeDamage(damage, !StatBlock::TAKE_DMG_CRIT, effects.getDamageSourceType(Effect::DAMAGE_PERCENT));
-		comb->addInt(damage, pos, CombatText::MSG_TAKEDMG);
+		comb->addFloat(damage, pos, CombatText::MSG_TAKEDMG);
 	}
 
 	if(effects.death_sentence)
@@ -1031,27 +1116,55 @@ void StatBlock::logic() {
 
 	// apply healing over time
 	if (effects.hpot > 0) {
-		comb->addString(msg->get("+%d HP",effects.hpot), pos, CombatText::MSG_BUFF);
-		hp += effects.hpot;
+		float hpot = effects.hpot;
+		hpot = eset->combat.resourceRound(hpot);
+		comb->addString(msg->getv("+%s HP", Utils::floatToString(hpot, eset->number_format.combat_text).c_str()), pos, CombatText::MSG_BUFF);
+		hp += hpot;
 		if (hp > get(Stats::HP_MAX)) hp = get(Stats::HP_MAX);
 	}
 	if (effects.hpot_percent > 0) {
-		int hpot = (get(Stats::HP_MAX)*effects.hpot_percent)/100;
-		comb->addString(msg->get("+%d HP",hpot), pos, CombatText::MSG_BUFF);
+		float hpot = (get(Stats::HP_MAX) * effects.hpot_percent) / 100;
+		hpot = eset->combat.resourceRound(hpot);
+		comb->addString(msg->getv("+%s HP", Utils::floatToString(hpot, eset->number_format.combat_text).c_str()), pos, CombatText::MSG_BUFF);
 		hp += hpot;
 		if (hp > get(Stats::HP_MAX)) hp = get(Stats::HP_MAX);
 	}
 	if (effects.mpot > 0) {
-		comb->addString(msg->get("+%d MP",effects.mpot), pos, CombatText::MSG_BUFF);
-		mp += effects.mpot;
+		float mpot = effects.mpot;
+		mpot = eset->combat.resourceRound(mpot);
+		comb->addString(msg->getv("+%s MP", Utils::floatToString(mpot, eset->number_format.combat_text).c_str()), pos, CombatText::MSG_BUFF);
+		mp += mpot;
 		if (mp > get(Stats::MP_MAX)) mp = get(Stats::MP_MAX);
 	}
 	if (effects.mpot_percent > 0) {
-		int mpot = (get(Stats::MP_MAX)*effects.mpot_percent)/100;
-		comb->addString(msg->get("+%d MP",mpot), pos, CombatText::MSG_BUFF);
+		float mpot = (get(Stats::MP_MAX) * effects.mpot_percent) / 100;
+		mpot = eset->combat.resourceRound(mpot);
+		comb->addString(msg->getv("+%s MP", Utils::floatToString(mpot, eset->number_format.combat_text).c_str()), pos, CombatText::MSG_BUFF);
 		mp += mpot;
 		if (mp > get(Stats::MP_MAX)) mp = get(Stats::MP_MAX);
 	}
+	for (size_t i = 0; i < resource_stats.size(); ++i) {
+		if (effects.resource_ot[i] > 0) {
+			float resource_max = getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE);
+			float resource_ot = effects.resource_ot[i];
+			resource_ot = eset->combat.resourceRound(resource_ot);
+			comb->addString("+" + Utils::floatToString(resource_ot, eset->number_format.combat_text) + " " + eset->resource_stats.list[i].text_combat_heal, pos, CombatText::MSG_BUFF);
+			resource_stats[i] += resource_ot;
+
+			if (resource_stats[i] > resource_max)
+				resource_stats[i] = resource_max;
+		}
+		if (effects.resource_ot_percent[i] > 0) {
+			float resource_max = getResourceStat(i, EngineSettings::ResourceStats::STAT_BASE);
+			float resource_ot = (resource_max * effects.resource_ot_percent[i]) / 100;
+			resource_ot = eset->combat.resourceRound(resource_ot);
+			comb->addString("+" + Utils::floatToString(resource_ot, eset->number_format.combat_text) + " " + eset->resource_stats.list[i].text_combat_heal, pos, CombatText::MSG_BUFF);
+			resource_stats[i] += resource_ot;
+
+			if (resource_stats[i] > resource_max)
+				resource_stats[i] = resource_max;
+		}
+	}
 
 	// set movement type
 	// some creatures may shift between movement types
@@ -1118,12 +1231,11 @@ bool StatBlock::canUsePower(PowerID powerid, bool allow_passive) const {
 	}
 	else {
 		return (
-			mp >= power.requires_mp
+			powers->checkPowerCost(power, this)
 			&& (!power.passive || allow_passive)
 			&& !power.meta_power
 			&& (!effects.stun || (allow_passive && power.passive))
-			&& (power.sacrifice || hp > power.requires_hp)
-			&& powers->checkRequiredMaxHPMP(power, this)
+			&& powers->checkRequiredResourceState(power, this)
 			&& (!power.requires_corpse || (target_corpse && !target_corpse->corpse_timer.isEnd()) || (target_nearest_corpse && powers->checkNearestTargeting(power, this, true) && !target_nearest_corpse->corpse_timer.isEnd()))
 			&& (checkRequiredSpawns(power.requires_spawns))
 			&& (menu_powers && menu_powers->meetsUsageStats(powerid))
@@ -1224,9 +1336,10 @@ bool StatBlock::summonLimitReached(PowerID power_id) const {
 
 	int max_summons = 0;
 
-	if(spawn_power->spawn_limit_mode == Power::SPAWN_LIMIT_MODE_FIXED)
-		max_summons = spawn_power->spawn_limit_qty;
-	else if(spawn_power->spawn_limit_mode == Power::SPAWN_LIMIT_MODE_STAT) {
+	if (spawn_power->spawn_limit_mode == Power::SPAWN_LIMIT_MODE_FIXED) {
+		max_summons = static_cast<int>(spawn_power->spawn_limit_count);
+	}
+	else if (spawn_power->spawn_limit_mode == Power::SPAWN_LIMIT_MODE_STAT) {
 		int stat_val = 1;
 		for (size_t i = 0; i < eset->primary_stats.list.size(); ++i) {
 			if (spawn_power->spawn_limit_stat == i) {
@@ -1234,23 +1347,22 @@ bool StatBlock::summonLimitReached(PowerID power_id) const {
 				break;
 			}
 		}
-		max_summons = (stat_val / (spawn_power->spawn_limit_every == 0 ? 1 : spawn_power->spawn_limit_every)) * spawn_power->spawn_limit_qty;
+		max_summons = static_cast<int>(spawn_power->spawn_limit_count * (static_cast<float>(stat_val) / spawn_power->spawn_limit_ratio));
+	}
+	else {
+		// unlimited or unknown mode
+		return false;
 	}
-	else
-		return false;//unlimited or unknown mode
 
 	//if the power is available, there should be at least 1 allowed summon
-	if(max_summons < 1) max_summons = 1;
+	max_summons = std::max(max_summons, 1);
 
 
 	//find out how many there are currently
 	int qty_summons = 0;
 
 	for (unsigned int i=0; i < summons.size(); i++) {
-		if(!summons[i]->corpse && summons[i]->summoned_power_index == power_id
-				&& summons[i]->cur_state != ENTITY_SPAWN
-				&& summons[i]->cur_state != ENTITY_DEAD
-				&& summons[i]->cur_state != ENTITY_CRITDEAD) {
+		if (summons[i]->summoned_power_index == power_id && summons[i]->cur_state != ENTITY_DEAD && summons[i]->cur_state != ENTITY_CRITDEAD) {
 			qty_summons++;
 		}
 	}
@@ -1372,6 +1484,12 @@ void StatBlock::setPowerCooldown(PowerID power_id, int power_cooldown) {
 	}
 }
 
-int StatBlock::getResist(size_t resist_type) const {
+float StatBlock::getResist(size_t resist_type) const {
 	return current[Stats::COUNT + eset->damage_types.count + resist_type];
 }
+
+float StatBlock::getResourceStat(size_t resource_index, size_t field_offset) const {
+	size_t offset_index = Stats::COUNT + eset->damage_types.count + eset->elements.list.size();
+	return current[offset_index + (resource_index*4) + field_offset];
+}
+
