@@ -1,5 +1,5 @@
 /*
-Copyright © 2013 Justin Jacobs
+Copyright © 2013-2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -15,40 +15,48 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
-#pragma once
 #ifndef STATS_H
 #define STATS_H
 
 #include "CommonIncludes.h"
 
-#define STAT_COUNT 22
+namespace Stats {
+	enum STAT {
+		HP_MAX = 0,
+		HP_REGEN,
+		MP_MAX,
+		MP_REGEN,
+		ACCURACY,
+		AVOIDANCE,
+		ABS_MIN,
+		ABS_MAX,
+		CRIT,
+		XP_GAIN,
+		CURRENCY_FIND,
+		ITEM_FIND,
+		STEALTH,
+		POISE,
+		REFLECT,
+		RETURN_DAMAGE,
+		HP_STEAL,
+		MP_STEAL,
+		// all the below stats are hidden by default in MenuCharacter
+		RESIST_DAMAGE_OVER_TIME,
+		RESIST_SLOW,
+		RESIST_STUN,
+		RESIST_KNOCKBACK,
+		RESIST_STAT_DEBUFF,
+		RESIST_DAMAGE_REFLECT,
+		RESIST_HP_STEAL,
+		RESIST_MP_STEAL,
+		COUNT
+	};
 
-enum STAT {
-	STAT_DMG_MELEE_MIN = 0,
-	STAT_DMG_MELEE_MAX = 1,
-	STAT_DMG_RANGED_MIN = 2,
-	STAT_DMG_RANGED_MAX = 3,
-	STAT_DMG_MENT_MIN = 4,
-	STAT_DMG_MENT_MAX = 5,
-	STAT_ABS_MIN = 6,
-	STAT_ABS_MAX = 7,
-	STAT_HP_MAX = 8,
-	STAT_HP_REGEN = 9,
-	STAT_HP_PERCENT = 10,
-	STAT_MP_MAX = 11,
-	STAT_MP_REGEN = 12,
-	STAT_MP_PERCENT = 13,
-	STAT_ACCURACY = 14,
-	STAT_AVOIDANCE = 15,
-	STAT_CRIT = 16,
-	STAT_XP_GAIN = 17,
-	STAT_CURRENCY_FIND = 18,
-	STAT_ITEM_FIND = 19,
-	STAT_STEALTH = 20,
-	STAT_POISE = 21
-};
-
-extern std::string STAT_NAME[STAT_COUNT];
-void setStatNames();
+	extern std::string KEY[COUNT];
+	extern std::string NAME[COUNT];
+	extern std::string DESC[COUNT];
+	extern bool PERCENT[COUNT];
+	void init();
+}
 
 #endif
