@@ -1,6 +1,9 @@
 /*
 Copyright © 2012 Clint Bellanger
 Copyright © 2012 davidriod
+Copyright © 2013 Kurt Rinnert
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2014 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -20,7 +23,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class WidgetCheckBox
  */
 
-#pragma once
 #ifndef WIDGET_CHECKBOX_H
 #define WIDGET_CHECKBOX_H
 
@@ -28,22 +30,27 @@ class Widget;
 
 class WidgetCheckBox : public Widget {
 public:
-	WidgetCheckBox (const std::string &fname);
+	static const std::string DEFAULT_FILE;
+
+	explicit WidgetCheckBox (const std::string &fname);
 	~WidgetCheckBox ();
 
 	void activate();
-	void Check ();
-	void unCheck ();
-	bool checkClick ();
-	bool checkClick (int x, int y);
-	bool isChecked () const;
-	void render (SDL_Surface *target = NULL);
+	void setChecked(const bool status);
+	bool checkClick();
+	bool checkClickAt(int x, int y);
+	bool isChecked() const;
+	void render();
 	bool enabled;
+	std::string tooltip;
 
 private:
-	SDL_Surface * cb;
+	void checkTooltip(const Point& mouse);
+
+	Sprite *cb;
 	bool checked;
 	bool pressed;
+	bool activated;
 };
 
 #endif
