@@ -44,6 +44,7 @@ private:
 		}
 		std::string value;
 		std::string tooltip;
+		WidgetLabel label;
 		bool selected;
 	};
 
@@ -56,8 +57,8 @@ private:
 	int cursor;
 	bool has_scroll_bar;
 	bool any_selected;
+	bool show_tooltip_for_selected;
 	std::vector<ListBoxItem> items;
-	std::vector<WidgetLabel> vlabels;
 	std::vector<Rect> rows;
 	WidgetScrollBar *scrollbar;
 
@@ -90,6 +91,7 @@ public:
 	bool getNext();
 	bool getPrev();
 	void defocus();
+	void activate();
 
 	void select(int index);
 	bool isSelected(int index);
