@@ -104,13 +104,6 @@ bool WidgetSlider::checkClickAt(int x, int y) {
 
 	if (pressed) {
 		// The knob has been released
-		// create a temporary Rect slightly wider than the slider
-		Rect tmp_pos;
-		tmp_pos.x = pos.x - (pos_knob.w*2);
-		tmp_pos.y = pos.y;
-		tmp_pos.w = pos.w + (pos_knob.w*4);
-		tmp_pos.h = pos.h;
-
 		if (!inpt->lock[Input::MAIN1]) {
 			pressed = false;
 		}
@@ -189,7 +182,7 @@ void WidgetSlider::render () {
 			draw = false;
 		}
 		if (draw) {
-			render_device->drawRectangle(topLeft, bottomRight, eset->widgets.selection_rect_color);
+			render_device->drawRectangleCorners(eset->widgets.selection_rect_corner_size, topLeft, bottomRight, eset->widgets.selection_rect_color);
 		}
 	}
 
