@@ -1,5 +1,6 @@
 /*
-Copyright © 2012 Justin Jacobs
+Copyright © 2012-2015 Justin Jacobs
+Copyright © 2013 Kurt Rinnert
 
 This file is part of FLARE.
 
@@ -19,7 +20,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class WidgetSlider
  */
 
-#pragma once
 #ifndef WIDGET_SLIDER_H
 #define WIDGET_SLIDER_H
 
@@ -27,24 +27,28 @@ class Widget;
 
 class WidgetSlider : public Widget {
 public:
-	WidgetSlider (const std::string & fname);
-	~WidgetSlider ();
+	static const std::string DEFAULT_FILE;
 
-	bool checkClick ();
-	bool checkClick (int x, int y);
+	explicit WidgetSlider (const std::string & fname);
+	~WidgetSlider ();
+	void setPos(int offset_x, int offset_y);
+
+	bool checkClick();
+	bool checkClickAt(int x, int y);
 	void set (int min, int max, int val);
 	int getValue () const;
-	void render (SDL_Surface *target = NULL);
+	void render ();
 	bool enabled;
 
-	SDL_Rect pos_knob; // This is the position of the slider's knob within the screen
+	Rect pos_knob; // This is the position of the slider's knob within the screen
 
 	bool getNext();
 	bool getPrev();
 
 private:
-	SDL_Surface * sl;
+	Sprite *sl;
 	bool pressed;
+	bool changed_without_mouse;
 	int minimum;
 	int maximum;
 	int value;
